//---------------------------------------------------------------------------
// TestBrowsedRelativeGrowth
//---------------------------------------------------------------------------
#if !defined(TestBrowsedRelativeGrowth_H)
  #define TestBrowsedRelativeGrowth_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>
#include <cppunit/TestSuite.h>

class clSimManager;

/**
* Tests the clBrowsedRelativeGrowth class.
*/
class clTestBrowsedRelativeGrowth : public CppUnit::TestFixture {

  public:

  /**
  * Combines the testing into one function.
  */
  void TestBrowsedRelativeGrowth();

  protected:

  /**
  * Tests the growth when the timestep length is one year. WriteXMLFile1()
  * is used to set up the run.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void TestNormalRun1(clSimManager *p_oSimManager);

  /**
  * Tests the growth when the timestep length is three years.  WriteXMLFile2()
  * is used to set up the run.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void TestNormalRun2(clSimManager *p_oSimManager);

  /**
  * Tests when growth is diam only.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void TestNormalRun3(clSimManager *p_oSimManager);
  
  /**
  * Tests error processing.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file for normal run 1.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes a parameter file for normal run 2.
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes a parameter file for normal run 3.
  * @return Filename written.
  */
  char* WriteXMLFile3();
  
  /**
  * Writes a parameter file where not all trees also have light.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();
  
  /**
  * Writes a parameter file where not all trees also have browsing.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();
  
  /**
  * Writes common portions of the test parameter files (tree pop, plot,
  * etc).
  * @param oOut File stream to write to.
  */
  void WritePlotAndTrees(std::fstream &oOut);
  
  /**
  * Writes common parameters of the test parameter file.
  * @param oOut File stream to write to.
  */
  void WriteCommonParameters(std::fstream &oOut);
};
//---------------------------------------------------------------------------
#endif // TestBrowsedRelativeGrowth_H
