//---------------------------------------------------------------------------
// TestBrowsedStochasticMortality_H
//---------------------------------------------------------------------------
#if !defined(TestBrowsedStochasticMortality_H)
  #define TestBrowsedStochasticMortality_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clBrowsedStochasticMortality class.
*/
class clTestBrowsedStochasticMortality : public CppUnit::TestFixture
{
  public:

  /**
  * This puts all mortality tests into a single function.
  */
  void TestBrowsedStochasticMortality();

  protected:

  /**
  * Tests normal processing run 1.  WriteXMLFile1() does setup.  Timestep
  * length is 1 year and there is a light grid present.  1000 copies of each of
  * 27 trees is created of 3 species and assigned to a mix of browsed and
  * unbrowsed. Then mortality is run.  We check the number left of each tree
  * type to see if it is approximately the right number.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Tests normal processing run 2.  WriteXMLFile2() does setup.  Timestep
  * length is 3 years and there is a light grid present.  1000 copies of each
  * of 27 trees is created of 3 species and assigned to a mix of browsed and
  * unbrowsed. Then mortality is run.  We check the number left of each tree
  * type to see if it is approximately the right number.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun2(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  Inputs error files to make sure the errors are
  * caught.
  */
  void ErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file for normal processing run 1.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes a parameter file for normal processing run 2.
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes a parameter file where a value for browsed mortality probability
  * is not between 0 and 1.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes a parameter file where a value for unbrowsed mortality probability
  * is not between 0 and 1.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes a parameter file where there is no browsed behavior.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes common portions of the test parameter files.  This starts with
  * &lt;randomSeed&gt; and ends with &lt;/allometry&gt;.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);

  /**
  * Writes mortality parameters for the test parameter files.
  * @param oOut File stream to write to.
  */
  void WriteMortParameters(std::fstream &oOut);
};
#endif // TestBrowsedStochasticMortality_H
//---------------------------------------------------------------------------


