//---------------------------------------------------------------------------
// TestClimateChange.cpp
//---------------------------------------------------------------------------
#include "TestClimateChange.h"
#include "SimManager.h"
#include "TreePopulation.h"
#include "Plot.h"
#include "ModelMath.h"
#include "GridBase.h"
#include <math.h>
#include <fstream>

/////////////////////////////////////////////////////////////////////////////
// TestClimateChange()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::TestClimateChange()
{

  clSimManager * p_oSimManager = new clSimManager(3, 3, "");

  TestNormalProcessingRun1(p_oSimManager);
  TestNormalProcessingRun2(p_oSimManager);
  TestNormalProcessingRun3(p_oSimManager);
  TestNormalProcessingRun4(p_oSimManager);
  TestNormalProcessingRun5(p_oSimManager);
  TestNormalProcessingRun6(p_oSimManager);

  //Clean up
  delete p_oSimManager;
}


/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun1()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::TestNormalProcessingRun1(clSimManager *p_oSimManager)
{
  clPlot *p_oPlot;
  clGridBase *p_oClimateGrid;
  float fActualTemp, fExpectedTemp, fActualPrecip, fExpectedPrecip;
  int iTempCode, iPrecipCode;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile1());
  p_oPlot = p_oSimManager->GetPlotObject();
  p_oClimateGrid = p_oSimManager->GetGridObject("State Variables");
  iTempCode = p_oClimateGrid->GetFloatDataCode("Temp.C");
  iPrecipCode = p_oClimateGrid->GetFloatDataCode("Precip.mm");

  //Initial conditions
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 1
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 2
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.01;
  fExpectedTemp = 8.02;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 3
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.04;
  fExpectedTemp = 8.04;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 4
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.09;
  fExpectedTemp = 8.06;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 5
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.16;
  fExpectedTemp = 8.08;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun2()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::TestNormalProcessingRun2(clSimManager *p_oSimManager)
{
  clPlot *p_oPlot;
  clGridBase *p_oClimateGrid;
  float fActualTemp, fExpectedTemp, fActualPrecip, fExpectedPrecip;
  int iTempCode, iPrecipCode;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile2());
  p_oPlot = p_oSimManager->GetPlotObject();
  p_oClimateGrid = p_oSimManager->GetGridObject("State Variables");
  iTempCode = p_oClimateGrid->GetFloatDataCode("Temp.C");
  iPrecipCode = p_oClimateGrid->GetFloatDataCode("Precip.mm");

  //Initial conditions
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 1
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 2
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.09;
  fExpectedTemp = 8.06;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 3
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.36;
  fExpectedTemp = 8.12;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 4
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.81;
  fExpectedTemp = 8.18;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 5
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1001.44;
  fExpectedTemp = 8.24;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun3()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::TestNormalProcessingRun3(clSimManager *p_oSimManager)
{
  clPlot *p_oPlot;
  clGridBase *p_oClimateGrid;
  float fActualTemp, fExpectedTemp, fActualPrecip, fExpectedPrecip;
  int iTempCode, iPrecipCode;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile3());
  p_oPlot = p_oSimManager->GetPlotObject();
  p_oClimateGrid = p_oSimManager->GetGridObject("State Variables");
  iTempCode = p_oClimateGrid->GetFloatDataCode("Temp.C");
  iPrecipCode = p_oClimateGrid->GetFloatDataCode("Precip.mm");

  //Initial conditions
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 1
  p_oSimManager->RunSim(1);
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 2
  p_oSimManager->RunSim(1);
  fExpectedTemp = 8.02;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 3
  p_oSimManager->RunSim(1);
  fExpectedTemp = 8.04;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 4
  p_oSimManager->RunSim(1);
  fExpectedTemp = 8.06;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 5
  p_oSimManager->RunSim(1);
  fExpectedTemp = 8.08;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun4()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::TestNormalProcessingRun4(clSimManager *p_oSimManager)
{
  clPlot *p_oPlot;
  clGridBase *p_oClimateGrid;
  float fActualTemp, fExpectedTemp, fActualPrecip, fExpectedPrecip;
  int iTempCode, iPrecipCode;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile4());
  p_oPlot = p_oSimManager->GetPlotObject();
  p_oClimateGrid = p_oSimManager->GetGridObject("State Variables");
  iTempCode = p_oClimateGrid->GetFloatDataCode("Temp.C");
  iPrecipCode = p_oClimateGrid->GetFloatDataCode("Precip.mm");

  //Initial conditions
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 1
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 2
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.01;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 3
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.04;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 4
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.09;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 5
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000.16;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun5()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::TestNormalProcessingRun5(clSimManager *p_oSimManager)
{
  clPlot *p_oPlot;
  clGridBase *p_oClimateGrid;
  float fActualTemp, fExpectedTemp, fActualPrecip, fExpectedPrecip;
  int iTempCode, iPrecipCode;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile5());
  p_oPlot = p_oSimManager->GetPlotObject();
  p_oClimateGrid = p_oSimManager->GetGridObject("State Variables");
  iTempCode = p_oClimateGrid->GetFloatDataCode("Temp.C");
  iPrecipCode = p_oClimateGrid->GetFloatDataCode("Precip.mm");

  //Initial conditions
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 1
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 2
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1010;
  fExpectedTemp = 8.4;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 3
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1040;
  fExpectedTemp = 9.13137085;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 4
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1090;
  fExpectedTemp = 10.07846097;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 5
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1160;
  fExpectedTemp = 11.2;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 6
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1210;
  fExpectedTemp = 12;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 7
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1210;
  fExpectedTemp = 12;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 8
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1210;
  fExpectedTemp = 12;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 9
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1210;
  fExpectedTemp = 12;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun6()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::TestNormalProcessingRun6(clSimManager *p_oSimManager)
{
  clPlot *p_oPlot;
  clGridBase *p_oClimateGrid;
  float fActualTemp, fExpectedTemp, fActualPrecip, fExpectedPrecip;
  int iTempCode, iPrecipCode;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile6());
  p_oPlot = p_oSimManager->GetPlotObject();
  p_oClimateGrid = p_oSimManager->GetGridObject("State Variables");
  iTempCode = p_oClimateGrid->GetFloatDataCode("Temp.C");
  iPrecipCode = p_oClimateGrid->GetFloatDataCode("Precip.mm");

  //Initial conditions
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 1
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 1000;
  fExpectedTemp = 8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 2
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 990;
  fExpectedTemp = 7.8;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 3
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 960;
  fExpectedTemp = 7.434315;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 4
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 910;
  fExpectedTemp = 7;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 5
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 900;
  fExpectedTemp = 7;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

  //Timestep 6
  p_oSimManager->RunSim(1);
  fExpectedPrecip = 900;
  fExpectedTemp = 7;
  fActualPrecip = p_oPlot->GetMeanAnnualPrecip();
  fActualTemp = p_oPlot->GetMeanAnnualTemp();
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);
  p_oClimateGrid->GetValueOfCell(0, 0, iTempCode, &fActualTemp);
  p_oClimateGrid->GetValueOfCell(0, 0, iPrecipCode, &fActualPrecip);
  CPPUNIT_ASSERT(fabs(fExpectedPrecip - fActualPrecip) < 0.000001);
  CPPUNIT_ASSERT(fabs(fExpectedTemp - fActualTemp) < 0.000001);

}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestClimateChange::WriteXMLFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open( cFileString, ios::out | ios::trunc );

  WriteCommonStuff(oOut, 1);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Temperature climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Precipitation climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>State Reporter</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "</behaviorList>"
       << "<stateChange>"
       << "<sc_climateChangePrecipB>0.01</sc_climateChangePrecipB>"
       << "<sc_climateChangePrecipC>2</sc_climateChangePrecipC>"
       << "<sc_climateChangeMinPrecip>900</sc_climateChangeMinPrecip>"
       << "<sc_climateChangeMaxPrecip>2000</sc_climateChangeMaxPrecip>"
       << "<sc_climateChangeTempB>0.02</sc_climateChangeTempB>"
       << "<sc_climateChangeTempC>1</sc_climateChangeTempC>"
       << "<sc_climateChangeMinTemp>0</sc_climateChangeMinTemp>"
       << "<sc_climateChangeMaxTemp>10</sc_climateChangeMaxTemp>"
       << "</stateChange>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestClimateChange::WriteXMLFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open( cFileString, ios::out | ios::trunc );

  WriteCommonStuff(oOut, 3);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Temperature climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Precipitation climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>State Reporter</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "</behaviorList>"
       << "<stateChange>"
       << "<sc_climateChangePrecipB>0.01</sc_climateChangePrecipB>"
       << "<sc_climateChangePrecipC>2</sc_climateChangePrecipC>"
       << "<sc_climateChangeMinPrecip>900</sc_climateChangeMinPrecip>"
       << "<sc_climateChangeMaxPrecip>2000</sc_climateChangeMaxPrecip>"
       << "<sc_climateChangeTempB>0.02</sc_climateChangeTempB>"
       << "<sc_climateChangeTempC>1</sc_climateChangeTempC>"
       << "<sc_climateChangeMinTemp>0</sc_climateChangeMinTemp>"
       << "<sc_climateChangeMaxTemp>10</sc_climateChangeMaxTemp>"
       << "</stateChange>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestClimateChange::WriteXMLFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open( cFileString, ios::out | ios::trunc );

  WriteCommonStuff(oOut, 1);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Temperature climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>State Reporter</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "</behaviorList>"
       << "<stateChange>"
       << "<sc_climateChangeTempB>0.02</sc_climateChangeTempB>"
       << "<sc_climateChangeTempC>1</sc_climateChangeTempC>"
       << "<sc_climateChangeMinTemp>0</sc_climateChangeMinTemp>"
       << "<sc_climateChangeMaxTemp>10</sc_climateChangeMaxTemp>"
       << "</stateChange>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestClimateChange::WriteXMLFile4()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open( cFileString, ios::out | ios::trunc );

  WriteCommonStuff(oOut, 1);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Precipitation climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>State Reporter</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "</behaviorList>"
       << "<stateChange>"
       << "<sc_climateChangePrecipB>0.01</sc_climateChangePrecipB>"
       << "<sc_climateChangePrecipC>2</sc_climateChangePrecipC>"
       << "<sc_climateChangeMinPrecip>900</sc_climateChangeMinPrecip>"
       << "<sc_climateChangeMaxPrecip>2000</sc_climateChangeMaxPrecip>"
       << "</stateChange>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestClimateChange::WriteXMLFile5()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open( cFileString, ios::out | ios::trunc );

  WriteCommonStuff(oOut, 1);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Temperature climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Precipitation climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>State Reporter</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "</behaviorList>"
       << "<stateChange>"
       << "<sc_climateChangePrecipB>10</sc_climateChangePrecipB>"
       << "<sc_climateChangePrecipC>2</sc_climateChangePrecipC>"
       << "<sc_climateChangeMinPrecip>900</sc_climateChangeMinPrecip>"
       << "<sc_climateChangeMaxPrecip>1210</sc_climateChangeMaxPrecip>"
       << "<sc_climateChangeTempB>0.4</sc_climateChangeTempB>"
       << "<sc_climateChangeTempC>1.5</sc_climateChangeTempC>"
       << "<sc_climateChangeMinTemp>5</sc_climateChangeMinTemp>"
       << "<sc_climateChangeMaxTemp>12</sc_climateChangeMaxTemp>"
       << "</stateChange>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestClimateChange::WriteXMLFile6()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  std::fstream oOut;
  oOut.open( cFileString, ios::out | ios::trunc );

  WriteCommonStuff(oOut, 1);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Temperature climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Precipitation climate change</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>State Reporter</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "</behaviorList>"
       << "<stateChange>"
       << "<sc_climateChangePrecipB>-10</sc_climateChangePrecipB>"
       << "<sc_climateChangePrecipC>2</sc_climateChangePrecipC>"
       << "<sc_climateChangeMinPrecip>900</sc_climateChangeMinPrecip>"
       << "<sc_climateChangeMaxPrecip>1200</sc_climateChangeMaxPrecip>"
       << "<sc_climateChangeTempB>-0.2</sc_climateChangeTempB>"
       << "<sc_climateChangeTempC>1.5</sc_climateChangeTempC>"
       << "<sc_climateChangeMinTemp>7</sc_climateChangeMinTemp>"
       << "<sc_climateChangeMaxTemp>10</sc_climateChangeMaxTemp>"
       << "</stateChange>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestClimateChange::WriteCommonStuff( std::fstream &oOut, int iNumYrsPerTS )
{
  using namespace std;
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>10</timesteps>"
       << "<yearsPerTimestep>" << iNumYrsPerTS << "</yearsPerTimestep>"
       << "<randomSeed>0</randomSeed>"
       << "<plot_lenX>100</plot_lenX>"
       << "<plot_lenY>100</plot_lenY>"
       << "<plot_precip_mm_yr>1000</plot_precip_mm_yr>"
       << "<plot_temp_C>8</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  oOut << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";
}
