//---------------------------------------------------------------------------
// TestClimateChange
//---------------------------------------------------------------------------
#if !defined(TestClimateChange_H)
#define TestClimateChange_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clClimateChange class.
*/
class clTestClimateChange : public CppUnit::TestFixture
{

  public:

  /**
  * Rolls together all the tests into one function.
  */
  void TestClimateChange();

  private:

  /**
  * Tests normal processing for a 1-year timestep.
  * WriteXMLFile1() does setup.
  * @param p_oSimManager Sim Manager to do runs.
  */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Tests normal processing for a 3-year timestep.
  * WriteXMLFile2() does setup.
  * @param p_oSimManager Sim Manager to do runs.
  */
  void TestNormalProcessingRun2(clSimManager *p_oSimManager);

  /**
  * Tests normal processing for a 1-year timestep, only temperature.
  * WriteXMLFile3() does setup.
  * @param p_oSimManager Sim Manager to do runs.
  */
  void TestNormalProcessingRun3(clSimManager *p_oSimManager);

  /**
  * Tests normal processing for a 1-year timestep, only precipitation.
  * WriteXMLFile4() does setup.
  * @param p_oSimManager Sim Manager to do runs.
  */
  void TestNormalProcessingRun4(clSimManager *p_oSimManager);

  /**
  * Tests normal processing for a 1-year timestep.
  * WriteXMLFile5() does setup.
  * @param p_oSimManager Sim Manager to do runs.
  */
  void TestNormalProcessingRun5(clSimManager *p_oSimManager);

  /**
  * Tests normal processing for a 1-year timestep.
  * WriteXMLFile6() does setup.
  * @param p_oSimManager Sim Manager to do runs.
  */
  void TestNormalProcessingRun6(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file for normal proceessing, run 1.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file for normal proceessing, run 2.
  * @return Filename written.
  */
  char * WriteXMLFile2();

  /**
  * Writes a parameter file for normal proceessing, run 3.
  * @return Filename written.
  */
  char * WriteXMLFile3();

  /**
  * Writes a parameter file for normal proceessing, run 4.
  * @return Filename written.
  */
  char * WriteXMLFile4();

  /**
  * Writes a parameter file for normal proceessing, run 5.
  * @return Filename written.
  */
  char * WriteXMLFile5();

  /**
  * Writes a parameter file for normal proceessing, run 6.
  * @return Filename written.
  */
  char * WriteXMLFile6();

    /**
  * Writes common portions of the test parameter files (allometry and tree
  * pop).
  * @param oOut File stream to write to.
  * @param iNumYrsPerTS Number of years per timestep.
  */
  void WriteCommonStuff(std::fstream &oOut, int iNumYrsPerTS);

};
//---------------------------------------------------------------------------
#endif // TestDensityLight_H
