//---------------------------------------------------------------------------
// TestDensitySelfThinningGompertz.h
//---------------------------------------------------------------------------
#if !defined(TestDensitySelfThinningGompertz_H)
  #define TestDensitySelfThinningGompertz_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests DensitySelfThinning.
*/
class clTestDensitySelfThinningGompertz : public CppUnit::TestFixture
{
  public:

  /**
  * Tests the Density Self Thinning behavior.  Tests both normal and error processing.
  */
  void TestDensitySelfThinningGompertz();

  protected:

  /**
  * Tests normal processing using WriteXMLFile1()
  */
  void TestNormalProcessingRun1 (clSimManager *p_oSimManager);

  /**
  * Tests normal processing using WriteXMLFile2()
  */
  void TestNormalProcessingRun2 (clSimManager *p_oSimManager);

  /**
  * Tests error processing by using each of the Error XML files and then checking to see if the correct error is triggered.
  */
  void TestErrorProcessing (clSimManager *p_oSimManager);

  /**
  * Writes a parameter file for normal processing run 1.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file for normal processing run 2.
  */
  char * WriteXMLFile2();

  /**
  * Writes a parameter file with a negative radius parameter.
  */
  char * WriteXMLErrorFile1();

  /**
  * Writes a parameter file with a negative minimum height parameter.
  */
  char * WriteXMLErrorFile2();

  /**
   * Writes allometry parameters common to all parameter files.
   * @param oOut
   */
  void WriteCommonStuff(std::fstream &oOut);


};
//---------------------------------------------------------------------------
#endif // TestDensitySelfThinningGompertz_H

