//---------------------------------------------------------------------------
// TestFoliarChemistry
//---------------------------------------------------------------------------
#if !defined(TestFoliarChemistry_H)
  #define TestFoliarChemistry_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;
class clTreePopulation;

/**
* Tests the class clFoliarChemistry.
*/
class clTestFoliarChemistry : public CppUnit::TestFixture {

  public:

  /**
  * Performs all the tests from one function.
  */
  void TestFoliarChemistry();

  protected:

  /**
   * Tests normal processing, run 1.  This uses WriteXMLFile1() to do setup.
   * @param p_oSimManager Sim Manager object to call for runs.
   */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);

  /**
   * Tests normal processing, run 2.  This uses WriteXMLFile2() to do setup.
   * @param p_oSimManager Sim Manager object to call for runs.
   */
  void TestNormalProcessingRun2(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  This uses WriteXMLErrorFileX() to introduce errors
  * and makes sure that they are caught.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes the parameter file for normal processing run 1.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes the parameter file for normal processing run 2.
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes an error file where the Foliar Chemistry behavior is applied to
  * seedlings.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
   * Creates the test tree set.
   * @param p_oPop Tree population object.
   */
  void CreateTrees(clTreePopulation *p_oPop);

  /**
  * Writes common beginning of the test parameter files, which is everything
  * after the grid settings.
  * @param oOut File stream to write to.
  */
  void WriteCommonFileBegin(std::fstream &oOut);

  /**
  * Writes common ending of the test parameter files, which is everything
  * after the grid settings.
  * @param oOut File stream to write to.
  */
  void WriteCommonFileEnd(std::fstream &oOut);
};
//---------------------------------------------------------------------------
#endif // TestFoliarChemistry_H
