//---------------------------------------------------------------------------
// TestFuncResponseSeedPredation.cpp
//---------------------------------------------------------------------------
#include "TestFuncResponseSeedPredation.h"
#include "SimManager.h"
#include "GridBase.h"
#include "FuncResponseSeedPredation.h"
#include <fstream>
#include <math.h>

/////////////////////////////////////////////////////////////////////////////
//  TestFuncResponseSeedPredation()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestFuncResponseSeedPredation()
{
  clSimManager * p_oSimManager = new clSimManager(3, 3, "");

  TestSeedPredationNormal(p_oSimManager);
  TestSetup1(p_oSimManager);
  TestSetup2(p_oSimManager);
  TestSetup3(p_oSimManager);
  TestDensities(p_oSimManager);
  TestSeedOfftake1(p_oSimManager);
  TestSeedOfftake2(p_oSimManager);
  TestSeedOfftake3(p_oSimManager);
  TestSeedOfftake4(p_oSimManager);

  TestErrorProcessing(p_oSimManager);

  delete p_oSimManager;
}


/////////////////////////////////////////////////////////////////////////////
//  TestDensities()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestDensities(clSimManager *p_oSimManager) {

  clGridBase *p_oPredatorGrid, *p_oSeedsGrid;
  float fPredNum1, //number of predators after timestep 1
        fPredNum2, //number of predators after timestep 2
        fNumSeeds = 51200000.0;

  //Read in the file with preservation of predator densities
  p_oSimManager->ReadFile(WriteXMLFile6());
  p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");
  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  //Set the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum1);
  //Reset the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum2);
  //Assert that they are at least 20% different
  CPPUNIT_ASSERT(fabs(fPredNum1 - fPredNum2)/fPredNum1 > 0.2);


  //Now repeat with no preservation of predator densities
  p_oSimManager->ReadFile(WriteXMLFile7());
  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");
  //Set the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum1);
  //Reset the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum2);
  //Assert that they are within 1%
  CPPUNIT_ASSERT(fabs(fPredNum1 - fPredNum2)/fPredNum1 < 0.01);
}


/////////////////////////////////////////////////////////////////////////////
//  TestSeedOfftake1()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSeedOfftake1(clSimManager *p_oSimManager) {

  clGridBase *p_oSeedsGrid;
  float fNumExpectedSeeds = 46724929.24,
        fSeed1Proportion = 0.25, fSeed2Proportion = 0.75,
        fNumActualSeeds,
        fSpecies1Seeds,
        fSpecies2Seeds,
        fSpecies3Seeds;

  p_oSimManager->ReadFile(WriteXMLFile8());
  p_oSimManager->RunSim(1);

  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), &fSpecies1Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_1"), &fSpecies2Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_2"), &fSpecies3Seeds);

  //Make sure the total is right - only species 1 and 2
  fNumActualSeeds = fSpecies1Seeds + fSpecies2Seeds;

  CPPUNIT_ASSERT(fabs(fNumExpectedSeeds - fNumActualSeeds)/fNumActualSeeds < 0.01);

  //Make sure that the species 3 level is right
  CPPUNIT_ASSERT(fabs(100000 - fSpecies3Seeds) < 1);

  //Make sure the proportions of species 1 and species 2 are right
  CPPUNIT_ASSERT(fabs((fNumExpectedSeeds * fSeed1Proportion) - fSpecies1Seeds)/fSpecies1Seeds < 0.01);
  CPPUNIT_ASSERT(fabs((fNumExpectedSeeds * fSeed2Proportion) - fSpecies2Seeds)/fSpecies2Seeds < 0.01);

}


/////////////////////////////////////////////////////////////////////////////
// TestSeedOfftake2()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSeedOfftake2(clSimManager *p_oSimManager) {
  clGridBase *p_oSeedsGrid;
  clBehaviorBase *p_oTemp;
  clFuncResponseSeedPredation *p_oPred;
  float fNumSp1ExpectedSeeds = 47623086.43,
        fNumSp2ExpectedSeeds = 51200000,
        fNumSp3ExpectedSeeds = 36000000,
        fExpectedOfftake = 0.077311856,
        fSpecies1Seeds,
        fSpecies2Seeds,
        fSpecies3Seeds,
        fOfftake;

  p_oSimManager->ReadFile(WriteXMLOfftakeTestFile2());
  p_oSimManager->RunSim(1);

  //Test seed totals
  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), &fSpecies1Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_1"), &fSpecies2Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_2"), &fSpecies3Seeds);

  CPPUNIT_ASSERT(fabs(fNumSp1ExpectedSeeds - fSpecies1Seeds) < 100);
  CPPUNIT_ASSERT(fabs(fNumSp2ExpectedSeeds - fSpecies2Seeds) < 2);
  CPPUNIT_ASSERT(fabs(fNumSp3ExpectedSeeds - fSpecies3Seeds) < 2);

  //Test seed offtake rate
  p_oTemp = p_oSimManager->GetBehaviorObject("linked functional response seed predation");
  CPPUNIT_ASSERT(NULL != p_oTemp);
  p_oPred = dynamic_cast<clFuncResponseSeedPredation*>(p_oTemp);

  fOfftake = p_oPred->GetOfftakeRate();
  CPPUNIT_ASSERT(fabs(fExpectedOfftake - fOfftake)/fExpectedOfftake < 0.001);
}


/////////////////////////////////////////////////////////////////////////////
// TestSeedOfftake3()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSeedOfftake3(clSimManager *p_oSimManager) {

  clGridBase *p_oSeedsGrid;
  clBehaviorBase *p_oTemp;
  clFuncResponseSeedPredation *p_oPred;
  float fNumSp1ExpectedSeeds = 0,
        fNumSp2ExpectedSeeds = 100000,
        fNumSp3ExpectedSeeds = 100000,
        fExpectedOfftake = 0.596678234,
        fSpecies1Seeds,
        fSpecies2Seeds,
        fSpecies3Seeds,
        fOfftake;
  int iX, iY, iNumXCells, iNumYCells;

  p_oSimManager->ReadFile(WriteXMLOfftakeTestFile3());
  p_oSimManager->RunSim(1);

  //Test seed totals
  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  iNumXCells = p_oSeedsGrid->GetNumberXCells();
  iNumYCells = p_oSeedsGrid->GetNumberYCells();
  CPPUNIT_ASSERT(iNumXCells == 16);
  CPPUNIT_ASSERT(iNumYCells == 16);
  for (iX = 0; iX < iNumXCells; iX++) {
    for (iY = 0; iY < iNumYCells; iY++) {
      p_oSeedsGrid->GetValueOfCell(iX, iY, p_oSeedsGrid->GetFloatDataCode("seeds_0"), &fSpecies1Seeds);
      p_oSeedsGrid->GetValueOfCell(iX, iY, p_oSeedsGrid->GetFloatDataCode("seeds_1"), &fSpecies2Seeds);
      p_oSeedsGrid->GetValueOfCell(iX, iY, p_oSeedsGrid->GetFloatDataCode("seeds_2"), &fSpecies3Seeds);

      CPPUNIT_ASSERT(fNumSp1ExpectedSeeds == fSpecies1Seeds);
      CPPUNIT_ASSERT(fNumSp2ExpectedSeeds == fSpecies2Seeds);
      CPPUNIT_ASSERT(fNumSp3ExpectedSeeds == fSpecies3Seeds);
    }
  }

  //Test seed offtake rate
  p_oTemp = p_oSimManager->GetBehaviorObject("linked functional response seed predation");
  CPPUNIT_ASSERT(NULL != p_oTemp);
  p_oPred = dynamic_cast<clFuncResponseSeedPredation*>(p_oTemp);

  fOfftake = p_oPred->GetOfftakeRate();
  CPPUNIT_ASSERT(fabs(fExpectedOfftake - fOfftake)/fExpectedOfftake < 0.01);

  //Eliminate all seeds, run another timestep, and verify an updated offtake
  //rate
  fSpecies1Seeds = 0;
  for (iX = 0; iX < iNumXCells; iX++) {
    for (iY = 0; iY < iNumYCells; iY++) {
        p_oSeedsGrid->SetValueOfCell(iX, iY, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fSpecies1Seeds);
        p_oSeedsGrid->SetValueOfCell(iX, iY, p_oSeedsGrid->GetFloatDataCode("seeds_1"), fSpecies1Seeds);
        p_oSeedsGrid->SetValueOfCell(iX, iY, p_oSeedsGrid->GetFloatDataCode("seeds_2"), fSpecies1Seeds);
      }
    }
  p_oSimManager->RunSim(1);

  fOfftake = p_oPred->GetOfftakeRate();
  CPPUNIT_ASSERT(fOfftake >= 0 && fOfftake < 0.00001);
}

/////////////////////////////////////////////////////////////////////////////
// TestSeedOfftake4()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSeedOfftake4(clSimManager *p_oSimManager) {
  clGridBase *p_oSeedsGrid;
  float fNumSp1ExpectedSeeds = 24901578.21,
        fNumSp2ExpectedSeeds = 33799935.73,
        fNumSp3ExpectedSeeds = 36000000,
        fNumSp4ExpectedSeeds = 36778314.44,
        fSpecies1Seeds,
        fSpecies2Seeds,
        fSpecies3Seeds,
        fSpecies4Seeds;

  p_oSimManager->ReadFile(WriteXMLOfftakeTestFile4());
  p_oSimManager->RunSim(1);

  //Test seed totals
  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), &fSpecies1Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_1"), &fSpecies2Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_2"), &fSpecies3Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_3"), &fSpecies4Seeds);

  CPPUNIT_ASSERT(fabs(fNumSp1ExpectedSeeds - fSpecies1Seeds)/fNumSp1ExpectedSeeds < 0.001);
  CPPUNIT_ASSERT(fabs(fNumSp2ExpectedSeeds - fSpecies2Seeds)/fNumSp2ExpectedSeeds < 0.001);
  CPPUNIT_ASSERT(fabs(fNumSp3ExpectedSeeds - fSpecies3Seeds) < 2);
  CPPUNIT_ASSERT(fabs(fNumSp4ExpectedSeeds - fSpecies4Seeds)/fNumSp4ExpectedSeeds < 0.001);
}


/////////////////////////////////////////////////////////////////////////////
//  TestSetup1()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSetup1(clSimManager *p_oSimManager) {

  p_oSimManager->ReadFile(WriteXMLFile2());

  clGridBase *p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");

  //Make sure it has default resolution
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthXCells()) < 0.001);
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthYCells()) < 0.001);

  //Make sure the grid cells have the right value - should all be 30
  float fExpected = 30, fActual;
  int iNumX = p_oPredatorGrid->GetNumberXCells(),
      iNumY = p_oPredatorGrid->GetNumberYCells(),
      iNumCode = p_oPredatorGrid->GetFloatDataCode("num preds"),
      iX, iY;

  for (iX = 0; iX < iNumX; iX++) {
    for (iY = 0; iY < iNumY; iY++) {
      p_oPredatorGrid->GetValueOfCell(iX, iY, iNumCode, &fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpected) < 0.001);
    }
  }
}


/////////////////////////////////////////////////////////////////////////////
//  TestSetup2()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSetup2(clSimManager *p_oSimManager) {

  p_oSimManager->ReadFile(WriteXMLFile3());

  clGridBase *p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");

  //Make sure it has default resolution
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthXCells()) < 0.001);
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthYCells()) < 0.001);

  //Make sure the grid cells have the right value - should all be 30
  float fExpected = 0, fActual;
  int iNumX = p_oPredatorGrid->GetNumberXCells(),
      iNumY = p_oPredatorGrid->GetNumberYCells(),
      iNumCode = p_oPredatorGrid->GetFloatDataCode("num preds"),
      iX, iY;

  for (iX = 0; iX < iNumX; iX++) {
    for (iY = 0; iY < iNumY; iY++) {
      p_oPredatorGrid->GetValueOfCell(iX, iY, iNumCode, &fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpected) < 0.001);
    }
  }
}


/////////////////////////////////////////////////////////////////////////////
//  TestSetup3()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSetup3(clSimManager *p_oSimManager) {

  p_oSimManager->ReadFile(WriteXMLFile4());

  clGridBase *p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");

  //Make sure it has default resolution
  CPPUNIT_ASSERT(fabs(2 - p_oPredatorGrid->GetLengthXCells()) < 0.001);
  CPPUNIT_ASSERT(fabs(4 - p_oPredatorGrid->GetLengthYCells()) < 0.001);

  //Make sure the grid cells have the right value - should all be 30
  float fExpected, fActual;
  int iNumX = p_oPredatorGrid->GetNumberXCells(),
      iNumY = p_oPredatorGrid->GetNumberYCells(),
      iNumCode = p_oPredatorGrid->GetFloatDataCode("num preds"),
      iX, iY;

  for (iX = 0; iX < iNumX; iX++) {
    for (iY = 0; iY < iNumY; iY++) {
      fExpected = iX + iY;
      p_oPredatorGrid->GetValueOfCell(iX, iY, iNumCode, &fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpected) < 0.001);
    }
  }
}


/////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestErrorProcessing(clSimManager *p_oSimManager)
{

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile4.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile4.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile5.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile5.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile6());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile6.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile6.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile7());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile7.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile7.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile8());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile8.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile8.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile9());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile9.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile9.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile10());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile10.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile10.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile11());
    CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing didn't catch error for WriteXMLErrorFile11.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestFuncResponseSeedPredation error processing caught wrong error for WriteXMLErrorFile11.");
    }
    ;
  }
}


/////////////////////////////////////////////////////////////////////////////
//  TestSeedPredationNormal()
/////////////////////////////////////////////////////////////////////////////
void clTestFuncResponseSeedPredation::TestSeedPredationNormal(clSimManager *p_oSimManager)
{
  clGridBase *p_oSeedsGrid;
  float fNumExpectedSeeds = 46724931.74,
        fNumActualSeeds;
  p_oSimManager->ReadFile(WriteXMLFile1());
  p_oSimManager->RunSim(1);

  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), &fNumActualSeeds);

  CPPUNIT_ASSERT(fabs(fNumExpectedSeeds - fNumActualSeeds) < 100);

}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"


       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "</ma_v>";



/*       << "<ma_lengthXCells>10</ma_lengthXCells>"
       << "<ma_lengthYCells>10</ma_lengthYCells>";
       for (iX = 0; iX < 16; iX++) {
         for (iY = 0; iY < 16; iY++) {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << fSeedsPerCell << "</fl>"
           << "</ma_v>";
         }
       }
*/

/*       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>2</ma_lengthYCells>";
       for (iX = 0; iX < 80; iX++) {
         for (iY = 0; iY < 80; iY++) {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << fSeedsPerCell << "</fl>"
           << "</ma_v>";
         }
       }
*/


  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespWeekSeason2Starts>52</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.46875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>1</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>1</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLFile4()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"num preds\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>";
       for (iX = 0; iX < 80; iX++)
       {
         for (iY = 0; iY < 40; iY++)
         {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << (float)(iX + iY) << "</fl>"
           << "</ma_v>";
         }
       }
  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>1</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLFile6()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>32</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>1</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile7()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLFile7()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>32</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile8()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLFile8()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  float fTotalSeeds = 51200000.0,
        fSeed1Proportion = 0.25, fSeed2Proportion = 0.75,
        fSpecieslSeeds = fTotalSeeds * fSeed1Proportion,
        fSpecies2Seeds = fTotalSeeds * fSeed2Proportion;

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_2\">2</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">" << fSpecieslSeeds << "</fl>"
       << "<fl c=\"1\">" << fSpecies2Seeds << "</fl>"
       << "<fl c=\"2\">100000</fl>"
       << "</ma_v>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "<pr_frmirVal species=\"Species_2\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "<pr_frfeVal species=\"Species_2\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "<pr_funcRespOutputFilename>TestOfftake1.txt</pr_funcRespOutputFilename>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
// WriteXMLOfftakeTestFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLOfftakeTestFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_2\">2</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"

       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "<fl c=\"1\">51200000</fl>"
       << "<fl c=\"2\">36000000</fl>"
       << "</ma_v>";

  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>linked functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>35</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "<pr_funcRespPredatorInitialDensityLnk>0.002</pr_funcRespPredatorInitialDensityLnk>"
       << "<pr_funcRespMaxInstDeclineRate1Lnk>-0.04</pr_funcRespMaxInstDeclineRate1Lnk>"
       << "<pr_funcRespMaxInstDeclineRate2Lnk>-0.04</pr_funcRespMaxInstDeclineRate2Lnk>"
       << "<pr_funcRespDemographicEfficiency1Lnk>0.0002</pr_funcRespDemographicEfficiency1Lnk>"
       << "<pr_funcRespDemographicEfficiency2Lnk>0.0002</pr_funcRespDemographicEfficiency2Lnk>"
       << "<pr_funcRespDensityDependentCoefficient1Lnk>-0.008</pr_funcRespDensityDependentCoefficient1Lnk>"
       << "<pr_funcRespDensityDependentCoefficient2Lnk>-0.008</pr_funcRespDensityDependentCoefficient2Lnk>"
       << "<pr_funcRespMaxIntakeRateLnk>"
       << "<pr_frmirlVal species=\"Species_3\">300</pr_frmirlVal>"
       << "</pr_funcRespMaxIntakeRateLnk>"
       << "<pr_funcRespForagingEfficiencyLnk>"
       << "<pr_frfelVal species=\"Species_3\">0.002</pr_frfelVal>"
       << "</pr_funcRespForagingEfficiencyLnk>"
       << "<pr_funcRespNumWeeksSeedFallLnk>7</pr_funcRespNumWeeksSeedFallLnk>"
       << "<pr_funcRespNumWeeksToModelLnk>30</pr_funcRespNumWeeksToModelLnk>"
       << "<pr_funcRespWeekSeason2StartsLnk>12</pr_funcRespWeekSeason2StartsLnk>"
       << "<pr_funcRespWeekGerminationStartsLnk>10</pr_funcRespWeekGerminationStartsLnk>"
       << "<pr_funcRespPreservePredatorDensitiesLnk>0</pr_funcRespPreservePredatorDensitiesLnk>"
       << "<pr_funcRespProportionGerminatingLnk>0.1</pr_funcRespProportionGerminatingLnk>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
// WriteXMLOfftakeTestFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLOfftakeTestFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_2\">2</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>10</ma_lengthXCells>"
       << "<ma_lengthYCells>10</ma_lengthYCells>";
       for (iX = 0; iX < 16; iX++) {
         for (iY = 0; iY < 16; iY++) {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
                << "<fl c=\"1\">100000</fl>"
                << "<fl c=\"2\">100000</fl>"
                << "</ma_v>";
         }
       }

  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>linked functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensityLnk>0.002</pr_funcRespPredatorInitialDensityLnk>"
       << "<pr_funcRespMaxInstDeclineRate1Lnk>-0.04</pr_funcRespMaxInstDeclineRate1Lnk>"
       << "<pr_funcRespMaxInstDeclineRate2Lnk>-0.04</pr_funcRespMaxInstDeclineRate2Lnk>"
       << "<pr_funcRespDemographicEfficiency1Lnk>0.0002</pr_funcRespDemographicEfficiency1Lnk>"
       << "<pr_funcRespDemographicEfficiency2Lnk>0.0002</pr_funcRespDemographicEfficiency2Lnk>"
       << "<pr_funcRespDensityDependentCoefficient1Lnk>-0.008</pr_funcRespDensityDependentCoefficient1Lnk>"
       << "<pr_funcRespDensityDependentCoefficient2Lnk>-0.008</pr_funcRespDensityDependentCoefficient2Lnk>"
       << "<pr_funcRespMaxIntakeRateLnk>"
       << "<pr_frmirlVal species=\"Species_2\">2000</pr_frmirlVal>"
       << "<pr_frmirlVal species=\"Species_3\">2000</pr_frmirlVal>"
       << "</pr_funcRespMaxIntakeRateLnk>"
       << "<pr_funcRespForagingEfficiencyLnk>"
       << "<pr_frfelVal species=\"Species_2\">0.002</pr_frfelVal>"
       << "<pr_frfelVal species=\"Species_3\">0.002</pr_frfelVal>"
       << "</pr_funcRespForagingEfficiencyLnk>"
       << "<pr_funcRespNumWeeksSeedFallLnk>12</pr_funcRespNumWeeksSeedFallLnk>"
       << "<pr_funcRespNumWeeksToModelLnk>45</pr_funcRespNumWeeksToModelLnk>"
       << "<pr_funcRespWeekSeason2StartsLnk>12</pr_funcRespWeekSeason2StartsLnk>"
       << "<pr_funcRespWeekGerminationStartsLnk>30</pr_funcRespWeekGerminationStartsLnk>"
       << "<pr_funcRespPreservePredatorDensitiesLnk>0</pr_funcRespPreservePredatorDensitiesLnk>"
       << "<pr_funcRespProportionGerminatingLnk>0.4</pr_funcRespProportionGerminatingLnk>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
// WriteXMLOfftakeTestFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLOfftakeTestFile4()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "<tr_species speciesName=\"Species_4\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_2\">2</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_3\">3</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "<fl c=\"1\">102400000</fl>"
       << "<fl c=\"2\">36000000</fl>"
       << "<fl c=\"3\">153600000</fl>"
       << "</ma_v>";

  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.002</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.1749</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>0.549</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.00179</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.024</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.1566</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.0258</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">666.67</pr_frmirVal>"
       << "<pr_frmirVal species=\"Species_2\">1042</pr_frmirVal>"
       << "<pr_frmirVal species=\"Species_4\">1378</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.002</pr_frfeVal>"
       << "<pr_frfeVal species=\"Species_2\">0.00139</pr_frfeVal>"
       << "<pr_frfeVal species=\"Species_4\">0.00105</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespWeekSeason2Starts>20</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>30</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.4</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.1</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"num preds\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>4</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>";
       for (iX = 0; iX < 40; iX++)
       {
         for (iY = 0; iY < 40; iY++)
         {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << (float)(iX + iY) << "</fl>"
           << "</ma_v>";
         }
       }
  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.1</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>1</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile4()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.1</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>0</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile5()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.1</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>0</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile6()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"num preds\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>2</ma_lengthYCells>";
       for (iX = 0; iX < 80; iX++)
       {
         for (iY = 0; iY < 80; iY++)
         {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << (float)(iX + iY) << "</fl>"
           << "</ma_v>";
         }
       }
  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.1</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>1</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile7()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile7()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"num preds\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.1</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">7295.4</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>1</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile8()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile8()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "</ma_v>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>-32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile9()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile9()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "</ma_v>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>53</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>0.35</pr_funcRespProportionGerminating>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile10()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile10()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "</ma_v>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>-0.35</pr_funcRespProportionGerminating>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile11()
/////////////////////////////////////////////////////////////////////////////
char * clTestFuncResponseSeedPredation::WriteXMLErrorFile11()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "</ma_v>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_funcRespPredatorInitialDensity>0.00046875</pr_funcRespPredatorInitialDensity>"
       << "<pr_funcRespMaxInstDeclineRate1>-0.050622442</pr_funcRespMaxInstDeclineRate1>"
       << "<pr_funcRespMaxInstDeclineRate2>-0.050622442</pr_funcRespMaxInstDeclineRate2>"
       << "<pr_funcRespDemographicEfficiency1>0.000154258</pr_funcRespDemographicEfficiency1>"
       << "<pr_funcRespDemographicEfficiency2>0.000154258</pr_funcRespDemographicEfficiency2>"
       << "<pr_funcRespDensityDependentCoefficient1>-0.000718667</pr_funcRespDensityDependentCoefficient1>"
       << "<pr_funcRespDensityDependentCoefficient2>-0.000718667</pr_funcRespDensityDependentCoefficient2>"
       << "<pr_funcRespMaxIntakeRate>"
       << "<pr_frmirVal species=\"Species_1\">1042.2</pr_frmirVal>"
       << "</pr_funcRespMaxIntakeRate>"
       << "<pr_funcRespForagingEfficiency>"
       << "<pr_frfeVal species=\"Species_1\">0.001389</pr_frfeVal>"
       << "</pr_funcRespForagingEfficiency>"
       << "<pr_funcRespWeekSeason2Starts>12</pr_funcRespWeekSeason2Starts>"
       << "<pr_funcRespNumWeeksSeedFall>12</pr_funcRespNumWeeksSeedFall>"
       << "<pr_funcRespNumWeeksToModel>52</pr_funcRespNumWeeksToModel>"
       << "<pr_funcRespWeekGerminationStarts>32</pr_funcRespWeekGerminationStarts>"
       << "<pr_funcRespPreservePredatorDensities>0</pr_funcRespPreservePredatorDensities>"
       << "<pr_funcRespProportionGerminating>1.35</pr_funcRespProportionGerminating>"
       << "<pr_funcRespOutputFilename>TestSeeds.txt</pr_funcRespOutputFilename>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

