//---------------------------------------------------------------------------
// TestGeneralizedHarvestRegime.cpp
//---------------------------------------------------------------------------
#include "TestGeneralizedHarvestRegime.h"
#include <fstream>
#include <math.h>
#include "TreePopulation.h"
#include "SimManager.h"
#include "BehaviorBase.h"

////////////////////////////////////////////////////////////////////////////
//  TestGeneralizedHarvestRegime()
////////////////////////////////////////////////////////////////////////////
void clTestGeneralizedHarvestRegime::TestGeneralizedHarvestRegime() {
  clSimManager *p_oSimManager = new clSimManager(4, 2, "");

  //TestRun1(p_oSimManager);
  //TestRun2(p_oSimManager);
  TestRun3(p_oSimManager);
  TestRun4(p_oSimManager);

  delete p_oSimManager;
}

////////////////////////////////////////////////////////////////////////////
//  TestRun1()
////////////////////////////////////////////////////////////////////////////
void clTestGeneralizedHarvestRegime::TestRun1(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  int iNumRuns = 1000,
      iCutRuns = 0, iNoCutRuns = 0, iNumTrees, i;

  for (i = 0; i < iNumRuns; i++) {
    //Load our test file and get our tree population pointers
    p_oSimManager->ReadFile( WriteXMLFileSet1(50) );
    p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

    p_oSimManager->RunSim(1);

    //See if we got any adults this run
    p_oAllTrees = p_oPop->Find("type=3");
    p_oTree = p_oAllTrees->NextTree();
    if (p_oTree) iNoCutRuns++;
    else iCutRuns++;

    if (p_oTree) {
      iNumTrees = 0;
      while (p_oTree) {
        iNumTrees++;
        p_oTree = p_oAllTrees->NextTree();
      }
      CPPUNIT_ASSERT(100 == iNumTrees);
    }

    //Make sure saplings were untouched
    p_oAllTrees = p_oPop->Find("type=2");
    p_oTree = p_oAllTrees->NextTree();
    iNumTrees = 0;
    while (p_oTree) {
      iNumTrees++;
      p_oTree = p_oAllTrees->NextTree();
    }
    CPPUNIT_ASSERT(50 == iNumTrees);
  }

  CPPUNIT_ASSERT(abs(iCutRuns - 788) < 100);
  CPPUNIT_ASSERT(abs(iNoCutRuns - (iNumRuns - 788)) < 100);
}

////////////////////////////////////////////////////////////////////////////
//  TestRun2()
////////////////////////////////////////////////////////////////////////////
void clTestGeneralizedHarvestRegime::TestRun2(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  int iNumRuns = 1000,
      iCutRuns = 0, iNoCutRuns = 0, iNumTrees, i;

  for (i = 0; i < iNumRuns; i++) {
    //Load our test file and get our tree population pointers
    p_oSimManager->ReadFile( WriteXMLFileSet1(100) );
    p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

    p_oSimManager->RunSim(1);

    //See if we got any adults this run
    p_oAllTrees = p_oPop->Find("type=3");
    p_oTree = p_oAllTrees->NextTree();
    if (p_oTree) iNoCutRuns++;
    else iCutRuns++;

    if (p_oTree) {
      iNumTrees = 0;
      while (p_oTree) {
        iNumTrees++;
        p_oTree = p_oAllTrees->NextTree();
      }
      CPPUNIT_ASSERT(200 == iNumTrees);
    }

    //Make sure saplings were untouched
    p_oAllTrees = p_oPop->Find("type=2");
    CPPUNIT_ASSERT(p_oAllTrees->NextTree());
  }

  CPPUNIT_ASSERT(abs(iCutRuns - 938) < 50);
  CPPUNIT_ASSERT(abs(iNoCutRuns - (iNumRuns - 938)) < 50);
}

////////////////////////////////////////////////////////////////////////////
//  TestRun3()
////////////////////////////////////////////////////////////////////////////
void clTestGeneralizedHarvestRegime::TestRun3(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fBA = 0, fPostCutBA = 0, fDBH;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile3() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  p_oAllTrees = p_oPop->Find("type=3");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDBH);
    fBA += clModelMath::CalculateBasalArea(fDBH);
    p_oTree = p_oAllTrees->NextTree();
  }

  p_oSimManager->RunSim(1);

  //See if we got any adults this run
  p_oAllTrees = p_oPop->Find("type=3");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDBH);
    fPostCutBA += clModelMath::CalculateBasalArea(fDBH);
    p_oTree = p_oAllTrees->NextTree();
  }

  CPPUNIT_ASSERT(fabs((fPostCutBA / fBA) - (1-0.71627)) < 0.5);
}

////////////////////////////////////////////////////////////////////////////
//  TestRun4()
////////////////////////////////////////////////////////////////////////////
void clTestGeneralizedHarvestRegime::TestRun4(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fBA = 0, fPostCutBA = 0, fDBH;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile4() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  p_oAllTrees = p_oPop->Find("type=3");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDBH);
    fBA += clModelMath::CalculateBasalArea(fDBH);
    p_oTree = p_oAllTrees->NextTree();
  }

  p_oSimManager->RunSim(1);

  //See if we got any adults this run
  p_oAllTrees = p_oPop->Find("type=3");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDBH);
    fPostCutBA += clModelMath::CalculateBasalArea(fDBH);
    p_oTree = p_oAllTrees->NextTree();
  }

  CPPUNIT_ASSERT(fabs((fPostCutBA / fBA) - (1-0.12567)) < 0.5);
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFileSet1()
////////////////////////////////////////////////////////////////////////////
char* clTestGeneralizedHarvestRegime::WriteXMLFileSet1(int iNumTreesPerSpecies) {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>0</randomSeed>"
       << "<plot_lenX>80.0</plot_lenX>"
       << "<plot_lenY>80.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "<tr_treemap>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"" << clTreePopulation::adult << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"" << clTreePopulation::sapling << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_2\" tp=\"" << clTreePopulation::adult << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>";

  for (int i = 0; i < iNumTreesPerSpecies; i++) {
    oOut << "<tree sp=\"0\" tp=\"" << clTreePopulation::adult << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"2\">" << (clModelMath::GetRand() * 50) + 10 << "</fl>"
         << "</tree>";
  }
  for (int i = 0; i < iNumTreesPerSpecies; i++) {
    oOut << "<tree sp=\"1\" tp=\"" << clTreePopulation::adult << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"2\">" << (clModelMath::GetRand() * 50) + 10 << "</fl>"
         << "</tree>";
  }
  for (int i = 0; i < iNumTreesPerSpecies; i++) {
    oOut << "<tree sp=\"0\" tp=\"" << clTreePopulation::sapling << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"2\">" << clModelMath::GetRand() * 8 + 1 << "</fl>"
         << "</tree>";
  }
  oOut << "</tr_treemap>"
       << "</trees>"
       << "<allometry>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightDiam>"
       << "<tr_wachdVal species=\"Species_1\">0</tr_wachdVal>"
       << "<tr_wachdVal species=\"Species_2\">0</tr_wachdVal>"
       << "</tr_whatAdultCrownHeightDiam>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightDiam>"
       << "<tr_wschdVal species=\"Species_1\">0</tr_wschdVal>"
       << "<tr_wschdVal species=\"Species_2\">0</tr_wschdVal>"
       << "</tr_whatSaplingCrownHeightDiam>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0614</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.368</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.0269</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Generalized Harvest Regime</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>tree biomass calculator</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>";
  oOut << "<disturbanceOther>"
       << "<di_genHarvLogProbA>65.51</di_genHarvLogProbA>"
       << "<di_genHarvLogProbM>1.38</di_genHarvLogProbM>"
       << "<di_genHarvLogProbB>0.282</di_genHarvLogProbB>"
       << "<di_genHarvLogRemoveAlpha>200</di_genHarvLogRemoveAlpha>"
       << "<di_genHarvLogRemoveMu>0</di_genHarvLogRemoveMu>"
       << "<di_genHarvGammaScale>0.000001</di_genHarvGammaScale>"
       << "<di_genHarvAllowedDeviation>0</di_genHarvAllowedDeviation>"
       << "<di_genHarvLogCutProbAlpha>"
       << "<di_ghlcpaVal species=\"Species_1\">1.748758</di_ghlcpaVal>"
       << "<di_ghlcpaVal species=\"Species_2\">1.853409</di_ghlcpaVal>"
       << "</di_genHarvLogCutProbAlpha>"
       << "<di_genHarvLogCutProbBeta>"
       << "<di_ghlcpbVal species=\"Species_1\">0.001083513</di_ghlcpbVal>"
       << "<di_ghlcpbVal species=\"Species_2\">0.001018502</di_ghlcpbVal>"
       << "</di_genHarvLogCutProbBeta>"
       << "<di_genHarvLogCutProbGamma>"
       << "<di_ghlcpgVal species=\"Species_1\">1</di_ghlcpgVal>"
       << "<di_ghlcpgVal species=\"Species_2\">0.9468814</di_ghlcpgVal>"
       << "</di_genHarvLogCutProbGamma>"
       << "<di_genHarvLogCutProbMu>"
       << "<di_ghlcpmVal species=\"Species_1\">42.53707</di_ghlcpmVal>"
       << "<di_ghlcpmVal species=\"Species_2\">39.45325</di_ghlcpmVal>"
       << "</di_genHarvLogCutProbMu>"
       << "<di_genHarvLogCutProbA>21.2954</di_genHarvLogCutProbA>"
       << "<di_genHarvLogCutProbB>0.01202805</di_genHarvLogCutProbB>"
       << "<di_genHarvLogCutProbC>15.20595</di_genHarvLogCutProbC>"
       << "</disturbanceOther>";
  oOut << "<analysis>"
       << "<bi_a>"
       << "<bi_aVal species=\"Species_1\">1000</bi_aVal>"
       << "<bi_aVal species=\"Species_2\">1000</bi_aVal>"
       << "</bi_a>"
       << "<bi_b>"
       << "<bi_bVal species=\"Species_1\">0</bi_bVal>"
       << "<bi_bVal species=\"Species_2\">0</bi_bVal>"
       << "</bi_b>"
       << "<bi_c>"
       << "<bi_cVal species=\"Species_1\">0</bi_cVal>"
       << "<bi_cVal species=\"Species_2\">0</bi_cVal>"
       << "</bi_c>"
       << "<bi_d>"
       << "<bi_dVal species=\"Species_1\">1</bi_dVal>"
       << "<bi_dVal species=\"Species_2\">1</bi_dVal>"
       << "</bi_d>"
       << "<bi_e>"
       << "<bi_eVal species=\"Species_1\">0</bi_eVal>"
       << "<bi_eVal species=\"Species_2\">0</bi_eVal>"
       << "</bi_e>"
       << "<bi_eqID>"
       << "<bi_eiVal species=\"Species_1\">4</bi_eiVal>"
       << "<bi_eiVal species=\"Species_2\">4</bi_eiVal>"
       << "</bi_eqID>"
       << "<bi_dbhUnits>"
       << "<bi_duVal species=\"Species_1\">0</bi_duVal>"
       << "<bi_duVal species=\"Species_2\">1</bi_duVal>"
       << "</bi_dbhUnits>"
       << "<bi_biomassUnits>"
       << "<bi_buVal species=\"Species_1\">1</bi_buVal>"
       << "<bi_buVal species=\"Species_2\">1</bi_buVal>"
       << "</bi_biomassUnits>"
       << "<bi_useCorrectionFactor>"
       << "<bi_ucfVal species=\"Species_1\">0</bi_ucfVal>"
       << "<bi_ucfVal species=\"Species_2\">0</bi_ucfVal>"
       << "</bi_useCorrectionFactor>"
       << "<bi_correctionFactorValue>"
       << "<bi_cfvVal species=\"Species_1\">1</bi_cfvVal>"
       << "<bi_cfvVal species=\"Species_2\">1</bi_cfvVal>"
       << "</bi_correctionFactorValue>"
       << "<bi_whatDia>"
       << "<bi_wdVal species=\"Species_1\">0</bi_wdVal>"
       << "<bi_wdVal species=\"Species_2\">0</bi_wdVal>"
       << "</bi_whatDia>"
       << "</analysis>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestGeneralizedHarvestRegime::WriteXMLFile3() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>0</randomSeed>"
       << "<plot_lenX>80.0</plot_lenX>"
       << "<plot_lenY>80.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "<tr_treemap>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"" << clTreePopulation::adult << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"" << clTreePopulation::sapling << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_2\" tp=\"" << clTreePopulation::adult << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>";

  for (int i = 0; i < 50; i++) {
    oOut << "<tree sp=\"0\" tp=\"" << clTreePopulation::adult << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"2\">" << (clModelMath::GetRand() * 50) + 10 << "</fl>"
         << "</tree>";
  }
  for (int i = 0; i < 50; i++) {
    oOut << "<tree sp=\"1\" tp=\"" << clTreePopulation::adult << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"2\">" << (clModelMath::GetRand() * 50) + 10 << "</fl>"
         << "</tree>";
  }
  for (int i = 0; i < 50; i++) {
    oOut << "<tree sp=\"0\" tp=\"" << clTreePopulation::sapling << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 80 << "</fl>"
         << "<fl c=\"2\">" << clModelMath::GetRand() * 8 << "</fl>"
         << "</tree>";
  }
  oOut << "</tr_treemap>"
       << "</trees>"
       << "<allometry>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightDiam>"
       << "<tr_wachdVal species=\"Species_1\">0</tr_wachdVal>"
       << "<tr_wachdVal species=\"Species_2\">0</tr_wachdVal>"
       << "</tr_whatAdultCrownHeightDiam>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightDiam>"
       << "<tr_wschdVal species=\"Species_1\">0</tr_wschdVal>"
       << "<tr_wschdVal species=\"Species_2\">0</tr_wschdVal>"
       << "</tr_whatSaplingCrownHeightDiam>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0614</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.368</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.0269</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Generalized Harvest Regime</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>tree biomass calculator</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>";
  oOut << "<disturbanceOther>"
       << "<di_genHarvLogProbA>0</di_genHarvLogProbA>"
       << "<di_genHarvLogProbM>0</di_genHarvLogProbM>"
       << "<di_genHarvLogProbB>0.282</di_genHarvLogProbB>"
       << "<di_genHarvLogRemoveAlpha>99.6</di_genHarvLogRemoveAlpha>"
       << "<di_genHarvLogRemoveMu>0.00211</di_genHarvLogRemoveMu>"
       << "<di_genHarvGammaScale>0.000001</di_genHarvGammaScale>"
       << "<di_genHarvAllowedDeviation>0.1</di_genHarvAllowedDeviation>"
       << "<di_genHarvLogCutProbAlpha>"
       << "<di_ghlcpaVal species=\"Species_1\">1.748758</di_ghlcpaVal>"
       << "<di_ghlcpaVal species=\"Species_2\">1.853409</di_ghlcpaVal>"
       << "</di_genHarvLogCutProbAlpha>"
       << "<di_genHarvLogCutProbBeta>"
       << "<di_ghlcpbVal species=\"Species_1\">0.001083513</di_ghlcpbVal>"
       << "<di_ghlcpbVal species=\"Species_2\">0.001018502</di_ghlcpbVal>"
       << "</di_genHarvLogCutProbBeta>"
       << "<di_genHarvLogCutProbGamma>"
       << "<di_ghlcpgVal species=\"Species_1\">1</di_ghlcpgVal>"
       << "<di_ghlcpgVal species=\"Species_2\">0.9468814</di_ghlcpgVal>"
       << "</di_genHarvLogCutProbGamma>"
       << "<di_genHarvLogCutProbMu>"
       << "<di_ghlcpmVal species=\"Species_1\">42.53707</di_ghlcpmVal>"
       << "<di_ghlcpmVal species=\"Species_2\">39.45325</di_ghlcpmVal>"
       << "</di_genHarvLogCutProbMu>"
       << "<di_genHarvLogCutProbA>21.2954</di_genHarvLogCutProbA>"
       << "<di_genHarvLogCutProbB>0.01202805</di_genHarvLogCutProbB>"
       << "<di_genHarvLogCutProbC>15.20595</di_genHarvLogCutProbC>"
       << "</disturbanceOther>";
  oOut << "<analysis>"
       << "<bi_a>"
       << "<bi_aVal species=\"Species_1\">1000</bi_aVal>"
       << "<bi_aVal species=\"Species_2\">1000</bi_aVal>"
       << "</bi_a>"
       << "<bi_b>"
       << "<bi_bVal species=\"Species_1\">0</bi_bVal>"
       << "<bi_bVal species=\"Species_2\">0</bi_bVal>"
       << "</bi_b>"
       << "<bi_c>"
       << "<bi_cVal species=\"Species_1\">0</bi_cVal>"
       << "<bi_cVal species=\"Species_2\">0</bi_cVal>"
       << "</bi_c>"
       << "<bi_d>"
       << "<bi_dVal species=\"Species_1\">1</bi_dVal>"
       << "<bi_dVal species=\"Species_2\">1</bi_dVal>"
       << "</bi_d>"
       << "<bi_e>"
       << "<bi_eVal species=\"Species_1\">0</bi_eVal>"
       << "<bi_eVal species=\"Species_2\">0</bi_eVal>"
       << "</bi_e>"
       << "<bi_eqID>"
       << "<bi_eiVal species=\"Species_1\">4</bi_eiVal>"
       << "<bi_eiVal species=\"Species_2\">4</bi_eiVal>"
       << "</bi_eqID>"
       << "<bi_dbhUnits>"
       << "<bi_duVal species=\"Species_1\">0</bi_duVal>"
       << "<bi_duVal species=\"Species_2\">1</bi_duVal>"
       << "</bi_dbhUnits>"
       << "<bi_biomassUnits>"
       << "<bi_buVal species=\"Species_1\">1</bi_buVal>"
       << "<bi_buVal species=\"Species_2\">1</bi_buVal>"
       << "</bi_biomassUnits>"
       << "<bi_useCorrectionFactor>"
       << "<bi_ucfVal species=\"Species_1\">0</bi_ucfVal>"
       << "<bi_ucfVal species=\"Species_2\">0</bi_ucfVal>"
       << "</bi_useCorrectionFactor>"
       << "<bi_correctionFactorValue>"
       << "<bi_cfvVal species=\"Species_1\">1</bi_cfvVal>"
       << "<bi_cfvVal species=\"Species_2\">1</bi_cfvVal>"
       << "</bi_correctionFactorValue>"
       << "<bi_whatDia>"
       << "<bi_wdVal species=\"Species_1\">0</bi_wdVal>"
       << "<bi_wdVal species=\"Species_2\">0</bi_wdVal>"
       << "</bi_whatDia>"
       << "</analysis>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestGeneralizedHarvestRegime::WriteXMLFile4() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>0</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "<tr_treemap>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"" << clTreePopulation::adult << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"" << clTreePopulation::sapling << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_2\" tp=\"" << clTreePopulation::adult << "\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>";

  for (int i = 0; i < 100; i++) {
    oOut << "<tree sp=\"0\" tp=\"" << clTreePopulation::adult << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 200 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 200 << "</fl>"
         << "<fl c=\"2\">" << (clModelMath::GetRand() * 50) + 10 << "</fl>"
         << "</tree>";
  }
  for (int i = 0; i < 100; i++) {
    oOut << "<tree sp=\"1\" tp=\"" << clTreePopulation::adult << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 200 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 200 << "</fl>"
         << "<fl c=\"2\">" << (clModelMath::GetRand() * 50) + 10 << "</fl>"
         << "</tree>";
  }
  for (int i = 0; i < 50; i++) {
    oOut << "<tree sp=\"0\" tp=\"" << clTreePopulation::sapling << "\">"
         << "<fl c=\"0\">" << clModelMath::GetRand() * 200 << "</fl>"
         << "<fl c=\"1\">" << clModelMath::GetRand() * 200 << "</fl>"
         << "<fl c=\"2\">" << clModelMath::GetRand() * 8 << "</fl>"
         << "</tree>";
  }
  oOut << "</tr_treemap>"
       << "</trees>"
       << "<allometry>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightDiam>"
       << "<tr_wachdVal species=\"Species_1\">0</tr_wachdVal>"
       << "<tr_wachdVal species=\"Species_2\">0</tr_wachdVal>"
       << "</tr_whatAdultCrownHeightDiam>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightDiam>"
       << "<tr_wschdVal species=\"Species_1\">0</tr_wschdVal>"
       << "<tr_wschdVal species=\"Species_2\">0</tr_wschdVal>"
       << "</tr_whatSaplingCrownHeightDiam>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0614</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.368</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.0269</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Generalized Harvest Regime</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>tree biomass calculator</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>";
  oOut << "<disturbanceOther>"
       << "<di_genHarvLogProbA>0</di_genHarvLogProbA>"
       << "<di_genHarvLogProbM>0</di_genHarvLogProbM>"
       << "<di_genHarvLogProbB>0.282</di_genHarvLogProbB>"
       << "<di_genHarvLogRemoveAlpha>24.3</di_genHarvLogRemoveAlpha>"
       << "<di_genHarvLogRemoveMu>0.00211</di_genHarvLogRemoveMu>"
       << "<di_genHarvGammaScale>0.000001</di_genHarvGammaScale>"
       << "<di_genHarvAllowedDeviation>0.1</di_genHarvAllowedDeviation>"
       << "<di_genHarvLogCutProbAlpha>"
       << "<di_ghlcpaVal species=\"Species_1\">1.748758</di_ghlcpaVal>"
       << "<di_ghlcpaVal species=\"Species_2\">1.853409</di_ghlcpaVal>"
       << "</di_genHarvLogCutProbAlpha>"
       << "<di_genHarvLogCutProbBeta>"
       << "<di_ghlcpbVal species=\"Species_1\">0.001083513</di_ghlcpbVal>"
       << "<di_ghlcpbVal species=\"Species_2\">0.001018502</di_ghlcpbVal>"
       << "</di_genHarvLogCutProbBeta>"
       << "<di_genHarvLogCutProbGamma>"
       << "<di_ghlcpgVal species=\"Species_1\">1</di_ghlcpgVal>"
       << "<di_ghlcpgVal species=\"Species_2\">0.9468814</di_ghlcpgVal>"
       << "</di_genHarvLogCutProbGamma>"
       << "<di_genHarvLogCutProbMu>"
       << "<di_ghlcpmVal species=\"Species_1\">3.063641</di_ghlcpmVal>"
       << "<di_ghlcpmVal species=\"Species_2\">51.29938</di_ghlcpmVal>"
       << "</di_genHarvLogCutProbMu>"
       << "<di_genHarvLogCutProbA>65.51862</di_genHarvLogCutProbA>"
       << "<di_genHarvLogCutProbB>0.2821873</di_genHarvLogCutProbB>"
       << "<di_genHarvLogCutProbC>1.386188</di_genHarvLogCutProbC>"
       << "</disturbanceOther>";
  oOut << "<analysis>"
       << "<bi_a>"
       << "<bi_aVal species=\"Species_1\">1000</bi_aVal>"
       << "<bi_aVal species=\"Species_2\">1000</bi_aVal>"
       << "</bi_a>"
       << "<bi_b>"
       << "<bi_bVal species=\"Species_1\">0</bi_bVal>"
       << "<bi_bVal species=\"Species_2\">0</bi_bVal>"
       << "</bi_b>"
       << "<bi_c>"
       << "<bi_cVal species=\"Species_1\">0</bi_cVal>"
       << "<bi_cVal species=\"Species_2\">0</bi_cVal>"
       << "</bi_c>"
       << "<bi_d>"
       << "<bi_dVal species=\"Species_1\">1</bi_dVal>"
       << "<bi_dVal species=\"Species_2\">1</bi_dVal>"
       << "</bi_d>"
       << "<bi_e>"
       << "<bi_eVal species=\"Species_1\">0</bi_eVal>"
       << "<bi_eVal species=\"Species_2\">0</bi_eVal>"
       << "</bi_e>"
       << "<bi_eqID>"
       << "<bi_eiVal species=\"Species_1\">4</bi_eiVal>"
       << "<bi_eiVal species=\"Species_2\">4</bi_eiVal>"
       << "</bi_eqID>"
       << "<bi_dbhUnits>"
       << "<bi_duVal species=\"Species_1\">0</bi_duVal>"
       << "<bi_duVal species=\"Species_2\">1</bi_duVal>"
       << "</bi_dbhUnits>"
       << "<bi_biomassUnits>"
       << "<bi_buVal species=\"Species_1\">1</bi_buVal>"
       << "<bi_buVal species=\"Species_2\">1</bi_buVal>"
       << "</bi_biomassUnits>"
       << "<bi_useCorrectionFactor>"
       << "<bi_ucfVal species=\"Species_1\">0</bi_ucfVal>"
       << "<bi_ucfVal species=\"Species_2\">0</bi_ucfVal>"
       << "</bi_useCorrectionFactor>"
       << "<bi_correctionFactorValue>"
       << "<bi_cfvVal species=\"Species_1\">1</bi_cfvVal>"
       << "<bi_cfvVal species=\"Species_2\">1</bi_cfvVal>"
       << "</bi_correctionFactorValue>"
       << "<bi_whatDia>"
       << "<bi_wdVal species=\"Species_1\">0</bi_wdVal>"
       << "<bi_wdVal species=\"Species_2\">0</bi_wdVal>"
       << "</bi_whatDia>"
       << "</analysis>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

