//---------------------------------------------------------------------------
// TestInsectInfestation
//---------------------------------------------------------------------------
#if !defined(TestInsectInfestation_H)
  #define TestInsectInfestation_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;
class clTreePopulation;

/**
* Tests the clInsectInfestation class.
*/
class clTestInsectInfestation : public CppUnit::TestFixture {

  public:

  /**
  * Assembles all other testing functions into one test.
  */
  void TestInsectInfestation();

  protected:

  /**
  * Tests error processing.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Tests normal processing Run 1. WriteXMLFile1() writes the parameter file.
  * 1 year per timestep.
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Tests normal processing Run 2.  WriteXMLFile2() writes the parameter file.
  * 3 years per timestep.
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun2(clSimManager *p_oSimManager);

  /**
  * Writes the parameter file for TestNormalProcessingX().
  * @param iNumYrsTimestep Number of years per timestep.
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLNormalFile(int iNumYrsTimestep, int iTSStart);

  /**
  * Writes the parameter file for TestNormalProcessing2().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile2();

  /**
  * Writes an error file where the minimum DBH is negative.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error file where the insect infestation behavior is applied
  * to seedlings.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error file where the timestep to start infestation is negative.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes an error file where the intercept is not between 0 and 1.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile4();

  /**
  * Writes an error file where max infestation is not between 0 and 1.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile5();

  /**
  * Writes an error file where X0 = zero.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile6();

  /**
  * Writes common portions of the test parameter files.
  * @param oOut File stream to write to.
  */
  void WriteErrorCommonStuff(std::fstream &oOut);

  /**
   * Counts trees.
   * @param p_oPop Tree population
   * @param p_iTotal Total trees per species, sized 5.
   * @param p_iInfested Infested trees per species, sized 5.
   * @param bNoInfestation If true, there will be no checking of the years
   * infested value.
   */
  void GetTreeCount1Yr(clTreePopulation *p_oPop, long *p_iTotal, long *p_iInfested,
      bool bNoInfestation);

  /**
   * Counts trees.
   * @param p_oPop Tree population
   * @param p_iTotal Total trees per species, sized 5.
   * @param p_iInfested Infested trees per species, sized 5.
   * @param bNoInfestation If true, there will be no checking of the years
   * infested value.
   */
  void GetTreeCount3Yrs(clTreePopulation *p_oPop, long *p_iTotal, long *p_iInfested,
      bool bNoInfestation);
};
//---------------------------------------------------------------------------
#endif //TestInsectInfestation_H
