//---------------------------------------------------------------------------
// TestInsectInfestationMortality_H
//---------------------------------------------------------------------------
#if !defined(TestInsectInfestationMortality_H)
  #define TestInsectInfestationMortality_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clInsectInfestationMortality class.
*/
class clTestInsectInfestationMortality : public CppUnit::TestFixture
{
  public:

  /**
  * This puts all mortality tests into a single function.
  */
  void TestInsectInfestationMortality();

  protected:

  /**
  * Tests normal processing run 1. WriteXMLFile1() does setup.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  Inputs error files to make sure the errors are
  * caught.
  */
  void ErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file for normal processing run 1.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes a parameter file where a value for mortality probability intercept
  * is not between 0 and 1.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes a parameter file where a value for max mortality probability
  * is not between 0 and 1.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes a parameter file where there is no insect infestation behavior.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes a parameter file where a value for X0 is 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile4();

  /**
  * Writes common portions of the test parameter files.  This starts with
  * &lt;randomSeed&gt; and ends with &lt;/allometry&gt;.
  * @param oOut File stream to write to.
  */
  void WriteErrorCommonStuff(std::fstream &oOut);

};
#endif // TestInsectInfestationMortality_H
//---------------------------------------------------------------------------


