//---------------------------------------------------------------------------
// TestMerchantableStemWoodVolume
//---------------------------------------------------------------------------
#if !defined(TestMerchantableStemWoodVolume_H)
  #define TestMerchantableStemWoodVolume_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;
class clTreePopulation;
class clTree;

/**
* Tests the class clMerchantableStemWoodVolume.
*/
class clTestMerchantableStemWoodVolume : public CppUnit::TestFixture {

  public:

  /**
  * Performs all the tests from one function.
  */
  void TestMerchantableStemWoodVolume();

  protected:

  /**
  * Tests error processing.  This uses WriteXMLErrorFileX() to introduce errors
  * and makes sure that they are caught.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Performs test run 1. Uses the trees and equations from
  * clTestDimensionAnalysis::TestRun1. WriteXMLFile1() does setup. This function
  * creates three trees for each species, of varying sizes.  The run goes for a
  * timestep and then the function checks the volume values.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestNormalProcessing(clSimManager *p_oSimManager);

  /**
  * Writes the parameter file for run 1.  There are 19 species (Species 13 is
  * not used).  Dimension analysis and merchantable stem wood volume are the
  * only behaviors and are applied to adults of all used species.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes an error file where Dimension analysis is not applied to all trees
  * that use merchantable stem wood volume.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error file where merchantable stem wood volume is applied to a
  * tree type other than adult.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();
};
//---------------------------------------------------------------------------
#endif // TestBiomassCalculator_H
