//---------------------------------------------------------------------------
// TestMortality
//---------------------------------------------------------------------------
#if !defined(TestMortality_H)
  #define TestMortality_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>
#include <cppunit/TestSuite.h>

/**
* Tests the classes descended from clMortalityBase.
* @author Lora E. Murphy
*/
class clTestMortality : public CppUnit::TestFixture
{
  public:

  /**
  * Tests the mortality classes.
  * First run: WriteXMLFile1() creates the parameter file.  The file has the
  * following characteristics:
  * <ul>
  * <li>Timestep length of 1 year.
  * <li>5 species: Species 1, Species 2, Species 3, Species 4, Species 5.
  * <li>BC mortality behavior, applied to seedlings, saplings, and adults of
  * Species 1.
  * <li>Juvenile stochastic mortality behavior, applied to seedlings of
  * Species 3 and Species 4.
  * <li>Adult stochastic mortality behavior, applied to adults of Species 3.
  * <li>Senescence mortality behavior, applied to adults of Species 4.
  * <li>Adult self-thinning behavior, applied to adults of Species 5.
  * <li>Juvenile self-thinning behavior, applied to saplings of Species 4.
  * </ul>
  * The function does the following:
  * <ol>
  * <li>1000 trees are created of each tree species/type combination that has
  * been applied to a behavior.
  * <ul>
  * <li>Seedlings of species 1 all get a value of 0 in their "lgm" data member.
  * <li>Saplings of Species 1 all get a value of 0.1 in their "lgm" data member.
  * <li>Adults of Species 1 all get a value of 5 in their "lgm" data member.
  * <li>Adults of Species 4 all get a DBH of 100.
  * <li>Adults of Species 5 all get a DBH 20.
  * <li>Saplings of Species 4 all get a DBH of 8.
  * </ul>
  * <li> The model is run for 1 timestep.
  * <li> The remaining trees of each tree type and species are counted.
  * <li> The counts are compared to expected results, give or take 5%.
  * </ol>
  * <p>
  * Second run:
  * WriteXMLFile2() creates the parameter file.  The file has the following
  * characteristics:
  * <ul>
  * <li>Timestep length of 5 years.
  * <li>BC mortality behavior, applied to seedlings, saplings, and adults of
  * Species 1.
  * <li>GMF mortality behavior, applied to seedlings, saplings, and adults of
  * Species 2.
  * <li>Juvenile stochastic mortality behavior, applied to seedlings and
  * saplings of Species 3.
  * <li>Adult stochastic mortality behavior, applied to adults of Species 3.
  * <li>Senescence mortality behavior, applied to adults of Species 4.
  * <li>Adult self-thinning behavior, applied to adults of Species 5.
  * <li>Juvenile self-thinning behavior, applied to saplings of Species 4.
  * </ul>
  * The function does the following:
  * <ol>
  * <li>1000 trees are created of each tree species/type combination that has
  * been applied to a behavior.
  * <ul>
  * <li>Seedlings of species 1 all get a value of 0 in their "lgm" data member.
  * <li>Saplings of Species 1 all get a value of 0.5 in their "lgm" data member.
  * <li>Adults of Species 1 all get a value of 5 in their "lgm" data member.
  * <li>Seedlings of species 2 all get a value of 0 in their "lgm" data member.
  * <li>Saplings of Species 2 all get a value of 0.1 in their "lgm" data member.
  * <li>Adults of Species 2 all get a value of 5 in their "lgm" data member.
  * <li>Adults of Species 4 all get a DBH of 100.
  * <li>Adults of Species 5 all get a DBH 20.
  * <li>Saplings of Species 4 all get a DBH of 8.
  * </ul>
  * <li> The model is run for 1 timestep.
  * <li> The remaining trees of each tree type and species are counted.
  * <li> The counts are compared to expected results, give or take 5%.
  * </ol>
  */
  void TestMortality();

  protected:

  /**
  * Writes a parameter file with the specifications given for
  * TestMortality(), run 1.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file with the specifications given for
  * TestMortality(), run 2.
  * @return Filename written.
  */
  char * WriteXMLFile2();

};
//---------------------------------------------------------------------------
#endif // TestMortality_H
