//---------------------------------------------------------------------------
// TestNCIJuvenileGrowth.cpp
//---------------------------------------------------------------------------
#include "TestNCIJuvenileGrowth.h"
#include <fstream>
#include <math.h>
#include "TreePopulation.h"
#include "SimManager.h"
#include "BehaviorBase.h"

////////////////////////////////////////////////////////////////////////////
//  TestNCIJuvenileGrowth()
////////////////////////////////////////////////////////////////////////////
void clTestNCIJuvenileGrowth::TestNCIJuvenileGrowth() {
  clSimManager *p_oSimManager = new clSimManager(4, 2, "");

  TestRun1(p_oSimManager);
  TestRun2(p_oSimManager);
  TestErrorProcessing(p_oSimManager);

  delete p_oSimManager;
}

////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestNCIJuvenileGrowth::TestErrorProcessing(clSimManager *p_oSimManager) {

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNCIJuvenileGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIJuvenileGrowth error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNCIJuvenileGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIJuvenileGrowth error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNCIJuvenileGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIJuvenileGrowth error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }
}

////////////////////////////////////////////////////////////////////////////
// TestRun1()
////////////////////////////////////////////////////////////////////////////
void clTestNCIJuvenileGrowth::TestRun1(clSimManager *p_oSimManager) {

  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1, *p_oTargetTree2, *p_oTree;
  float fDiam, fExpectedDiam, fGrowth, fExpectedGrowth;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile1() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Create our two target trees
  fDiam = 8;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, 0, clTreePopulation::sapling, fDiam);

  fDiam = 8;
  p_oTargetTree2 = p_oPop->CreateTree(50, 50, 0, clTreePopulation::sapling, fDiam);

  //Now create all the neighbors
  p_oPop->CreateTree(53, 52, 1, clTreePopulation::adult, 15);
  p_oPop->CreateTree(59, 50, 2, clTreePopulation::adult, 25);
  p_oPop->CreateTree(50, 59, 0, clTreePopulation::adult, 30);
  p_oPop->CreateTree(55, 55, 1, clTreePopulation::adult, 45);
  p_oPop->CreateTree(60, 61, 2, clTreePopulation::adult, 15);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oTree = p_oPop->CreateTree(54, 54, 0, clTreePopulation::adult, 20);
  p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 10.39444738;
  fExpectedGrowth = 2.02218694;
  p_oTargetTree1->GetValue(p_oPop->GetDiam10Code(p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fDiam);
  p_oTargetTree1->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 10.19028901;
  fExpectedGrowth = 1.001395088;
  p_oTargetTree2->GetValue(p_oPop->GetDiam10Code(p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fDiam);
  p_oTargetTree2->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile2() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Create our two target trees
  fDiam = 8;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, 0, clTreePopulation::sapling, fDiam);

  fDiam = 8;
  p_oTargetTree2 = p_oPop->CreateTree(50, 50, 0, clTreePopulation::sapling, fDiam);

  //Now create all the neighbors
  p_oPop->CreateTree(53, 52, 1, clTreePopulation::adult, 15);
  p_oPop->CreateTree(59, 50, 2, clTreePopulation::adult, 25);
  p_oPop->CreateTree(50, 59, 0, clTreePopulation::adult, 30);
  p_oPop->CreateTree(55, 55, 1, clTreePopulation::adult, 45);
  p_oPop->CreateTree(60, 61, 2, clTreePopulation::adult, 15);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oTree = p_oPop->CreateTree(54, 54, 0, clTreePopulation::adult, 20);
  p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 11.20570448;
  fExpectedGrowth = 2.026157479;
  p_oTargetTree1->GetValue(p_oPop->GetDiam10Code(p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fDiam);
  p_oTargetTree1->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 10.59144017;
  fExpectedGrowth = 1.002383635;
  p_oTargetTree2->GetValue(p_oPop->GetDiam10Code(p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fDiam);
  p_oTargetTree2->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);
}

////////////////////////////////////////////////////////////////////////////
// TestRun2()
////////////////////////////////////////////////////////////////////////////
void clTestNCIJuvenileGrowth::TestRun2(clSimManager *p_oSimManager) {

  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1,
         *p_oTargetTree2,
         *p_oTargetTree3,
         *p_oTargetTree4,
         *p_oTargetTree5,
         *p_oTargetTree6,
         *p_oTargetTree7,
         *p_oTargetTree8,
         *p_oTargetTree9,
         *p_oTargetTree;
  float fDiam, fExpectedDiam;
  int iSpecies, i;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile3() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Create our trees
  fDiam = 7;
  iSpecies = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 8;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 9;
  iSpecies = 3;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 9.5;
  iSpecies = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 0.2;
  iSpecies = 0;
  p_oTargetTree5 = p_oPop->CreateTree(56, 56, iSpecies, clTreePopulation::seedling, fDiam);

  fDiam = 1.1;
  iSpecies = 0;
  p_oTargetTree6 = p_oPop->CreateTree(52, 52, iSpecies, clTreePopulation::seedling, fDiam);

  fDiam = 1.1;
  iSpecies = 1;
  p_oTargetTree7 = p_oPop->CreateTree(53, 53, iSpecies, clTreePopulation::seedling, fDiam);

  fDiam = 4;
  iSpecies = 3;
  p_oTargetTree8 = p_oPop->CreateTree(54, 54, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 4;
  iSpecies = 3;
  p_oTargetTree9 = p_oPop->CreateTree(57, 57, iSpecies, clTreePopulation::sapling, fDiam);

  //Neighbors
  fDiam = 15;
  iSpecies = 1;
  p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 25;
  iSpecies = 3;
  p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 30;
  iSpecies = 0;
  p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 45;
  iSpecies = 1;
  p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 11;
  iSpecies = 0;
  p_oPop->CreateTree(57, 58, iSpecies, clTreePopulation::snag, fDiam);

  for (i = 0; i < 100; i++) {
    p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
    p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);
  }

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 9.143004869;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 11.36400094;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 12.02483875;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 12.06527425;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 0.36481175;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 1.279475968;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 1.924116554;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 5.479854383;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 5.479854383;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile4() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Create our trees
  fDiam = 7;
  iSpecies = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 8;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 9;
  iSpecies = 3;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 9.5;
  iSpecies = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 0.2;
  iSpecies = 0;
  p_oTargetTree5 = p_oPop->CreateTree(56, 56, iSpecies, clTreePopulation::seedling, fDiam);

  fDiam = 1.1;
  iSpecies = 0;
  p_oTargetTree6 = p_oPop->CreateTree(52, 52, iSpecies, clTreePopulation::seedling, fDiam);

  fDiam = 1.1;
  iSpecies = 1;
  p_oTargetTree7 = p_oPop->CreateTree(53, 53, iSpecies, clTreePopulation::seedling, fDiam);

  fDiam = 4;
  iSpecies = 3;
  p_oTargetTree8 = p_oPop->CreateTree(54, 54, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 4;
  iSpecies = 3;
  p_oTargetTree9 = p_oPop->CreateTree(57, 57, iSpecies, clTreePopulation::sapling, fDiam);

  //Neighbors
  fDiam = 15;
  iSpecies = 1;
  p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 25;
  iSpecies = 3;
  p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 30;
  iSpecies = 0;
  p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 45;
  iSpecies = 1;
  p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  fDiam = 11;
  iSpecies = 0;
  p_oPop->CreateTree(57, 58, iSpecies, clTreePopulation::snag, fDiam);

  for (i = 0; i < 100; i++) {
    p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
    p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);
  }

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 9.94917298;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 11.31056392; //note DBH
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 10.89023666; //note DBH
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 12.47005897;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 0.707769002;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 1.642350086;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 3.601378255;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 6.451402057;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 6.451402057;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestNCIJuvenileGrowth::WriteXMLFile1() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRunCommonStuff(oOut);

  oOut << "<gr_juvNCIMinNeighborDiam10>"
       << "<gr_jnmndVal species=\"Species_1\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_2\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_3\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_4\">5</gr_jnmndVal>"
       << "</gr_juvNCIMinNeighborDiam10>"
       << "<gr_juvNCIDiam10Divisor>100</gr_juvNCIDiam10Divisor>"
       << "<gr_juvNCIIncludeSnagsInNCI>0</gr_juvNCIIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestNCIJuvenileGrowth::WriteXMLFile2() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRunCommonStuff(oOut);

  oOut << "<gr_juvNCIMinNeighborDiam10>"
       << "<gr_jnmndVal species=\"Species_1\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_2\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_3\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_4\">5</gr_jnmndVal>"
       << "</gr_juvNCIMinNeighborDiam10>"
       << "<gr_juvNCIDiam10Divisor>100</gr_juvNCIDiam10Divisor>"
       << "<gr_juvNCIIncludeSnagsInNCI>0</gr_juvNCIIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestNCIJuvenileGrowth::WriteXMLFile3() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRunCommonStuff(oOut);

  oOut << "<gr_juvNCIMinNeighborDiam10>"
       << "<gr_jnmndVal species=\"Species_1\">0</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_2\">0</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_3\">0</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_4\">0</gr_jnmndVal>"
       << "</gr_juvNCIMinNeighborDiam10>"
       << "<gr_juvNCIDiam10Divisor>100</gr_juvNCIDiam10Divisor>"
       << "<gr_juvNCIIncludeSnagsInNCI>1</gr_juvNCIIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestNCIJuvenileGrowth::WriteXMLFile4() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRunCommonStuff(oOut);

  oOut << "<gr_juvNCIMinNeighborDiam10>"
       << "<gr_jnmndVal species=\"Species_1\">0</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_2\">0</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_3\">0</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_4\">0</gr_jnmndVal>"
       << "</gr_juvNCIMinNeighborDiam10>"
       << "<gr_juvNCIDiam10Divisor>100</gr_juvNCIDiam10Divisor>"
       << "<gr_juvNCIIncludeSnagsInNCI>1</gr_juvNCIIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestNCIJuvenileGrowth::WriteCommonStuff( std::fstream &oOut )
{
  using namespace std;
  oOut << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";
}



////////////////////////////////////////////////////////////////////////////
//  WriteRunCommonStuff()
////////////////////////////////////////////////////////////////////////////
void clTestNCIJuvenileGrowth::WriteRunCommonStuff( std::fstream &oOut ) {

  using namespace std;
  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>NCI Juvenile Growth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>constradialgrowth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_4\" type=\"Seedling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_adultConstRadialInc>"
       << "<gr_acriVal species=\"Species_4\">10</gr_acriVal>"
       << "</gr_adultConstRadialInc>"
       << "<gr_juvNCIMaxCrowdingRadius>"
       << "<gr_jnmcrVal species=\"Species_1\">12</gr_jnmcrVal>"
       << "<gr_jnmcrVal species=\"Species_4\">12</gr_jnmcrVal>"
       << "<gr_jnmcrVal species=\"Species_2\">12</gr_jnmcrVal>"
       << "</gr_juvNCIMaxCrowdingRadius>"
       << "<gr_juvNCIAlpha>"
       << "<gr_jnaVal species=\"Species_1\">2.17031683</gr_jnaVal>"
       << "<gr_jnaVal species=\"Species_2\">2.81</gr_jnaVal>"
       << "<gr_jnaVal species=\"Species_4\">1.33</gr_jnaVal>"
       << "</gr_juvNCIAlpha>"
       << "<gr_juvNCIBeta>"
       << "<gr_jnbVal species=\"Species_1\">0.699942</gr_jnbVal>"
       << "<gr_jnbVal species=\"Species_2\">0.5</gr_jnbVal>"
       << "<gr_jnbVal species=\"Species_4\">0.09</gr_jnbVal>"
       << "</gr_juvNCIBeta>"
       << "<gr_juvNCIMaxPotentialGrowth>"
       << "<gr_jnmpgVal species=\"Species_1\">1.05258749</gr_jnmpgVal>"
       << "<gr_jnmpgVal species=\"Species_2\">1.531</gr_jnmpgVal>"
       << "<gr_jnmpgVal species=\"Species_4\">0.994</gr_jnmpgVal>"
       << "</gr_juvNCIMaxPotentialGrowth>"
       << "<gr_juvNCISizeEffectA>"
       << "<gr_jnseaVal species=\"Species_1\">0.342463899</gr_jnseaVal>"
       << "<gr_jnseaVal species=\"Species_2\">0.85</gr_jnseaVal>"
       << "<gr_jnseaVal species=\"Species_4\">0.7643</gr_jnseaVal>"
       << "</gr_juvNCISizeEffectA>"
       << "<gr_juvNCISizeEffectB>"
       << "<gr_jnsebVal species=\"Species_1\">0.05</gr_jnsebVal>"
       << "<gr_jnsebVal species=\"Species_2\">0.0236</gr_jnsebVal>"
       << "<gr_jnsebVal species=\"Species_4\">0.0141</gr_jnsebVal>"
       << "</gr_juvNCISizeEffectB>"
       << "<gr_juvNCICrowdingSlope>"
       << "<gr_jncslVal species=\"Species_1\">0.698</gr_jncslVal>"
       << "<gr_jncslVal species=\"Species_2\">0.457</gr_jncslVal>"
       << "<gr_jncslVal species=\"Species_4\">0.469</gr_jncslVal>"
       << "</gr_juvNCICrowdingSlope>"
       << "<gr_juvNCICrowdingSteepness>"
       << "<gr_jncstVal species=\"Species_1\">-0.00163</gr_jncstVal>"
       << "<gr_jncstVal species=\"Species_2\">-0.00126</gr_jncstVal>"
       << "<gr_jncstVal species=\"Species_4\">-0.00163</gr_jncstVal>"
       << "</gr_juvNCICrowdingSteepness>"
       << "<gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.66401082</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.71</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_4\">0.08</gr_jnlVal>"
       << "</gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.00442797</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.12</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_4\">0.03</gr_jnlVal>"
       << "</gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_juvNCISpecies_3NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.41812471</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.24</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_4\">0.05</gr_jnlVal>"
       << "</gr_juvNCISpecies_3NeighborLambda>"
       << "<gr_juvNCISpecies_4NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.41812471</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.24</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_4\">0.05</gr_jnlVal>"
       << "</gr_juvNCISpecies_4NeighborLambda>";

}

/////////////////////////////////////////////////////////////////////////////
//  WriteErrorFileCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestNCIJuvenileGrowth::WriteErrorFileCommonStuff( std::fstream &oOut )
{
  using namespace std;
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestNCIJuvenileGrowth::WriteXMLErrorFile1() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>NCI Juvenile Growth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seedling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_juvNCIMaxCrowdingRadius>"
       << "<gr_jnmcrVal species=\"Species_1\">-12</gr_jnmcrVal>"
       << "<gr_jnmcrVal species=\"Species_2\">12</gr_jnmcrVal>"
       << "</gr_juvNCIMaxCrowdingRadius>"
       << "<gr_juvNCIAlpha>"
       << "<gr_jnaVal species=\"Species_1\">2.17031683</gr_jnaVal>"
       << "<gr_jnaVal species=\"Species_2\">2.81</gr_jnaVal>"
       << "</gr_juvNCIAlpha>"
       << "<gr_juvNCIBeta>"
       << "<gr_jnbVal species=\"Species_1\">0.699942</gr_jnbVal>"
       << "<gr_jnbVal species=\"Species_2\">0.5</gr_jnbVal>"
       << "</gr_juvNCIBeta>"
       << "<gr_juvNCIMaxPotentialGrowth>"
       << "<gr_jnmpgVal species=\"Species_1\">1.05258749</gr_jnmpgVal>"
       << "<gr_jnmpgVal species=\"Species_2\">1.531</gr_jnmpgVal>"
       << "</gr_juvNCIMaxPotentialGrowth>"
       << "<gr_juvNCISizeEffectA>"
       << "<gr_jnseaVal species=\"Species_1\">0.342463899</gr_jnseaVal>"
       << "<gr_jnseaVal species=\"Species_2\">0.85</gr_jnseaVal>"
       << "</gr_juvNCISizeEffectA>"
       << "<gr_juvNCISizeEffectB>"
       << "<gr_jnsebVal species=\"Species_1\">0.05</gr_jnsebVal>"
       << "<gr_jnsebVal species=\"Species_2\">0.0236</gr_jnsebVal>"
       << "</gr_juvNCISizeEffectB>"
       << "<gr_juvNCICrowdingSlope>"
       << "<gr_jncslVal species=\"Species_1\">0.698</gr_jncslVal>"
       << "<gr_jncslVal species=\"Species_2\">0.457</gr_jncslVal>"
       << "</gr_juvNCICrowdingSlope>"
       << "<gr_juvNCICrowdingSteepness>"
       << "<gr_jncstVal species=\"Species_1\">-0.00163</gr_jncstVal>"
       << "<gr_jncstVal species=\"Species_2\">-0.00126</gr_jncstVal>"
       << "</gr_juvNCICrowdingSteepness>"
       << "<gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.66401082</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.71</gr_jnlVal>"
       << "</gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.00442797</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.12</gr_jnlVal>"
       << "</gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_juvNCIMinNeighborDiam10>"
       << "<gr_jnmndVal species=\"Species_1\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_2\">5</gr_jnmndVal>"
       << "</gr_juvNCIMinNeighborDiam10>"
       << "<gr_juvNCIDiam10Divisor>100</gr_juvNCIDiam10Divisor>"
       << "<gr_juvNCIIncludeSnagsInNCI>0</gr_juvNCIIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestNCIJuvenileGrowth::WriteXMLErrorFile2() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>NCI Juvenile Growth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seedling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_juvNCIMaxCrowdingRadius>"
       << "<gr_jnmcrVal species=\"Species_1\">12</gr_jnmcrVal>"
       << "<gr_jnmcrVal species=\"Species_2\">12</gr_jnmcrVal>"
       << "</gr_juvNCIMaxCrowdingRadius>"
       << "<gr_juvNCIAlpha>"
       << "<gr_jnaVal species=\"Species_1\">2.17031683</gr_jnaVal>"
       << "<gr_jnaVal species=\"Species_2\">2.81</gr_jnaVal>"
       << "</gr_juvNCIAlpha>"
       << "<gr_juvNCIBeta>"
       << "<gr_jnbVal species=\"Species_1\">0.699942</gr_jnbVal>"
       << "<gr_jnbVal species=\"Species_2\">0.5</gr_jnbVal>"
       << "</gr_juvNCIBeta>"
       << "<gr_juvNCIMaxPotentialGrowth>"
       << "<gr_jnmpgVal species=\"Species_1\">1.05258749</gr_jnmpgVal>"
       << "<gr_jnmpgVal species=\"Species_2\">-1.531</gr_jnmpgVal>"
       << "</gr_juvNCIMaxPotentialGrowth>"
       << "<gr_juvNCISizeEffectA>"
       << "<gr_jnseaVal species=\"Species_1\">0.342463899</gr_jnseaVal>"
       << "<gr_jnseaVal species=\"Species_2\">0.85</gr_jnseaVal>"
       << "</gr_juvNCISizeEffectA>"
       << "<gr_juvNCISizeEffectB>"
       << "<gr_jnsebVal species=\"Species_1\">0.05</gr_jnsebVal>"
       << "<gr_jnsebVal species=\"Species_2\">0.0236</gr_jnsebVal>"
       << "</gr_juvNCISizeEffectB>"
       << "<gr_juvNCICrowdingSlope>"
       << "<gr_jncslVal species=\"Species_1\">0.698</gr_jncslVal>"
       << "<gr_jncslVal species=\"Species_2\">0.457</gr_jncslVal>"
       << "</gr_juvNCICrowdingSlope>"
       << "<gr_juvNCICrowdingSteepness>"
       << "<gr_jncstVal species=\"Species_1\">-0.00163</gr_jncstVal>"
       << "<gr_jncstVal species=\"Species_2\">-0.00126</gr_jncstVal>"
       << "</gr_juvNCICrowdingSteepness>"
       << "<gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.66401082</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.71</gr_jnlVal>"
       << "</gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.00442797</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.12</gr_jnlVal>"
       << "</gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_juvNCIMinNeighborDiam10>"
       << "<gr_jnmndVal species=\"Species_1\">5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_2\">5</gr_jnmndVal>"
       << "</gr_juvNCIMinNeighborDiam10>"
       << "<gr_juvNCIDiam10Divisor>100</gr_juvNCIDiam10Divisor>"
       << "<gr_juvNCIIncludeSnagsInNCI>0</gr_juvNCIIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestNCIJuvenileGrowth::WriteXMLErrorFile3() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>NCI Juvenile Growth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seedling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_juvNCIMaxCrowdingRadius>"
       << "<gr_jnmcrVal species=\"Species_1\">12</gr_jnmcrVal>"
       << "<gr_jnmcrVal species=\"Species_2\">12</gr_jnmcrVal>"
       << "</gr_juvNCIMaxCrowdingRadius>"
       << "<gr_juvNCIAlpha>"
       << "<gr_jnaVal species=\"Species_1\">2.17031683</gr_jnaVal>"
       << "<gr_jnaVal species=\"Species_2\">2.81</gr_jnaVal>"
       << "</gr_juvNCIAlpha>"
       << "<gr_juvNCIBeta>"
       << "<gr_jnbVal species=\"Species_1\">0.699942</gr_jnbVal>"
       << "<gr_jnbVal species=\"Species_2\">0.5</gr_jnbVal>"
       << "</gr_juvNCIBeta>"
       << "<gr_juvNCIMaxPotentialGrowth>"
       << "<gr_jnmpgVal species=\"Species_1\">1.05258749</gr_jnmpgVal>"
       << "<gr_jnmpgVal species=\"Species_2\">1.531</gr_jnmpgVal>"
       << "</gr_juvNCIMaxPotentialGrowth>"
       << "<gr_juvNCISizeEffectA>"
       << "<gr_jnseaVal species=\"Species_1\">0.342463899</gr_jnseaVal>"
       << "<gr_jnseaVal species=\"Species_2\">0.85</gr_jnseaVal>"
       << "</gr_juvNCISizeEffectA>"
       << "<gr_juvNCISizeEffectB>"
       << "<gr_jnsebVal species=\"Species_1\">0.05</gr_jnsebVal>"
       << "<gr_jnsebVal species=\"Species_2\">0.0236</gr_jnsebVal>"
       << "</gr_juvNCISizeEffectB>"
       << "<gr_juvNCICrowdingSlope>"
       << "<gr_jncslVal species=\"Species_1\">0.698</gr_jncslVal>"
       << "<gr_jncslVal species=\"Species_2\">0.457</gr_jncslVal>"
       << "</gr_juvNCICrowdingSlope>"
       << "<gr_juvNCICrowdingSteepness>"
       << "<gr_jncstVal species=\"Species_1\">-0.00163</gr_jncstVal>"
       << "<gr_jncstVal species=\"Species_2\">-0.00126</gr_jncstVal>"
       << "</gr_juvNCICrowdingSteepness>"
       << "<gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.66401082</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.71</gr_jnlVal>"
       << "</gr_juvNCISpecies_1NeighborLambda>"
       << "<gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_jnlVal species=\"Species_1\">0.00442797</gr_jnlVal>"
       << "<gr_jnlVal species=\"Species_2\">0.12</gr_jnlVal>"
       << "</gr_juvNCISpecies_2NeighborLambda>"
       << "<gr_juvNCIMinNeighborDiam10>"
       << "<gr_jnmndVal species=\"Species_1\">-5</gr_jnmndVal>"
       << "<gr_jnmndVal species=\"Species_2\">5</gr_jnmndVal>"
       << "</gr_juvNCIMinNeighborDiam10>"
       << "<gr_juvNCIDiam10Divisor>100</gr_juvNCIDiam10Divisor>"
       << "<gr_juvNCIIncludeSnagsInNCI>0</gr_juvNCIIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}
