//---------------------------------------------------------------------------
// TestNCIJuvenileGrowth
//---------------------------------------------------------------------------
#if !defined(TestNCIJuvenileGrowth_H)
  #define TestNCIJuvenileGrowth_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clNciGrowth class.
*/
class clTestNCIJuvenileGrowth : public CppUnit::TestFixture {

  public:

  /**
  * Tests the clNciGrowth class.
  */
  void TestNCIJuvenileGrowth();

  /**
  * Performs a test run of NCI growth. WriteXMLFile1() performs setup for a
  * 1-year timestep; then WriteXMLFile2() performs setup for an otherwise
  * identical 3-year timestep.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun1(clSimManager *p_oSimManager);

  /**
  * Tests the growth calculations at two timestep lengths. WriteXMLFile3() is
  * used to do setup in the first case, for a 1 year timestep. WriteXMLFile4()
  * does setup for a 3 year timestep and the growth is checked for the same
  * trees.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun2(clSimManager *p_oSimManager);

  /**
  * Tests error processing for input files.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);


  protected:

  /**
  * Writes a 1-year timestep file.  This contains 3 species.  NCI growth
  * (auto-height) is assigned to adults of Species 1.
  *
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes a 3-year timestep file.  This contains 3 species.  NCI growth
  * (auto-height) is assigned to adults of Species 1.
  *
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes a 1-year timestep file.  This contains 4 species, one unused
  * (species 3; this helps catch array-index problems).  NCI growth
  * (auto-height) is assigned to all saplings and adults.
  *
  * @return Filename written.
  */
  char* WriteXMLFile3();

  /**
  * Writes a 3-year timestep file.  This contains 4 species, one unused
  * (species 3; this helps catch array-index problems).  NCI growth
  * (auto-height) is assigned to all saplings and adults.
  *
  * @return Filename written.
  */
  char* WriteXMLFile4();

  /**
  * Writes an error condition where max radius of neighbor effects is < 0.
  *
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error condition where max growth for a species is < 0.
  *
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error condition where a min neighbor diam10 is less than 0.
  *
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * Picks up right after the number of years per timestep and ends at the
  * closing tree tag.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);

  /**
  * Writes common portions of the test parameter files for Run 1.
  * Picks up at the behavior list through the end of the file.
  * @param oOut File stream to write to.
  */
  void WriteRunCommonStuff(std::fstream &oOut);

  /**
  * Writes common portions of the test error parameter files (tree pop, plot,
  * etc).  Starts at the beginning of the file and ends at the closing tree tag.
  * @param oOut File stream to write to.
  */
  void WriteErrorFileCommonStuff(std::fstream &oOut);


};

//---------------------------------------------------------------------------
#endif // TestNCIJuvenileGrowth_H
