//---------------------------------------------------------------------------
// TestNeighbhorhoodSeedPredation.cpp
//---------------------------------------------------------------------------
#include "TestNeighborhoodSeedPredation.h"
#include "SimManager.h"
#include "TreePopulation.h"
#include "GridBase.h"
#include <fstream>
#include <math.h>

////////////////////////////////////////////////////////////////////////////
//  TestNeighborhoodSeedPredation()
////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNeighborhoodSeedPredation() {
  clSimManager *p_oSimManager = new clSimManager(4, 2, "");

  TestNormalProcessingRun1(p_oSimManager);
  TestNormalProcessingRun2(p_oSimManager);
  TestNormalProcessingRun3(p_oSimManager);
  TestNormalProcessingRun4(p_oSimManager);
  TestNormalProcessingRun5(p_oSimManager);
  TestNormalProcessingRun6(p_oSimManager);
  TestNormalProcessingRun7(p_oSimManager);
  TestErrorProcessing(p_oSimManager);

  delete p_oSimManager;
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun1()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNormalProcessingRun1(clSimManager *p_oSimManager)
{
  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile1());
  TestRun1And5(p_oSimManager);
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun2()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNormalProcessingRun2(clSimManager *p_oSimManager)
{
  p_oSimManager->ReadFile(WriteXMLFile2());
  TestRun2And6(p_oSimManager);
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun3()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNormalProcessingRun3(clSimManager *p_oSimManager)
{
  clTreePopulation *p_oPop;
  clTreeSearch *p_oAllSeedlings;
  clTree *p_oTree;
  float fX, fY, fXMin, fXMax, fYMin, fYMax,
        fDbh,
        fXCellLength = 8, fYCellLength = 8;
  int *p_iNumSeedlings = new int[4], iSp, i;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile3());
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Add our trees
  fX = 4; fY = 4;
  iSp = 0;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 1;
  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 20;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 15;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 0;
  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 35;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 50;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 21;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fX = 34; fY = 34;
  iSp = 0;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 1;
  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 0;
  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 35;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  //Run a timestep
  p_oSimManager->RunSim(1);

  //Count the number of seedlings in each grid cell
  p_oAllSeedlings = p_oPop->Find("type=1");

  //Check our values for cell 0, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fYMin = 0;
  fYMax = fYCellLength;
  fXMin = 0;
  fXMax = fXCellLength;
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX < fXMax && fY >= fYMin && fY < fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(79 == p_iNumSeedlings[0] || 80 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(190 == p_iNumSeedlings[1] || 191 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(384 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(192 == p_iNumSeedlings[3]);

  //Check our values for cell 4, 4
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 4 * fXCellLength;
  fXMax = (4 + 1) * fXCellLength;
  fYMin = 4 * fYCellLength;
  fYMax = (4 + 1) * fYCellLength;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(36 == p_iNumSeedlings[0] || 37 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(102 == p_iNumSeedlings[1] || 103 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(384 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(192 == p_iNumSeedlings[3]);

  delete[] p_iNumSeedlings;
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun4()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNormalProcessingRun4(clSimManager *p_oSimManager)
{
  clTreePopulation *p_oPop;
  clTreeSearch *p_oAllSeedlings;
  clGridBase *p_oGrid;
  clTree *p_oTree;
  float fX, fY, fXMin, fXMax, fYMin, fYMax,
        fDbh,
        fValue, fExpectedValue,
        fXCellLength = 50, fYCellLength = 50;
  int *p_iNumSeedlings = new int[5], iSp, i;

  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile4());
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oGrid = p_oSimManager->GetGridObject("Neighborhood Seed Predation");
  CPPUNIT_ASSERT(NULL != p_oGrid);

  //Add our trees
  fX = 25; fY = 25;
  iSp = 0;
  fDbh = 5;
  for (i = 0; i < 100; i++)
    p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 1;
  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 20;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 15;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 0;
  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 35;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 50;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 21;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fX = 25; fY = 75;
  iSp = 0;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 1;
  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 3;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 0;
  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 35;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 3;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  fX = 75; fY = 75;
  iSp = 0;
  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 20;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 40;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 50;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 60;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 70;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 80;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 90;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 100;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 110;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  //Run a timestep
  p_oSimManager->RunSim(1);

  //Count the number of seedlings in each grid cell
  p_oAllSeedlings = p_oPop->Find("type=1");

  //Check our values for cell 0, 0
  for (i = 0; i < 5; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fYMin = 0;
  fYMax = fYCellLength;
  fXMin = 0;
  fXMax = fXCellLength;
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX < fXMax && fY >= fYMin && fY < fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(p_iNumSeedlings[0] >= 1996 && p_iNumSeedlings[0] <= 1997);
  CPPUNIT_ASSERT(p_iNumSeedlings[1] >= 1526 && p_iNumSeedlings[1] <= 1527);
  CPPUNIT_ASSERT(5000 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(p_iNumSeedlings[3] >= 1868 && p_iNumSeedlings[3] <= 1869);
  CPPUNIT_ASSERT(p_iNumSeedlings[4] >= 298 && p_iNumSeedlings[4] <= 301);

  //Check our values for cell 1, 0
  for (i = 0; i < 5; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = fXCellLength;
  fXMax = (1 + 1) * fXCellLength;
  fYMin = 0;
  fYMax = fYCellLength;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(p_iNumSeedlings[0] >= 1785 && p_iNumSeedlings[0] <= 1786);
  CPPUNIT_ASSERT(p_iNumSeedlings[1] >= 1870 && p_iNumSeedlings[1] <= 1871);
  CPPUNIT_ASSERT(5000 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(p_iNumSeedlings[3] >= 2131 && p_iNumSeedlings[3] <= 2132);
  CPPUNIT_ASSERT(p_iNumSeedlings[4] >= 2271 && p_iNumSeedlings[4] <= 2274);

  //Check our values for cell 0, 1
  for (i = 0; i < 5; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 0;
  fXMax = fXCellLength;
  fYMin = fYCellLength;
  fYMax = (1 + 1) * fYCellLength;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(),
        p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(),
        p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(p_iNumSeedlings[0] >= 1917 && p_iNumSeedlings[0] <= 1918);
  CPPUNIT_ASSERT(p_iNumSeedlings[1] >= 1495 && p_iNumSeedlings[1] <= 1496);
  CPPUNIT_ASSERT(5000 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(p_iNumSeedlings[3] >= 2261 && p_iNumSeedlings[3] <= 2263);
  CPPUNIT_ASSERT(p_iNumSeedlings[4] >= 181 && p_iNumSeedlings[4] <= 184);

  //Check our values for cell 1, 1
  for (i = 0; i < 5; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = fXCellLength;
  fXMax = (1 + 1) * fXCellLength;
  fYMin = fYCellLength;
  fYMax = (1 + 1) * fYCellLength;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(),
        p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(),
        p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(p_iNumSeedlings[0] >= 1790 && p_iNumSeedlings[0] <= 1791);
  CPPUNIT_ASSERT(p_iNumSeedlings[1] >= 1854 && p_iNumSeedlings[1] <= 1856);
  CPPUNIT_ASSERT(5000 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(p_iNumSeedlings[3] >= 992 && p_iNumSeedlings[3] <= 993);
  CPPUNIT_ASSERT(p_iNumSeedlings[4] >= 0 && p_iNumSeedlings[4] <= 3);

  delete[] p_iNumSeedlings;

  //Check our grid values
  //Cell 0, 0
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.201459072;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.389408398;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.252504483;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.88025482;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);

  //Cell 1, 0
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("startseeds_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.285720283;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.251978413;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.147201632;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.091122961;
  p_oGrid->GetValueOfCell(1, 0, p_oGrid->GetFloatDataCode("propeaten_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);

  //Cell 0, 1
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("startseeds_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.233095142;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.401669486;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.095378545;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.927028145;
  p_oGrid->GetValueOfCell(0, 1, p_oGrid->GetFloatDataCode("propeaten_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);

  //Cell 1, 1
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 2500;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("startseeds_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.283940005;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.257988172;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.603012682;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);
  fExpectedValue = 0.999975593;
  p_oGrid->GetValueOfCell(1, 1, p_oGrid->GetFloatDataCode("propeaten_4"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.05);

}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun5()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNormalProcessingRun5(clSimManager *p_oSimManager)
{
  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile5());
  TestRun1And5(p_oSimManager);
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun6()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNormalProcessingRun6(clSimManager *p_oSimManager)
{
  p_oSimManager->ReadFile(WriteXMLFile6());
  TestRun2And6(p_oSimManager);
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun7()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestNormalProcessingRun7(clSimManager *p_oSimManager)
{
  clTreePopulation *p_oPop;
  clTreeSearch *p_oAllSeedlings;
  clGridBase *p_oGrid;
  clTree *p_oTree;
  float fX, fY, fXMin, fXMax, fYMin, fYMax,
        fValue, fExpectedValue,
        fXCellLength = 8, fYCellLength = 8;
  int *p_iNumSeedlings = new int[4], i;
  //Feed our file to the sim manager
  p_oSimManager->ReadFile(WriteXMLFile7());
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oGrid = p_oSimManager->GetGridObject("Neighborhood Seed Predation");
  CPPUNIT_ASSERT(NULL != p_oGrid);

  //Run a timestep
  p_oSimManager->RunSim(1);

  //Count the number of seedlings in each grid cell
  p_oAllSeedlings = p_oPop->Find("type=1");

  //Check our values for cell 0, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fYMin = 0;
  fYMax = fYCellLength;
  fXMin = 0;
  fXMax = fXCellLength;
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX < fXMax && fY >= fYMin && fY < fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(59 == p_iNumSeedlings[0] || 60 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(203 == p_iNumSeedlings[1] || 204 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(128 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(64 == p_iNumSeedlings[3]);

  //Check our values for cell 4, 4
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 4 * fXCellLength;
  fXMax = (4 + 1) * fXCellLength;
  fYMin = 4 * fYCellLength;
  fYMax = (4 + 1) * fYCellLength;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(59 == p_iNumSeedlings[0] || 60 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(203 == p_iNumSeedlings[1] || 204 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(128 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(64 == p_iNumSeedlings[3]);

  //Check our grid values
  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 256;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.075160109;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0.204240302;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);

  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 256;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.075160109;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0.204240302;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);

  delete[] p_iNumSeedlings;
}

/////////////////////////////////////////////////////////////////////////////
// TestRun1And5()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestRun1And5(clSimManager *p_oSimManager)
{
  clTreePopulation *p_oPop;
  clTreeSearch *p_oAllSeedlings;
  clGridBase *p_oGrid;
  clTree *p_oTree;
  float fX, fY, fXMin, fXMax, fYMin, fYMax,
        fDbh,
        fValue, fExpectedValue,
        fXCellLength = 8, fYCellLength = 8;
  int *p_iNumSeedlings = new int[4], iSp, i;

  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oGrid = p_oSimManager->GetGridObject("Neighborhood Seed Predation");
  CPPUNIT_ASSERT(NULL != p_oGrid);

  //Add our trees
  fX = 4; fY = 4;
  iSp = 0;
  fDbh = 5;
  for (i = 0; i < 100; i++)
    p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 2;
  fDbh = 14 ;
  for (i = 0; i < 100; i++)
    p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 20;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 15;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 0;
  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 35;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 50;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 3;
  fDbh = 21;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fX = 34; fY = 34;
  iSp = 0;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 1;
  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 3;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 0;
  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 1;
  fDbh = 35;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  iSp = 2;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  iSp = 3;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  //Run a timestep
  p_oSimManager->RunSim(1);

  //Count the number of seedlings in each grid cell
  p_oAllSeedlings = p_oPop->Find("type=1");

  //Check our values for cell 0, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fYMin = 0;
  fYMax = fYCellLength;
  fXMin = 0;
  fXMax = fXCellLength;
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX < fXMax && fY >= fYMin && fY < fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(26 == p_iNumSeedlings[0] || 27 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(253 == p_iNumSeedlings[1] || 254 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(128 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(64 == p_iNumSeedlings[3]);

  //Check our values for cell 4, 4
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 4 * fXCellLength;
  fXMax = (4 + 1) * fXCellLength;
  fYMin = 4 * fYCellLength;
  fYMax = (4 + 1) * fYCellLength;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(12 == p_iNumSeedlings[0] || 13 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(136 == p_iNumSeedlings[1] || 137 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(128 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(64 == p_iNumSeedlings[3]);

  //Check our grid values
  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 256;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.585715849;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0.009568214;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(0, 0, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);

  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 256;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);
  fExpectedValue = 64;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("startseeds_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.001);

  fExpectedValue = 0.809911958;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_0"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0.466175336;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_1"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_2"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);
  fExpectedValue = 0;
  p_oGrid->GetValueOfCell(4, 4, p_oGrid->GetFloatDataCode("propeaten_3"), &fValue);
  CPPUNIT_ASSERT(fabs(fExpectedValue - fValue) < 0.1);

  delete[] p_iNumSeedlings;
}

/////////////////////////////////////////////////////////////////////////////
// TestRun2And6()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestRun2And6(clSimManager *p_oSimManager)
{
  clTreePopulation *p_oPop;
  clTreeSearch *p_oAllSeedlings;
  clTree *p_oTree;
  clGridBase *p_oSeeds;
  float fX, fY, fXMin, fXMax, fYMin, fYMax,
        fDbh, fValue,
        fXCellLength = 8, fYCellLength = 8;
  int *p_iNumSeedlings = new int[4], i, iSp;

  //Feed our file to the sim manager
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Add our trees
  fX = 4; fY = 4;
  iSp = 0;
  fDbh = 5;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::sapling, fDbh);

  fDbh = 10;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fDbh = 20;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fDbh = 15;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fDbh = 30;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fDbh = 35;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fDbh = 50;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  fDbh = 21;
  p_oPop->CreateTree(fX, fY, iSp, clTreePopulation::adult, fDbh);

  //Add the seeds to the appropriate grid cells
  p_oSeeds = p_oSimManager->GetGridObject("Dispersed Seeds");
  fValue = 10000;
  p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_0"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(4, 4, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);

  //Run a timestep
  p_oSimManager->RunSim(1);

  //Count the number of seedlings in each grid cell
  p_oAllSeedlings = p_oPop->Find("type=1");

  //Check our values for cell 0, 0
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fYMin = 0;
  fYMax = fYCellLength;
  fXMin = 0;
  fXMax = fXCellLength;
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX < fXMax && fY >= fYMin && fY < fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(9902 == p_iNumSeedlings[0] || 9903 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[3]);

  //Check our values for cell 4, 4
  for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
  fXMin = 4 * fXCellLength;
  fXMax = (4 + 1) * fXCellLength;
  fYMin = 4 * fYCellLength;
  fYMax = (4 + 1) * fYCellLength;
  p_oAllSeedlings->StartOver();
  p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
  }
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
  CPPUNIT_ASSERT(29 == p_iNumSeedlings[1] || 30 == p_iNumSeedlings[1]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[2]);
  CPPUNIT_ASSERT(0 == p_iNumSeedlings[3]);

  delete[] p_iNumSeedlings;
}

/////////////////////////////////////////////////////////////////////////////
// TestErrorProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::TestErrorProcessing(clSimManager *p_oSimManager)
{

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNeighborhoodSeedPredation::ReadParameterFileData") == NULL ||
        strstr(err.cMoreInfo, "Minimum neighbor DBH") == NULL)
    {
      CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNeighborhoodSeedPredation::ReadParameterFileData") == NULL ||
        strstr(err.cMoreInfo, "Masting seed density threshold") == NULL)
    {
      CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNeighborhoodSeedPredation::ReadParameterFileData") == NULL ||
        strstr(err.cMoreInfo, "Neighborhood radius") == NULL)
    {
      CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing didn't catch error for WriteXMLErrorFile4.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNeighborhoodSeedPredation::SetupGrids") == NULL ||
        strstr(err.cMoreInfo, "Disperse behavior") == NULL)
    {
      CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing caught wrong error for WriteXMLErrorFile4.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing didn't catch error for WriteXMLErrorFile5.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNeighborhoodSeedPredation::GetData") == NULL ||
        strstr(err.cMoreInfo, "functional response") == NULL)
    {
      CppUnit::Asserter::fail("TestNeighborhoodSeedPredation error processing caught wrong error for WriteXMLErrorFile5.");
    }
    ;
  }
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">4</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">2</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>4</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">15</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>"
       << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">0</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>1</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">2</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>4</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLFile4()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>100</plot_lenX>"
       << "<plot_lenY>100</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  oOut << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "<tr_species speciesName=\"Species_4\"/>"
       << "<tr_species speciesName=\"Species_5\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_5\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_5\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_5\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0614</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0242</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0242</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_5\">0.0242</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_5\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.7059</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_5\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_5\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.368</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.464</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.464</tr_sachVal>"
       << "<tr_sachVal species=\"Species_5\">0.464</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_5\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.0269</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.02871</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.02871</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_5\">0.02871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0263</tr_soahVal>"
       << "<tr_soahVal species=\"Species_5\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_5\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_5\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_5\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_5\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_5\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_5\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_5\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";

  oOut << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_2\">2</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_3\">3</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_4\">4</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>50</ma_lengthXCells>"
       << "<ma_lengthYCells>50</ma_lengthYCells>"
       << "</grid>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_5\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>linked functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Linked Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_5\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_5\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_5\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">2</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_5\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_funcRespMaxInstDeclineRate1Lnk>-0.04</pr_funcRespMaxInstDeclineRate1Lnk>"
       << "<pr_funcRespMaxInstDeclineRate2Lnk>-0.04</pr_funcRespMaxInstDeclineRate2Lnk>"
       << "<pr_funcRespDemographicEfficiency1Lnk>0.0002</pr_funcRespDemographicEfficiency1Lnk>"
       << "<pr_funcRespDemographicEfficiency2Lnk>0.0002</pr_funcRespDemographicEfficiency2Lnk>"
       << "<pr_funcRespDensityDependentCoefficient1Lnk>-0.008</pr_funcRespDensityDependentCoefficient1Lnk>"
       << "<pr_funcRespDensityDependentCoefficient2Lnk>-0.008</pr_funcRespDensityDependentCoefficient2Lnk>"
       << "<pr_funcRespPredatorInitialDensityLnk>0.002</pr_funcRespPredatorInitialDensityLnk>"
       << "<pr_maxIntakeRateLnk>20</pr_maxIntakeRateLnk>"
       << "<pr_funcRespMaxIntakeRateLnk>"
       << "<pr_frmirlVal species=\"Species_1\">20</pr_frmirlVal>"
       << "<pr_frmirlVal species=\"Species_2\">20</pr_frmirlVal>"
       << "<pr_frmirlVal species=\"Species_4\">20</pr_frmirlVal>"
       << "</pr_funcRespMaxIntakeRateLnk>"
       << "<pr_funcRespForagingEfficiencyLnk>"
       << "<pr_frfelVal species=\"Species_1\">0.002</pr_frfelVal>"
       << "<pr_frfelVal species=\"Species_2\">0.002</pr_frfelVal>"
       << "<pr_frfelVal species=\"Species_4\">0.002</pr_frfelVal>"
       << "</pr_funcRespForagingEfficiencyLnk>"
       << "<pr_funcRespWeekSeason2StartsLnk>12</pr_funcRespWeekSeason2StartsLnk>"
       << "<pr_funcRespNumWeeksSeedFallLnk>12</pr_funcRespNumWeeksSeedFallLnk>"
       << "<pr_funcRespNumWeeksToModelLnk>45</pr_funcRespNumWeeksToModelLnk>"
       << "<pr_funcRespWeekGerminationStartsLnk>30</pr_funcRespWeekGerminationStartsLnk>"
       << "<pr_funcRespPreservePredatorDensitiesLnk>0</pr_funcRespPreservePredatorDensitiesLnk>"
       << "<pr_funcRespProportionGerminatingLnk>0.4</pr_funcRespProportionGerminatingLnk>"
       << "<pr_neighPredRadiusLnk>10</pr_neighPredRadiusLnk>"
       << "<pr_neighPredLnkMinNeighDBH>"
       << "<pr_nplmndVal species=\"Species_1\">10</pr_nplmndVal>"
       << "<pr_nplmndVal species=\"Species_2\">10</pr_nplmndVal>"
       << "<pr_nplmndVal species=\"Species_3\">10</pr_nplmndVal>"
       << "<pr_nplmndVal species=\"Species_4\">10</pr_nplmndVal>"
       << "<pr_nplmndVal species=\"Species_5\">10</pr_nplmndVal>"
       << "</pr_neighPredLnkMinNeighDBH>"
       << "<pr_neighPredLnkP0>"
       << "<pr_npmlp0Val species=\"Species_1\">1.32</pr_npmlp0Val>"
       << "<pr_npmlp0Val species=\"Species_2\">0.86</pr_npmlp0Val>"
       << "<pr_npmlp0Val species=\"Species_4\">-0.93</pr_npmlp0Val>"
       << "</pr_neighPredLnkP0>"
       << "<pr_neighPredPnLnkSpecies_1>"
       << "<pr_nppnlVal species=\"Species_1\">-5.94</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_2\">0</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_4\">-4.72</pr_nppnlVal>"
       << "</pr_neighPredPnLnkSpecies_1>"
       << "<pr_neighPredPnLnkSpecies_2>"
       << "<pr_nppnlVal species=\"Species_1\">2.8</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_2\">3.1</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_4\">0.99</pr_nppnlVal>"
       << "</pr_neighPredPnLnkSpecies_2>"
       << "<pr_neighPredPnLnkSpecies_3>"
       << "<pr_nppnlVal species=\"Species_1\">-1.9</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_2\">1.99</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_4\">3.24</pr_nppnlVal>"
       << "</pr_neighPredPnLnkSpecies_3>"
       << "<pr_neighPredPnLnkSpecies_4>"
       << "<pr_nppnlVal species=\"Species_1\">0.00000228</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_2\">0.0255</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_4\">5.93</pr_nppnlVal>"
       << "</pr_neighPredPnLnkSpecies_4>"
       << "<pr_neighPredPnLnkSpecies_5>"
       << "<pr_nppnlVal species=\"Species_1\">0.00000228</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_2\">0.0255</pr_nppnlVal>"
       << "<pr_nppnlVal species=\"Species_4\">5.93</pr_nppnlVal>"
       << "</pr_neighPredPnLnkSpecies_5>"
       << "<pr_neighPredMastingDensity>4</pr_neighPredMastingDensity>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_5\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>"
       << "<pr_neighPredMastingP0>"
       << "<pr_npmp0Val species=\"Species_5\">-2.51</pr_npmp0Val>"
       << "</pr_neighPredMastingP0>"
       << "<pr_neighPredMastingPnSpecies_1>"
       << "<pr_npmpnVal species=\"Species_5\">2.56</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_1>"
       << "<pr_neighPredMastingPnSpecies_2>"
       << "<pr_npmpnVal species=\"Species_5\">4.91</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_2>"
       << "<pr_neighPredMastingPnSpecies_3>"
       << "<pr_npmpnVal species=\"Species_5\">2.66</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_3>"
       << "<pr_neighPredMastingPnSpecies_4>"
       << "<pr_npmpnVal species=\"Species_5\">0.0255</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_4>"
       << "<pr_neighPredMastingPnSpecies_5>"
       << "<pr_npmpnVal species=\"Species_5\">0.0255</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_5>"
       << "<pr_neighPredNonMastingP0>"
       << "<pr_npnmp0Val species=\"Species_5\">-2.3</pr_npnmp0Val>"
       << "</pr_neighPredNonMastingP0>"
       << "<pr_neighPredNonMastingPnSpecies_1>"
       << "<pr_npnmpnVal species=\"Species_5\">3.24</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_1>"
       << "<pr_neighPredNonMastingPnSpecies_2>"
       << "<pr_npnmpnVal species=\"Species_5\">5.93</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_2>"
       << "<pr_neighPredNonMastingPnSpecies_3>"
       << "<pr_npnmpnVal species=\"Species_5\">1.83</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_3>"
       << "<pr_neighPredNonMastingPnSpecies_4>"
       << "<pr_npnmpnVal species=\"Species_5\">13.2</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_4>"
       << "<pr_neighPredNonMastingPnSpecies_5>"
       << "<pr_npnmpnVal species=\"Species_5\">13.2</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_5>"
       << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_5\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLFile5()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>masting non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_nonSpatialMastMastFunction>"
       << "<di_nsmmfVal species=\"Species_1\">3</di_nsmmfVal>"
       << "<di_nsmmfVal species=\"Species_2\">3</di_nsmmfVal>"
       << "<di_nsmmfVal species=\"Species_3\">3</di_nsmmfVal>"
       << "<di_nsmmfVal species=\"Species_4\">3</di_nsmmfVal>"
       << "</di_nonSpatialMastMastFunction>"
       << "<di_nonSpatialNonMastFunction>"
       << "<di_nsnmfVal species=\"Species_1\">3</di_nsnmfVal>"
       << "<di_nsnmfVal species=\"Species_2\">3</di_nsnmfVal>"
       << "<di_nsnmfVal species=\"Species_3\">3</di_nsnmfVal>"
       << "<di_nsnmfVal species=\"Species_4\">3</di_nsnmfVal>"
       << "</di_nonSpatialNonMastFunction>"
       << "<di_nonSpatialMastBinomialP>"
       << "<di_nsmbpVal species=\"Species_1\">0</di_nsmbpVal>"
       << "<di_nsmbpVal species=\"Species_2\">0</di_nsmbpVal>"
       << "<di_nsmbpVal species=\"Species_3\">0</di_nsmbpVal>"
       << "<di_nsmbpVal species=\"Species_4\">0</di_nsmbpVal>"
       << "</di_nonSpatialMastBinomialP>"
       << "<di_nonSpatialMastNormalMean>"
       << "<di_nsmnmVal species=\"Species_1\">1</di_nsmnmVal>"
       << "<di_nsmnmVal species=\"Species_2\">4</di_nsmnmVal>"
       << "<di_nsmnmVal species=\"Species_3\">2</di_nsmnmVal>"
       << "<di_nsmnmVal species=\"Species_4\">1</di_nsmnmVal>"
       << "</di_nonSpatialMastNormalMean>"
       << "<di_nonSpatialMastNormalStdDev>"
       << "<di_nsmnsdVal species=\"Species_1\">0</di_nsmnsdVal>"
       << "<di_nsmnsdVal species=\"Species_2\">0</di_nsmnsdVal>"
       << "<di_nsmnsdVal species=\"Species_3\">0</di_nsmnsdVal>"
       << "<di_nsmnsdVal species=\"Species_4\">0</di_nsmnsdVal>"
       << "</di_nonSpatialMastNormalStdDev>"
       << "<di_nonSpatialNonMastNormalMean>"
       << "<di_nsnmnmVal species=\"Species_1\">1</di_nsnmnmVal>"
       << "<di_nsnmnmVal species=\"Species_2\">4</di_nsnmnmVal>"
       << "<di_nsnmnmVal species=\"Species_3\">2</di_nsnmnmVal>"
       << "<di_nsnmnmVal species=\"Species_4\">1</di_nsnmnmVal>"
       << "</di_nonSpatialNonMastNormalMean>"
       << "<di_nonSpatialNonMastNormalStdDev>"
       << "<di_nsnmnsdVal species=\"Species_1\">0</di_nsnmnsdVal>"
       << "<di_nsnmnsdVal species=\"Species_2\">0</di_nsnmnsdVal>"
       << "<di_nsnmnsdVal species=\"Species_3\">0</di_nsnmnsdVal>"
       << "<di_nsnmnsdVal species=\"Species_4\">0</di_nsnmnsdVal>"
       << "</di_nonSpatialNonMastNormalStdDev>"
       << "<di_nonSpatialMastGroup>"
       << "<di_nsmgVal species=\"Species_1\">1</di_nsmgVal>"
       << "<di_nsmgVal species=\"Species_2\">2</di_nsmgVal>"
       << "<di_nsmgVal species=\"Species_3\">3</di_nsmgVal>"
       << "<di_nsmgVal species=\"Species_4\">5</di_nsmgVal>"
       << "</di_nonSpatialMastGroup>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredMastDecisionMethod>1</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>4</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">15</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>"
       << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">0</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLFile6()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>masting spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_mastCDFA>"
       << "<di_mcdfaVal species=\"Species_1\">0.00001</di_mcdfaVal>"
       << "<di_mcdfaVal species=\"Species_2\">1000</di_mcdfaVal>"
       << "<di_mcdfaVal species=\"Species_3\">1000</di_mcdfaVal>"
       << "<di_mcdfaVal species=\"Species_4\">1000</di_mcdfaVal>"
       << "</di_mastCDFA>"
       << "<di_mastCDFB>"
       << "<di_mcdfbVal species=\"Species_1\">-5</di_mcdfbVal>"
       << "<di_mcdfbVal species=\"Species_2\">-5</di_mcdfbVal>"
       << "<di_mcdfbVal species=\"Species_3\">-5</di_mcdfbVal>"
       << "<di_mcdfbVal species=\"Species_4\">-5</di_mcdfbVal>"
       << "</di_mastCDFB>"
       << "<di_mastSTRPDF>"
       << "<di_mstrpdfVal species=\"Species_1\">0</di_mstrpdfVal>"
       << "<di_mstrpdfVal species=\"Species_2\">0</di_mstrpdfVal>"
       << "<di_mstrpdfVal species=\"Species_3\">0</di_mstrpdfVal>"
       << "<di_mstrpdfVal species=\"Species_4\">0</di_mstrpdfVal>"
       << "</di_mastSTRPDF>"
       << "<di_spatialSTR>"
       << "<di_sstrVal species=\"Species_1\">0</di_sstrVal>"
       << "<di_sstrVal species=\"Species_2\">0</di_sstrVal>"
       << "<di_sstrVal species=\"Species_3\">0</di_sstrVal>"
       << "<di_sstrVal species=\"Species_4\">0</di_sstrVal>"
       << "</di_spatialSTR>"
       << "<di_spatialSTRStdDev>"
       << "<di_sstrsdVal species=\"Species_1\">0</di_sstrsdVal>"
       << "<di_sstrsdVal species=\"Species_2\">0</di_sstrsdVal>"
       << "<di_sstrsdVal species=\"Species_3\">0</di_sstrsdVal>"
       << "<di_sstrsdVal species=\"Species_4\">0</di_sstrsdVal>"
       << "</di_spatialSTRStdDev>"
       << "<di_mastingSTR>"
       << "<di_mstrVal species=\"Species_1\">0</di_mstrVal>"
       << "<di_mstrVal species=\"Species_2\">0</di_mstrVal>"
       << "<di_mstrVal species=\"Species_3\">0</di_mstrVal>"
       << "<di_mstrVal species=\"Species_4\">0</di_mstrVal>"
       << "</di_mastingSTR>"
       << "<di_mastingSTRStdDev>"
       << "<di_mstrsdVal species=\"Species_1\">0</di_mstrsdVal>"
       << "<di_mstrsdVal species=\"Species_2\">0</di_mstrsdVal>"
       << "<di_mstrsdVal species=\"Species_3\">0</di_mstrsdVal>"
       << "<di_mstrsdVal species=\"Species_4\">0</di_mstrsdVal>"
       << "</di_mastingSTRStdDev>"
       << "<di_spatialBeta>"
       << "<di_sbVal species=\"Species_1\">1</di_sbVal>"
       << "<di_sbVal species=\"Species_2\">3.5</di_sbVal>"
       << "<di_sbVal species=\"Species_3\">3.5</di_sbVal>"
       << "<di_sbVal species=\"Species_4\">2</di_sbVal>"
       << "</di_spatialBeta>"
       << "<di_mastingBeta>"
       << "<di_mbVal species=\"Species_1\">2</di_mbVal>"
       << "<di_mbVal species=\"Species_2\">2.5</di_mbVal>"
       << "<di_mbVal species=\"Species_3\">2.5</di_mbVal>"
       << "<di_mbVal species=\"Species_4\">1</di_mbVal>"
       << "</di_mastingBeta>"
       << "<di_canopyFunction>"
       << "<di_cfVal species=\"Species_1\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_2\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_3\">0</di_cfVal>"
       << "<di_cfVal species=\"Species_4\">0</di_cfVal>"
       << "</di_canopyFunction>"
       << "<di_weibullCanopyDispersal>"
       << "<di_wcdVal species=\"Species_1\">1.76E-04</di_wcdVal>"
       << "<di_wcdVal species=\"Species_2\">1.82E-04</di_wcdVal>"
       << "<di_wcdVal species=\"Species_3\">1.82E-04</di_wcdVal>"
       << "<di_wcdVal species=\"Species_4\">9.61E-05</di_wcdVal>"
       << "</di_weibullCanopyDispersal>"
       << "<di_weibullCanopyTheta>"
       << "<di_wctVal species=\"Species_1\">3</di_wctVal>"
       << "<di_wctVal species=\"Species_2\">3</di_wctVal>"
       << "<di_wctVal species=\"Species_3\">3</di_wctVal>"
       << "<di_wctVal species=\"Species_4\">3</di_wctVal>"
       << "</di_weibullCanopyTheta>"
       << "<di_weibullMastingDispersal>"
       << "<di_wmdVal species=\"Species_1\">1.76E-04</di_wmdVal>"
       << "<di_wmdVal species=\"Species_2\">1.82E-04</di_wmdVal>"
       << "<di_wmdVal species=\"Species_3\">1.82E-04</di_wmdVal>"
       << "<di_wmdVal species=\"Species_4\">9.61E-05</di_wmdVal>"
       << "</di_weibullMastingDispersal>"
       << "<di_weibullMastingTheta>"
       << "<di_wmtVal species=\"Species_1\">3</di_wmtVal>"
       << "<di_wmtVal species=\"Species_2\">3</di_wmtVal>"
       << "<di_wmtVal species=\"Species_3\">3</di_wmtVal>"
       << "<di_wmtVal species=\"Species_4\">3</di_wmtVal>"
       << "</di_weibullMastingTheta>"
       << "<di_mastGroup>"
       << "<di_mgVal species=\"Species_1\">1</di_mgVal>"
       << "<di_mgVal species=\"Species_2\">2</di_mgVal>"
       << "<di_mgVal species=\"Species_3\">2</di_mgVal>"
       << "<di_mgVal species=\"Species_4\">1</di_mgVal>"
       << "</di_mastGroup>"
       << "<di_mastDrawPerSpecies>"
       << "<di_mdpsVal species=\"Species_1\">0</di_mdpsVal>"
       << "<di_mdpsVal species=\"Species_2\">0</di_mdpsVal>"
       << "<di_mdpsVal species=\"Species_3\">0</di_mdpsVal>"
       << "<di_mdpsVal species=\"Species_4\">0</di_mdpsVal>"
       << "</di_mastDrawPerSpecies>"
       << "<di_mastPropParticipating>"
       << "<di_mppVal species=\"Species_1\">1</di_mppVal>"
       << "<di_mppVal species=\"Species_2\">1</di_mppVal>"
       << "<di_mppVal species=\"Species_3\">1</di_mppVal>"
       << "<di_mppVal species=\"Species_4\">1</di_mppVal>"
       << "</di_mastPropParticipating>"
       << "<di_spatialPropParticipating>"
       << "<di_sppVal species=\"Species_1\">1</di_sppVal>"
       << "<di_sppVal species=\"Species_2\">1</di_sppVal>"
       << "<di_sppVal species=\"Species_3\">1</di_sppVal>"
       << "<di_sppVal species=\"Species_4\">1</di_sppVal>"
       << "</di_spatialPropParticipating>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>1</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>"
       << "<pr_neighPredMastingP0>"
       << "<pr_npmp0Val species=\"Species_1\">1.32</pr_npmp0Val>"
       << "<pr_npmp0Val species=\"Species_2\">0.86</pr_npmp0Val>"
       << "<pr_npmp0Val species=\"Species_4\">-0.93</pr_npmp0Val>"
       << "</pr_neighPredMastingP0>"
       << "<pr_neighPredMastingPnSpecies_1>"
       << "<pr_npmpnVal species=\"Species_1\">-5.94</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">0</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">-4.72</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_1>"
       << "<pr_neighPredMastingPnSpecies_2>"
       << "<pr_npmpnVal species=\"Species_1\">2.8</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">3.1</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">0.99</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_2>"
       << "<pr_neighPredMastingPnSpecies_3>"
       << "<pr_npmpnVal species=\"Species_1\">-1.9</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">1.99</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">3.24</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_3>"
       << "<pr_neighPredMastingPnSpecies_4>"
       << "<pr_npmpnVal species=\"Species_1\">0.00000228</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">0.0255</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">5.93</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_4>"
       << "<pr_neighPredNonMastingP0>"
       << "<pr_npnmp0Val species=\"Species_1\">-2.51</pr_npnmp0Val>"
       << "<pr_npnmp0Val species=\"Species_2\">-1.36</pr_npnmp0Val>"
       << "<pr_npnmp0Val species=\"Species_4\">-99</pr_npnmp0Val>"
       << "</pr_neighPredNonMastingP0>"
       << "<pr_neighPredNonMastingPnSpecies_1>"
       << "<pr_npnmpnVal species=\"Species_1\">2.56</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">0.23</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">3.24</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_1>"
       << "<pr_neighPredNonMastingPnSpecies_2>"
       << "<pr_npnmpnVal species=\"Species_1\">4.91</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">1.9</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">5.93</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_2>"
       << "<pr_neighPredNonMastingPnSpecies_3>"
       << "<pr_npnmpnVal species=\"Species_1\">2.66</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">-7.49</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">1.83</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_3>"
       << "<pr_neighPredNonMastingPnSpecies_4>"
       << "<pr_npnmpnVal species=\"Species_1\">0.0255</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">0.00569</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">13.2</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_4>"
       << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}



/////////////////////////////////////////////////////////////////////////////
// WriteTreesAllometry()
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::WriteTreesAllometry(std::fstream &oOut)
{
  oOut << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "<tr_species speciesName=\"Species_4\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.54</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0614</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0242</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0242</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.5944</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7059</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.7059</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.368</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.464</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.464</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.0269</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.02871</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.02871</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0241</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0263</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0263</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLErrorFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLErrorFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">2</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>4</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">-10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLErrorFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLErrorFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">2</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>-4</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLErrorFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLErrorFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">2</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>4</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>-10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLErrorFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLErrorFile4()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>4</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLErrorFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLErrorFile5()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>100</plot_lenX>"
       << "<plot_lenY>100</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  oOut << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Linked Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>"
       << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_predatorInitialDensity>0.002</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.04</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.0002</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.008</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>20</pr_maxIntakeRate>"
       << "<pr_foragingEfficiency>0.002</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>"
       << "<pr_numWeeksToModel>45</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>30</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.4</pr_proportionGerminating>"
       << "<pr_neighPredRadiusLnk>10</pr_neighPredRadiusLnk>"
       << "<pr_neighPredLnkMinNeighDBH>"
       << "<pr_nplmndVal species=\"Species_1\">10</pr_nplmndVal>"
       << "</pr_neighPredLnkMinNeighDBH>"
       << "<pr_neighPredLnkP0>"
       << "<pr_npmlp0Val species=\"Species_1\">1.32</pr_npmlp0Val>"
       << "</pr_neighPredLnkP0>"
       << "<pr_neighPredPnLnkSpecies_1>"
       << "<pr_nppnlVal species=\"Species_1\">-5.94</pr_nppnlVal>"
       << "</pr_neighPredPnLnkSpecies_1>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile7()
/////////////////////////////////////////////////////////////////////////////
char * clTestNeighborhoodSeedPredation::WriteXMLFile7()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>96</plot_lenX>"
       << "<plot_lenY>96</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>";

  WriteTreesAllometry(oOut);

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Neighborhood Seed Predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">1</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">4</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">2</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_4\">1</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<seedPredation>";

  WriteCommonPredationParameters(oOut);

  oOut << "<pr_neighPredMastDecisionMethod>0</pr_neighPredMastDecisionMethod>"
       << "<pr_neighPredMastingDensity>1</pr_neighPredMastingDensity>"
       << "<pr_neighPredRadius>10</pr_neighPredRadius>"
       << "<pr_neighPredMinNeighDBH>"
       << "<pr_npmndVal species=\"Species_1\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_2\">10</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_3\">15</pr_npmndVal>"
       << "<pr_npmndVal species=\"Species_4\">10</pr_npmndVal>"
       << "</pr_neighPredMinNeighDBH>"
       << "<pr_neighPredCounts4Mast>"
       << "<pr_npc4mVal species=\"Species_1\">1</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_2\">0</pr_npc4mVal>"
       << "<pr_npc4mVal species=\"Species_4\">1</pr_npc4mVal>"
       << "</pr_neighPredCounts4Mast>"
       << "</seedPredation>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteCommonPredationParameters
/////////////////////////////////////////////////////////////////////////////
void clTestNeighborhoodSeedPredation::WriteCommonPredationParameters(std::fstream &oOut)
{
  oOut << "<pr_neighPredMastingP0>"
       << "<pr_npmp0Val species=\"Species_1\">1.32</pr_npmp0Val>"
       << "<pr_npmp0Val species=\"Species_2\">0.86</pr_npmp0Val>"
       << "<pr_npmp0Val species=\"Species_4\">-0.93</pr_npmp0Val>"
       << "</pr_neighPredMastingP0>"
       << "<pr_neighPredMastingPnSpecies_1>"
       << "<pr_npmpnVal species=\"Species_1\">-5.94</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">0</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">-4.72</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_1>"
       << "<pr_neighPredMastingPnSpecies_2>"
       << "<pr_npmpnVal species=\"Species_1\">2.8</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">3.1</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">0.99</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_2>"
       << "<pr_neighPredMastingPnSpecies_3>"
       << "<pr_npmpnVal species=\"Species_1\">-1.9</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">1.99</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">3.24</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_3>"
       << "<pr_neighPredMastingPnSpecies_4>"
       << "<pr_npmpnVal species=\"Species_1\">0.00000228</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_2\">0.0255</pr_npmpnVal>"
       << "<pr_npmpnVal species=\"Species_4\">5.93</pr_npmpnVal>"
       << "</pr_neighPredMastingPnSpecies_4>"
       << "<pr_neighPredNonMastingP0>"
       << "<pr_npnmp0Val species=\"Species_1\">-2.51</pr_npnmp0Val>"
       << "<pr_npnmp0Val species=\"Species_2\">-1.36</pr_npnmp0Val>"
       << "<pr_npnmp0Val species=\"Species_4\">-99</pr_npnmp0Val>"
       << "</pr_neighPredNonMastingP0>"
       << "<pr_neighPredNonMastingPnSpecies_1>"
       << "<pr_npnmpnVal species=\"Species_1\">2.56</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">0.23</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">3.24</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_1>"
       << "<pr_neighPredNonMastingPnSpecies_2>"
       << "<pr_npnmpnVal species=\"Species_1\">4.91</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">1.9</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">5.93</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_2>"
       << "<pr_neighPredNonMastingPnSpecies_3>"
       << "<pr_npnmpnVal species=\"Species_1\">2.66</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">-7.49</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">1.83</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_3>"
       << "<pr_neighPredNonMastingPnSpecies_4>"
       << "<pr_npnmpnVal species=\"Species_1\">0.0255</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_2\">0.00569</pr_npnmpnVal>"
       << "<pr_npnmpnVal species=\"Species_4\">13.2</pr_npnmpnVal>"
       << "</pr_neighPredNonMastingPnSpecies_4>";
}
