//---------------------------------------------------------------------------
// TestNonSpatialDispersal
//---------------------------------------------------------------------------
#if !defined(TestNonSpatialDispersal_H)
  #define TestNonSpatialDispersal_H

  #include <cppunit/TestFixture.h>
  #include <cppunit/TestCaller.h>

  class clSimManager;

  /**
   * This class tests the non-spatial dispersal behavior.  It writes out
   * parameter files and uses them as input to perform setup; it then sets up
   * the desired initial conditions, causes the behavior to run, then tests its
   * output.  There will be two normal processing runs.  Both use deterministic
   * seed numbers, which should equal the expected mean +- 1.
   */
  class clTestNonSpatialDispersal : public CppUnit::TestFixture
  {

  public:

  /**
  * Rolls together all the non-spatial dispersal tests.
  */
  void TestNonSpatialDispersal();

  private:

  /**
   * Tests non-spatial dispersal, run 1.  It will cause a parameter file to be 
   * written and then passed to a clSimManager object.  That object will read 
   * it. Then the non-spatial dispersal behavior is run. The number of 
   * seedlings per grid cell is compared with expected values.
   * @param p_oSimManager Sim manager to direct testing.
   */
  void TestNonSpatialDispersal1(clSimManager *p_oSimManager);

  /**
   * Tests non-spatial dispersal, run 2.  It will cause a parameter file to be 
   * written and then passed to a clSimManager object.  That object will read 
   * it. Then the non-spatial dispersal behavior is run. The number of seeds 
   * per grid cell is compared with expected values.
   * @param p_oSimManager Sim manager to direct testing.
   */
  void TestNonSpatialDispersal2(clSimManager *p_oSimManager);

  /**
   * Writes a parameter file to direct testing using the first set of testing
   * conditions. This contains all tree information and disperse information.
   * It also has a tree map so we'll be dealing with a known list of trees. The
   * timestep length is 1 year.
   * @return Filename written.
   */
  char * WriteXMLFile1();

  /**
   * Writes a parameter file to direct testing using the second set of testing
   * conditions (same as the first set, just different number of years per
   * timestep). This contains all tree information and disperse information. It
   * also has a tree map so we'll be dealing with a known list of trees.  The
   * timestep length is three years.
   * @return Filename written.
   */
  char * WriteXMLFile2();
};
//---------------------------------------------------------------------------
#endif // TestNonSpatialDispersal_H
