//---------------------------------------------------------------------------
// TestPuertoRicoEstablishment.cpp
//---------------------------------------------------------------------------
#include "TestPuertoRicoEstablishment.h"

#include "SimManager.h"
#include "GridBase.h"
#include "TreePopulation.h"
#include <fstream>

/////////////////////////////////////////////////////////////////////////////
//  TestPuertoRicoEstablishment()
/////////////////////////////////////////////////////////////////////////////
void clTestPuertoRicoEstablishment::TestPuertoRicoEstablishment() {
  clSimManager * p_oSimManager = new clSimManager(3, 3, "");

  TestErrorProcessing(p_oSimManager);

  TestNormalProcessing(p_oSimManager);

  delete p_oSimManager;
}

/////////////////////////////////////////////////////////////////////////////
//  TestNormalProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestPuertoRicoEstablishment::TestNormalProcessing(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clGridBase *p_oSeeds;
  clTreeSearch *p_oAllSeedlings;
  clTree *p_oTree;
  float fValue, fX, fY, fXMin, fXMax, fYMin, fYMax;
  int *p_iNumSeedlings = new int[4], i, iDamage;

  //Set up the run
  p_oSimManager->ReadFile(WriteXMLFile1());
  p_oTemp = p_oSimManager->GetPopulationObject("treepopulation");
  p_oPop = (clTreePopulation *) p_oTemp;

  //Add in our tree neighbors and set the damage level for each
  iDamage = 0;
  p_oTree = p_oPop->CreateTree(4, 4, 3, clTreePopulation::adult, 8);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTree->GetSpecies(),
                                                  p_oTree->GetType()),
                           iDamage);

  iDamage = 0;
  p_oTree = p_oPop->CreateTree(116, 4, 1, clTreePopulation::adult, 8);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                              p_oTree->GetSpecies(),
                                              p_oTree->GetType()),
                           iDamage);

  iDamage = 2004;
  p_oTree = p_oPop->CreateTree(168, 2, 1, clTreePopulation::adult, 45);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTree->GetSpecies(),
                                                  p_oTree->GetType()),
                           iDamage);

  iDamage = 1004;
  p_oTree = p_oPop->CreateTree(228, 4, 2, clTreePopulation::adult, 8);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTree->GetSpecies(),
                                                  p_oTree->GetType()),
                           iDamage);

  iDamage = 1004;
  p_oTree = p_oPop->CreateTree(284, 4, 3, clTreePopulation::adult, 8);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTree->GetSpecies(),
                                                  p_oTree->GetType()),
                           iDamage);

  iDamage = 2004;
  p_oTree = p_oPop->CreateTree(340, 4, 3, clTreePopulation::adult, 8);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTree->GetSpecies(),
                                                  p_oTree->GetType()),
                           iDamage);

  iDamage = 1004;
  p_oTree = p_oPop->CreateTree(396, 4, 1, clTreePopulation::adult, 8);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTree->GetSpecies(),
                                                  p_oTree->GetType()),
                           iDamage);

  iDamage = 0;
  p_oTree = p_oPop->CreateTree(452, 4, 2, clTreePopulation::adult, 8);
  p_oTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTree->GetSpecies(),
                                                  p_oTree->GetType()),
                           iDamage);

  //Add the seeds to the appropriate grid cells
  p_oSeeds = p_oSimManager->GetGridObject("Dispersed Seeds");
  fValue = 100;
  p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(0, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 300;
  p_oSeeds->SetValueOfCell(7, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(7, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(7, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 100;
  p_oSeeds->SetValueOfCell(14, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(14, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(14, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 300;
  p_oSeeds->SetValueOfCell(21, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(21, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(21, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 100;
  p_oSeeds->SetValueOfCell(28, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(28, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(28, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 200;
  p_oSeeds->SetValueOfCell(35, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(35, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(35, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 300;
  p_oSeeds->SetValueOfCell(42, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(42, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(42, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 100;
  p_oSeeds->SetValueOfCell(49, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 200;
  p_oSeeds->SetValueOfCell(49, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(49, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  fValue = 200;
  p_oSeeds->SetValueOfCell(56, 0, p_oSeeds->GetFloatDataCode("seeds_1"), fValue);
  fValue = 300;
  p_oSeeds->SetValueOfCell(56, 0, p_oSeeds->GetFloatDataCode("seeds_2"), fValue);
  fValue = 100;
  p_oSeeds->SetValueOfCell(56, 0, p_oSeeds->GetFloatDataCode("seeds_3"), fValue);

  //Run the run
  p_oSimManager->RunSim(1);

  //Count the seedlings
  p_oAllSeedlings = p_oPop->Find("type=1");

 //Check our values for cell 0, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fYMin = 0;
 fYMax = 8;
 fXMin = 0 * 8;
 fXMax = (0 + 1) * 8;
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(20 == p_iNumSeedlings[1] || 21 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(23 == p_iNumSeedlings[2] || 24 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(101 == p_iNumSeedlings[3] || 100 == p_iNumSeedlings[3]);

 //Check our values for cell 7, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 7 * 8;
 fXMax = (7 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(232 == p_iNumSeedlings[1] || 231 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(68 == p_iNumSeedlings[2] || 67 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(79 == p_iNumSeedlings[3] || 80 == p_iNumSeedlings[3]);

 //Check our values for cell 14, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 14 * 8;
 fXMax = (14 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(83 == p_iNumSeedlings[1] || 82 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(54 == p_iNumSeedlings[2] || 55 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(158 == p_iNumSeedlings[3] || 157 == p_iNumSeedlings[3]);

 //Check our values for cell 21, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 21 * 8;
 fXMax = (21 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(235 == p_iNumSeedlings[1] || 236 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(72 == p_iNumSeedlings[2] || 71 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(90 == p_iNumSeedlings[3] || 91 == p_iNumSeedlings[3]);

 //Check our values for cell 28, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 28 * 8;
 fXMax = (28 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(87 == p_iNumSeedlings[1] || 86 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(101 == p_iNumSeedlings[2] || 100 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(243 == p_iNumSeedlings[3] || 244 == p_iNumSeedlings[3]);

 //Check our values for cell 35, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 35 * 8;
 fXMax = (35 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(171 == p_iNumSeedlings[1] || 170 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(176 == p_iNumSeedlings[2] || 175 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(78 == p_iNumSeedlings[3] || 77 == p_iNumSeedlings[3]);

 //Check our values for cell 42, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 42 * 8;
 fXMax = (42 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(260 == p_iNumSeedlings[1] || 261 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(54 == p_iNumSeedlings[2] || 53 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(170 == p_iNumSeedlings[3] || 169 == p_iNumSeedlings[3]);

 //Check our values for cell 49, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 49 * 8;
 fXMax = (49 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(92 == p_iNumSeedlings[1] || 93 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(59 == p_iNumSeedlings[2] || 58 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(166 == p_iNumSeedlings[3] || 167 == p_iNumSeedlings[3]);

 //Check our values for cell 56, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 56 * 8;
 fXMax = (56 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(159 == p_iNumSeedlings[1] || 160 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(239 == p_iNumSeedlings[2] || 240 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(51 == p_iNumSeedlings[3] || 52 == p_iNumSeedlings[3]);

 //Check our values for cell 1, 0
 for (i = 0; i < 4; i++) {
    p_iNumSeedlings[i] = 0;
  }
 fXMin = 1 * 8;
 fXMax = (1 + 1) * 8;
 p_oAllSeedlings->StartOver();
 p_oTree = p_oAllSeedlings->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    p_oTree->GetValue(p_oPop->GetYCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fY);
    if (fX >= fXMin && fX <= fXMax && fY >= fYMin && fY <= fYMax) {
      p_iNumSeedlings[p_oTree->GetSpecies()]++;
    }
    p_oTree = p_oAllSeedlings->NextTree();
 }
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[0]);
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[1]);
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[2]);
 CPPUNIT_ASSERT(0 == p_iNumSeedlings[3]);

 delete[] p_iNumSeedlings;

}

////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestPuertoRicoEstablishment::TestErrorProcessing(clSimManager *p_oSimManager) {

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clPuertoRicoEstablishment::GetParameterFileData") == NULL)
    {
      CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clPuertoRicoEstablishment::GetParameterFileData") == NULL)
    {
      CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clPuertoRicoEstablishment::GetParameterFileData") == NULL)
    {
      CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing didn't catch error for WriteXMLErrorFile4.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clPuertoRicoEstablishment::SetupGrid") == NULL)
    {
      CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing caught wrong error for WriteXMLErrorFile4.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing didn't catch error for WriteXMLErrorFile5.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clPuertoRicoEstablishment::GetTreeMemberCodes") == NULL)
    {
      CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing caught wrong error for WriteXMLErrorFile5.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile6());
    CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing didn't catch error for WriteXMLErrorFile9.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clPuertoRicoEstablishment::GetParameterFileData") == NULL)
    {
      CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing caught wrong error for WriteXMLErrorFile9.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile7());
    CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing didn't catch error for WriteXMLErrorFile10.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clPuertoRicoEstablishment::GetParameterFileData") == NULL)
    {
      CppUnit::Asserter::fail("TestPuertoRicoEstablishment error processing caught wrong error for WriteXMLErrorFile10.");
    }
    ;
  }
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLFile1() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  WriteCommonStuff(oOut);

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">55.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">0.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestPuertoRicoEstablishment::WriteCommonStuff( std::fstream &oOut )
{
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>500.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "</trees>"
       << "<allometry>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.8</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.8</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.8</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.8</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>PR establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>" << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>" << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>" << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>" << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>" << "<st_stochasticity>0</st_stochasticity>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "<st_mdVal species=\"Species_3\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_4\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "<st_sdimVal species=\"Species_3\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_4\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "<st_sdifVal species=\"Species_3\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_4\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "<st_sicVal species=\"Species_3\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_4\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "<st_sdcVal species=\"Species_3\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_4\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_3\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_4\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_3\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_4\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>";

  oOut << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_4\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLErrorFile1() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  WriteCommonStuff(oOut);

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">55.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">1.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLErrorFile2() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  WriteCommonStuff(oOut);

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">55.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>-2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">0.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLErrorFile3() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  WriteCommonStuff(oOut);

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">155.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">0.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLErrorFile4() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>500.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "</trees>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>PR establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>" << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>" << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>" << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>" << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>" << "<st_stochasticity>0</st_stochasticity>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "<st_mdVal species=\"Species_3\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_4\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "<st_sdimVal species=\"Species_3\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_4\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "<st_sdifVal species=\"Species_3\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_4\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "<st_sicVal species=\"Species_3\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_4\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "<st_sdcVal species=\"Species_3\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_4\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_3\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_4\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_3\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_4\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>";

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">55.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">0.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile5()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLErrorFile5() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>500.0</plot_lenX>"
       << "<plot_lenY>100.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "</trees>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>PR establishment</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>";

  oOut << "<disperse>"
       << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_4\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_2\">15.0</di_mdfrVal>"
       << "<di_mdfrVal species=\"Species_3\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_4\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_2\">0</di_nssolVal>"
       << "<di_nssolVal species=\"Species_3\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_4\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_2\">0</di_nsiolVal>"
       << "<di_nsiolVal species=\"Species_3\">0</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>";

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">55.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">0.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile6()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLErrorFile6() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  WriteCommonStuff(oOut);

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">55.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">0.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>0</li_numAltGrids>"
       << "<li_numAziGrids>18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile7()
////////////////////////////////////////////////////////////////////////////
char* clTestPuertoRicoEstablishment::WriteXMLErrorFile7() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  WriteCommonStuff(oOut);

  oOut << "<establishment>"
       << "<es_prOptimumGLI>"
       << "<es_pogVal species=\"Species_2\">23</es_pogVal>"
       << "<es_pogVal species=\"Species_3\">87</es_pogVal>"
       << "<es_pogVal species=\"Species_4\">55.66</es_pogVal>"
       << "</es_prOptimumGLI>"
       << "<es_prLowSlope>"
       << "<es_plsVal species=\"Species_2\">0.034</es_plsVal>"
       << "<es_plsVal species=\"Species_3\">0.0098</es_plsVal>"
       << "<es_plsVal species=\"Species_4\">0.011</es_plsVal>"
       << "</es_prLowSlope>"
       << "<es_prHighSlope>"
       << "<es_phsVal species=\"Species_2\">0.0023</es_phsVal>"
       << "<es_phsVal species=\"Species_3\">0.0098</es_phsVal>"
       << "<es_phsVal species=\"Species_4\">0.012</es_phsVal>"
       << "</es_prHighSlope>"
       << "<es_prLightHeight>2</es_prLightHeight>"
       << "<es_prDensDepSlope>"
       << "<es_pddsVal species=\"Species_2\">0.2</es_pddsVal>"
       << "<es_pddsVal species=\"Species_3\">0.4</es_pddsVal>"
       << "<es_pddsVal species=\"Species_4\">0.8</es_pddsVal>"
       << "</es_prDensDepSlope>"
       << "<es_prDensDepSteepness>"
       << "<es_pddstVal species=\"Species_2\">-0.2</es_pddstVal>"
       << "<es_pddstVal species=\"Species_3\">-0.1</es_pddstVal>"
       << "<es_pddstVal species=\"Species_4\">-0.3</es_pddstVal>"
       << "</es_prDensDepSteepness>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.2</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.87</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<es_prLightExtCoeffPartDmg>"
       << "<es_plecpdVal species=\"Species_1\">0.2</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_2\">0.23</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_3\">0.5</es_plecpdVal>"
       << "<es_plecpdVal species=\"Species_4\">0.6</es_plecpdVal>"
       << "</es_prLightExtCoeffPartDmg>"
       << "<es_prLightExtCoeffFullDmg>"
       << "<es_plecfdVal species=\"Species_1\">0.2</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_2\">0.8</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_3\">0.9</es_plecfdVal>"
       << "<es_plecfdVal species=\"Species_4\">0.5566</es_plecfdVal>"
       << "</es_prLightExtCoeffFullDmg>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>105</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>258</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_numAltGrids>12</li_numAltGrids>"
       << "<li_numAziGrids>-18</li_numAziGrids>"
       << "</establishment>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}
