//---------------------------------------------------------------------------
// TestRipleysKCalculator
//---------------------------------------------------------------------------
#if !defined(TestRipleysKCalculator_H)
  #define TestRipleysKCalculator_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;
class clTreePopulation;
class clGridBase;
class clPlot;

/**
* Tests the class clRipleysKCalculator.
*/
class clTestRipleysKCalculator : public CppUnit::TestFixture {

  public:

  /**
  * Performs all the tests from one function.
  */
  void TestRipleysKCalculator();

  protected:

  /**
  * Tests normal processing, run 1. WriteXMLFile1() does setup. Several
  * trees are created and the Ripley's K calculated.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Tests normal processing, run 2. WriteXMLFile2() does setup. Several
  * trees are created and the Ripley's K calculated.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestNormalProcessingRun2(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing, run 3. WriteXMLFile3() does setup. Several
  * trees are created and the Ripley's K calculated.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestNormalProcessingRun3(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing, run 4. WriteXMLFile4() does setup. Several
  * trees are created and the Ripley's K calculated.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestNormalProcessingRun4(clSimManager *p_oSimManager);

  /**
  * Tests error processing.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);
  
  /**
   * Creates the set of testing trees.
   * @param p_oPop Tree population
   * @param p_oPlot Plot object
   * @param fOffset Any offset to be applied to the tree coordinates
   */
  void CreateTrees(clTreePopulation *p_oPop, clPlot *p_oPlot, float fOffset);
  
  /**
   * Checks the results of the Ripley's K grid for the first run.
   * @param p_oGrid Ripley's K grid.
   */
  void CheckRun1Results(clGridBase *p_oGrid);

  /**
  * Writes the parameter file for normal processing. There are 4 species;
  * timestep length is 1 year; there is only one behavior, the Ripley's K
  * calculator behavior.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes the parameter file for normal processing. There are 4 species;
  * timestep length is 1 year; there is only one behavior, the Ripley's K
  * calculator behavior.
  * @return Filename written.
  */
  char* WriteXMLFile2();
  
  /**
  * Writes the parameter file for normal processing. There are 4 species;
  * timestep length is 1 year; there is only one behavior, the Ripley's K
  * calculator behavior.
  * @return Filename written.
  */
  char* WriteXMLFile3();
  
  /**
  * Writes the parameter file for normal processing. There are 4 species;
  * timestep length is 1 year; there is only one behavior, the Ripley's K
  * calculator behavior.
  * @return Filename written.
  */
  char* WriteXMLFile4();

  /**
  * Writes an error file where the max distance is less than the increment.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();
  
  /**
  * Writes an error file where the max distance is less than zero.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();
  
  /**
  * Writes an error file where the increment is less than zero.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();
  
  /**
  * Writes common portions of the test parameter files between the plot and
  * the analysis parameters.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);
};
//---------------------------------------------------------------------------
#endif // TestRipleysKCalculator_H
