//---------------------------------------------------------------------------
// TestStormDirectKiller
//---------------------------------------------------------------------------
#if !defined(TestStormDirectKiller_H)
  #define TestStormDirectKiller_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;
class clTreePopulation;

/**
* Tests the clStormDirectKiller class.
*/
class clTestStormDirectKiller : public CppUnit::TestFixture {

  public:

  /**
  * Assembles all other testing functions into one test.
  */
  void TestStormDirectKiller();

  protected:

  /**
  * Tests normal processing.  WriteXMLFile1() writes the parameter file.
  * Aspects of the run:
  * <ul>
  * <li>4 species.</li>
  * <li>Plot size 50X50.</li>
  * <li>Behavior applied to seedlings, saplings, and adults of species 1 and 4, 
  * adults only of species 2, none of species 3.</li>
  * <li>Susceptibility map - 25X25 m cells; 0 in southern half of the plot, 1 in 
  * northern half.</li>
  * <li>1000 each of seedlings, saplings, and adults of each species, on each 
  * half of the plot.</li>
  * <li>Timestep 1: No storms.</li>
  * <li>Timestep 2: Storm of 0.2.</li>
  * <li>Timestep 3: No storms.</li>
  * <li>Timestep 4: Storm of 0.5 and 0.6.</li>
  * </ul>
  * The run proceeds for 5 timesteps and the number of trees with each damage
  * counter is checked through time.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);
  
  /**
  * Tests error processing.
  * @throws error if any of the errors are not caught, or an error other than
  * the intended error is thrown by a parameter file.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes the parameter file for TestNormalProcessing1().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile1();

  /**
  * Writes an error file where the storm behavior is not also enabled.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error file where mortality behaviors aren't applied to all
  * storm trees.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile2();

};
//---------------------------------------------------------------------------
#endif //TestStormDirectKiller_H
