//---------------------------------------------------------------------------
// TestSuppressionDurationMort_H
//---------------------------------------------------------------------------
#if !defined(TestSuppressionDurationMort_H)
  #define TestSuppressionDurationMort_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clSuppressionDurationMort class.
*/
class clTestSuppressionDurationMort : public CppUnit::TestFixture
{
  public:

  /**
  * This puts all mortality tests into a single function.
  */
  void TestSuppressionDurationMort();

  protected:

  /**
  * Tests normal processing run 1. WriteXMLFile1() does setup.
  * @param p_oSimManager Sim manager object for doing the run.
  */
  void NormalProcessingRun1(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  Inputs error files to make sure the errors are
  * caught.
  */
  void ErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Writes a parameter file for normal processing run 1.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes a parameter file where a value for max mortality probability
  * is not between 0 and 1.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes a parameter file where there is no tree age behavior.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes a parameter file where a value for X0 is 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes common portions of the test parameter files.  This starts with
  * &lt;randomSeed&gt; and ends with &lt;/allometry&gt;.
  * @param oOut File stream to write to.
  */
  void WriteErrorCommonStuff(std::fstream &oOut);

};
#endif // TestSuppressionDurationMort_H
//---------------------------------------------------------------------------


