//---------------------------------------------------------------------------
// TestTreeRemover.cpp
//---------------------------------------------------------------------------
#include "TestTreeRemover.h"
#include "SimManager.h"
#include "TreePopulation.h"
#include <fstream>
#include <math.h>

/////////////////////////////////////////////////////////////////////////////
// TestRandomBrowse()
/////////////////////////////////////////////////////////////////////////////
void clTestTreeRemover::TestTreeRemover()
{
  clSimManager * p_oSimManager = new clSimManager(3, 3, "");
  TestNormalProcessingRun1(p_oSimManager);
  //TestNormalProcessingRun2(p_oSimManager);
  //TestNormalProcessingRun3(p_oSimManager);
  TestErrorProcessing(p_oSimManager);
  delete p_oSimManager;
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun1()
/////////////////////////////////////////////////////////////////////////////
void clTestTreeRemover::TestNormalProcessingRun1(clSimManager *p_oSimManager)
{
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fX;
  int iDeadCode, iTreeNum, iDeadVal;

  //Load our file
  p_oSimManager->ReadFile( WriteXMLFile1() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Set the "dead" data member of trees 1 & 3
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {

    //Get the X coordinate so we know what tree this is
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    iTreeNum = (int)fX;
    if (iTreeNum == 1 || iTreeNum == 3) {

      //Set the dead code to killed
      iDeadCode = p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType());
      CPPUNIT_ASSERT(iDeadCode > -1);

      p_oTree->SetValue(iDeadCode, natural);
    }

    p_oTree = p_oAllTrees->NextTree();
  }

  //Now, run the model one timestep
  p_oSimManager->RunSim(1);

  //Search for all trees again and make sure they are as they should be
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {

    //Get the X coordinate so we know what tree this is
    p_oTree->GetValue(p_oPop->GetXCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fX);
    iTreeNum = (int)fX;
    if (iTreeNum == 1) {
      //Tree 1 should now be a snag

      iDeadCode = p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType());
      CPPUNIT_ASSERT(iDeadCode > -1);
      p_oTree->GetValue(iDeadCode, &iDeadVal);

      CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
      CPPUNIT_ASSERT(iDeadVal == notdead);
    }
    else if (iTreeNum == 3) {
      //Tree 3 should have been left alone - and its dead code should still
      //be true

      iDeadCode = p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType());
      CPPUNIT_ASSERT(iDeadCode > -1);
      p_oTree->GetValue(iDeadCode, &iDeadVal);

      CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::adult);
      CPPUNIT_ASSERT(iDeadVal == natural);

    }
    else if (iTreeNum == 2 || iTreeNum == 4) {

      //Trees 2 & 4 should have been left alone
      iDeadCode = p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType());
      CPPUNIT_ASSERT(iDeadCode > -1);
      p_oTree->GetValue(iDeadCode, &iDeadVal);

      CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::adult);
      CPPUNIT_ASSERT(iDeadVal == notdead);
    }
    else {

      //Last tree should have been left alone
      iDeadCode = p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType());
      CPPUNIT_ASSERT(iDeadCode == -1);
      CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::adult);
    }

    p_oTree = p_oAllTrees->NextTree();
  }
}

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun2()
/////////////////////////////////////////////////////////////////////////////
/*void clTestTreeRemover::TestNormalProcessingRun2(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fDBH;
  int *p_iNumTrees = new int[remove_tree], i, iDead;

  for (i = 0; i < remove_tree; i++) {
    p_iNumTrees[i] = 0;
  }
  p_oSimManager->ReadFile(WriteXMLFile2());
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject("treepopulation");

  //Add 1000 trees to the plot of each mortality reason code
  for (i = 0; i < 1000; i++) {
    iDead = natural;
    fDBH = 20 + iDead;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  0, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter
    p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(),
                                                   p_oTree->GetType()), iDead);

    iDead = fire;
    fDBH = 20 + iDead;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  0, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter
    p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(),
                                                   p_oTree->GetType()), iDead);

    iDead = notdead;
    fDBH = 20 + iDead;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  0, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter
    p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(),
                                                   p_oTree->GetType()), iDead);

    iDead = insects;
    fDBH = 20 + iDead;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  0, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter
    p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(),
                                                   p_oTree->GetType()), iDead);

    iDead = disease;
    fDBH = 20 + iDead;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  0, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter
    p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(),
                                                   p_oTree->GetType()), iDead);

    iDead = storm;
    fDBH = 20 + iDead;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  0, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter
    p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(),
                                                   p_oTree->GetType()), iDead);
  }

  //Run the model
  p_oSimManager->RunSim(1);

  //Count up the trees
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(),
        p_oTree->GetType()), &fDBH);
    iDead = (int)(fDBH - 20);
    if (iDead != notdead)
      CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);

    p_iNumTrees[iDead]++;

    p_oTree = p_oAllTrees->NextTree();
  }

  //Compare to expected results
  CPPUNIT_ASSERT(p_iNumTrees[notdead] == 1000);
  CPPUNIT_ASSERT(fabs(p_iNumTrees[natural] - 300)/300 < 0.05);
  CPPUNIT_ASSERT(fabs(p_iNumTrees[fire] - 500)/500 < 0.05);
  CPPUNIT_ASSERT(fabs(p_iNumTrees[insects] - 600)/600 < 0.05);
  CPPUNIT_ASSERT(fabs(p_iNumTrees[disease] - 700)/700 < 0.05);
  CPPUNIT_ASSERT(fabs(p_iNumTrees[storm] - 850)/850 < 0.05);


}*/

/////////////////////////////////////////////////////////////////////////////
// TestNormalProcessingRun3()
/////////////////////////////////////////////////////////////////////////////
/*void clTestTreeRemover::TestNormalProcessingRun3(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fDBH;
  int iNumTrees, i;


  p_oSimManager->ReadFile(WriteXMLFile3());
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject("treepopulation");

  //Add 1000 trees to the plot of each tree type being tested
  for (i = 0; i < 1000; i++) {
    fDBH = 20;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  0, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter

    fDBH = 20;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  1, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter

    fDBH = 55;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  1, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter

    fDBH = 8;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  2, //species
                                  clTreePopulation::sapling, //type
                                  fDBH); //diameter

    fDBH = 20;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  2, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter

    fDBH = 20;
    p_oTree = p_oPop->CreateTree((200.0*clModelMath::GetRand()), //X
                                 (200.0*clModelMath::GetRand()), //Y
                                  3, //species
                                  clTreePopulation::adult, //type
                                  fDBH); //diameter
  }

  //Run the model
  p_oSimManager->RunSim(1);

  p_oAllTrees = p_oPop->Find("all");

  //Count up snags of species one
  iNumTrees = 0;
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetSpecies() == 0) {
      CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
      iNumTrees++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(fabs(iNumTrees - 800)/800 < 0.05);
  p_oAllTrees->StartOver();

  //Count up snags of species 2, 20 cm DBH
  iNumTrees = 0;
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetSpecies() == 1) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(),
          p_oTree->GetType()), &fDBH);
      if (fDBH == 20) {
        CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
        iNumTrees++;
      }
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(fabs(iNumTrees - 300)/300 < 0.1);
  p_oAllTrees->StartOver();

  //Count up snags of species 2, 55 cm DBH
  iNumTrees = 0;
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetSpecies() == 1) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(),
          p_oTree->GetType()), &fDBH);
      if (fDBH == 55) {
        CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
        iNumTrees++;
      }
    }

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(iNumTrees == 1000);
  p_oAllTrees->StartOver();

  //Count up snags of species 3, 8 cm DBH
  iNumTrees = 0;
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetSpecies() == 2) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(),
          p_oTree->GetType()), &fDBH);
      if (fDBH == 8) {
        iNumTrees++;
      }
    }

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(iNumTrees == 0);
  p_oAllTrees->StartOver();

  //Count up snags of species 3, 20 cm DBH
  iNumTrees = 0;
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetSpecies() == 2) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(),
          p_oTree->GetType()), &fDBH);
      if (fDBH == 20) {
        CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
        iNumTrees++;
      }
    }

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(iNumTrees == 0);
  p_oAllTrees->StartOver();

  //Count up snags of species 4, 20 cm DBH
  iNumTrees = 0;
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetSpecies() == 3) {
      CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
      iNumTrees++;
    }

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(fabs(iNumTrees - 700)/700 < 0.05);
  p_oAllTrees->StartOver();

}*/

/////////////////////////////////////////////////////////////////////////////
// TestErrorProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestTreeRemover::TestErrorProcessing(clSimManager *p_oSimManager)
{

  //Error processing
  try {
    p_oSimManager->ReadFile( WriteXMLErrorFile1() );
    CppUnit::Asserter::fail("clTreeRemover::GetData failed - didn't catch lack of dead data member.");
  } catch (modelErr err) {

     if (strcmp(err.cFunction, "clTreeRemover::GetData") != 0) {
       CppUnit::Asserter::fail("clTreeRemover::GetData failed - didn't catch lack of dead data member.");
     }
  }

/*  try {
    p_oSimManager->ReadFile( WriteXMLErrorFile2() );
    CppUnit::Asserter::fail("clTreeRemover::GetData failed - didn't catch lack of dead data member.");
  } catch (modelErr err) {

     if (strcmp(err.cFunction, "clTreeRemover::GetData") != 0) {
       CppUnit::Asserter::fail("clTreeRemover::GetData failed - didn't catch lack of dead data member.");
     }
  }*/
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestTreeRemover::WriteXMLFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>2000</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "<tr_treemap>"
       << "<tm_treeSettings sp=\"Species_1\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_2\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tm_treeSettings sp=\"Species_3\" tp=\"3\">"
       << "<tm_floatCodes>"
       << "<tm_floatCode label=\"X\">0</tm_floatCode>"
       << "<tm_floatCode label=\"Y\">1</tm_floatCode>"
       << "<tm_floatCode label=\"DBH\">2</tm_floatCode>"
       << "</tm_floatCodes>"
       << "</tm_treeSettings>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">1</fl>"
       << "<fl c=\"1\">1</fl>"
       << "<fl c=\"2\">30</fl>"
       << "</tree>"
       << "<tree sp=\"0\" tp=\"3\">"
       << "<fl c=\"0\">2</fl>"
       << "<fl c=\"1\">2</fl>"
       << "<fl c=\"2\">30</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">3</fl>"
       << "<fl c=\"1\">3</fl>"
       << "<fl c=\"2\">30</fl>"
       << "</tree>"
       << "<tree sp=\"1\" tp=\"3\">"
       << "<fl c=\"0\">4</fl>"
       << "<fl c=\"1\">4</fl>"
       << "<fl c=\"2\">30</fl>"
       << "</tree>"
       << "<tree sp=\"2\" tp=\"3\">"
       << "<fl c=\"0\">5</fl>"
       << "<fl c=\"1\">5</fl>"
       << "<fl c=\"2\">33</fl>"
       << "</tree>"
       << "</tr_treemap>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultselfthin</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>3</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_adultSelfThinSlope>"
       << "<mo_astsVal species=\"Species_1\">0</mo_astsVal>"
       << "<mo_astsVal species=\"Species_2\">0</mo_astsVal>"
       << "</mo_adultSelfThinSlope>"
       << "<mo_adultSelfThinIntercept>"
       << "<mo_astiVal species=\"Species_1\">0</mo_astiVal>"
       << "<mo_astiVal species=\"Species_2\">0</mo_astiVal>"
       << "</mo_adultSelfThinIntercept>"
       << "<mo_adultSelfThinMaxDbh>"
       << "<mo_astmdVal species=\"Species_1\">10</mo_astmdVal>"
       << "<mo_astmdVal species=\"Species_2\">10</mo_astmdVal>"
       << "</mo_adultSelfThinMaxDbh>"
       /*<< "<mo_treeRemNatMortSnagsStanding>"
       << "<mo_trnmssVal species=\"Species_1\">1</mo_trnmssVal>"
       << "</mo_treeRemNatMortSnagsStanding>"
       << "<mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_trdmssVal species=\"Species_1\">1</mo_trdmssVal>"
       << "</mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_treeRemInsectMortSnagsStanding>"
       << "<mo_trimssVal species=\"Species_1\">1</mo_trimssVal>"
       << "</mo_treeRemInsectMortSnagsStanding>"
       << "<mo_treeRemStormMortSnagsStanding>"
       << "<mo_trsmssVal species=\"Species_1\">1</mo_trsmssVal>"
       << "</mo_treeRemStormMortSnagsStanding>"
       << "<mo_treeRemFireMortSnagsStanding>"
       << "<mo_trfmssVal species=\"Species_1\">1</mo_trfmssVal>"
       << "</mo_treeRemFireMortSnagsStanding>"*/
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestTreeRemover::WriteXMLFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>3</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "<mo_treeRemNatMortSnagsStanding>"
       << "<mo_trnmssVal species=\"Species_1\">0.3</mo_trnmssVal>"
       << "</mo_treeRemNatMortSnagsStanding>"
       << "<mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_trdmssVal species=\"Species_1\">0.7</mo_trdmssVal>"
       << "</mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_treeRemInsectMortSnagsStanding>"
       << "<mo_trimssVal species=\"Species_1\">0.6</mo_trimssVal>"
       << "</mo_treeRemInsectMortSnagsStanding>"
       << "<mo_treeRemStormMortSnagsStanding>"
       << "<mo_trsmssVal species=\"Species_1\">0.85</mo_trsmssVal>"
       << "</mo_treeRemStormMortSnagsStanding>"
       << "<mo_treeRemFireMortSnagsStanding>"
       << "<mo_trfmssVal species=\"Species_1\">0.5</mo_trfmssVal>"
       << "</mo_treeRemFireMortSnagsStanding>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestTreeRemover::WriteXMLFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "<tr_species speciesName=\"Species_4\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_6\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Constant GLI</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_2\" type=\"Snag\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>adultstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>senescence</behaviorName>"
       << "<version>1.0</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>Windstorm</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>3</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<lightOther>"
       << "<li_constGLI>12.5</li_constGLI>"
       << "</lightOther>"
       << "<windstorm>"
       << "<ws_severityReturnInterval1>1</ws_severityReturnInterval1>"
       << "<ws_severityReturnInterval5>0</ws_severityReturnInterval5>"
       << "<ws_severityReturnInterval10>0</ws_severityReturnInterval10>"
       << "<ws_severityReturnInterval20>0</ws_severityReturnInterval20>"
       << "<ws_severityReturnInterval40>0</ws_severityReturnInterval40>"
       << "<ws_severityReturnInterval80>0</ws_severityReturnInterval80>"
       << "<ws_severityReturnInterval160>0</ws_severityReturnInterval160>"
       << "<ws_severityReturnInterval320>0</ws_severityReturnInterval320>"
       << "<ws_severityReturnInterval640>0</ws_severityReturnInterval640>"
       << "<ws_severityReturnInterval1280>0</ws_severityReturnInterval1280>"
       << "<ws_severityReturnInterval2560>0</ws_severityReturnInterval2560>"
       << "<ws_minDBH>"
       << "<ws_mdVal species=\"Species_1\">5</ws_mdVal>"
       << "<ws_mdVal species=\"Species_2\">6</ws_mdVal>"
       << "<ws_mdVal species=\"Species_3\">6</ws_mdVal>"
       << "</ws_minDBH>"
       << "<ws_stmInterceptA>"
       << "<ws_siaVal species=\"Species_1\">10</ws_siaVal>"
       << "<ws_siaVal species=\"Species_2\">10</ws_siaVal>"
       << "<ws_siaVal species=\"Species_3\">10</ws_siaVal>"
       << "</ws_stmInterceptA>"
       << "<ws_stmIntensCoeffC>"
       << "<ws_sicVal species=\"Species_1\">1</ws_sicVal>"
       << "<ws_sicVal species=\"Species_2\">1</ws_sicVal>"
       << "<ws_sicVal species=\"Species_3\">1</ws_sicVal>"
       << "</ws_stmIntensCoeffC>"
       << "<ws_stmDBHExpB>"
       << "<ws_sdebVal species=\"Species_1\">0</ws_sdebVal>"
       << "<ws_sdebVal species=\"Species_2\">0</ws_sdebVal>"
       << "<ws_sdebVal species=\"Species_3\">0</ws_sdebVal>"
       << "</ws_stmDBHExpB>"
       << "<ws_stmTSToStartStorms>0</ws_stmTSToStartStorms>"
       << "<ws_stmSSTPeriod>1</ws_stmSSTPeriod>"
       << "<ws_stmSineD>0</ws_stmSineD>"
       << "<ws_stmSineF>1</ws_stmSineF>"
       << "<ws_stmSineG>1</ws_stmSineG>"
       << "<ws_stmTrendSlopeM>0</ws_stmTrendSlopeM>"
       << "<ws_stmTrendInterceptI>1</ws_stmTrendInterceptI>"
       << "</windstorm>"
       << "<mortality>"
       << "<mo_nonSizeDepMort>"
       << "<mo_nsdmVal species=\"Species_1\">0</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_3\">1</mo_nsdmVal>"
       << "<mo_nsdmVal species=\"Species_4\">1</mo_nsdmVal>"
       << "</mo_nonSizeDepMort>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "<mo_randomMortAlpha>"
       << "<mo_rmaVal species=\"Species_2\">10</mo_rmaVal>"
       << "</mo_randomMortAlpha>"
       << "<mo_randomMortBeta>"
       << "<mo_rmbVal species=\"Species_2\">1</mo_rmbVal>"
       << "</mo_randomMortBeta>"
       << "<mo_dbhAtOnsetOfSenescence>"
       << "<mo_daoosVal species=\"Species_2\">50.0</mo_daoosVal>"
       << "</mo_dbhAtOnsetOfSenescence>"
       << "<mo_dbhAtAsympMaxMort>110</mo_dbhAtAsympMaxMort>"
       << "<mo_treeRemNatMortSnagsStanding>"
       << "<mo_trnmssVal species=\"Species_1\">0.2</mo_trnmssVal>"
       << "<mo_trnmssVal species=\"Species_2\">1</mo_trnmssVal>"
       << "<mo_trnmssVal species=\"Species_3\">0</mo_trnmssVal>"
       << "<mo_trnmssVal species=\"Species_4\">0.7</mo_trnmssVal>"
       << "</mo_treeRemNatMortSnagsStanding>"
       << "<mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_trdmssVal species=\"Species_1\">1</mo_trdmssVal>"
       << "<mo_trdmssVal species=\"Species_2\">1</mo_trdmssVal>"
       << "<mo_trdmssVal species=\"Species_3\">1</mo_trdmssVal>"
       << "<mo_trdmssVal species=\"Species_4\">1</mo_trdmssVal>"
       << "</mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_treeRemInsectMortSnagsStanding>"
       << "<mo_trimssVal species=\"Species_1\">1</mo_trimssVal>"
       << "<mo_trimssVal species=\"Species_2\">1</mo_trimssVal>"
       << "<mo_trimssVal species=\"Species_3\">1</mo_trimssVal>"
       << "<mo_trimssVal species=\"Species_4\">1</mo_trimssVal>"
       << "</mo_treeRemInsectMortSnagsStanding>"
       << "<mo_treeRemStormMortSnagsStanding>"
       << "<mo_trsmssVal species=\"Species_1\">0.8</mo_trsmssVal>"
       << "<mo_trsmssVal species=\"Species_2\">0.3</mo_trsmssVal>"
       << "<mo_trsmssVal species=\"Species_3\">0.6</mo_trsmssVal>"
       << "<mo_trsmssVal species=\"Species_4\">0.1</mo_trsmssVal>"
       << "</mo_treeRemStormMortSnagsStanding>"
       << "<mo_treeRemFireMortSnagsStanding>"
       << "<mo_trfmssVal species=\"Species_1\">1</mo_trfmssVal>"
       << "<mo_trfmssVal species=\"Species_2\">1</mo_trfmssVal>"
       << "<mo_trfmssVal species=\"Species_3\">1</mo_trfmssVal>"
       << "<mo_trfmssVal species=\"Species_4\">1</mo_trfmssVal>"
       << "</mo_treeRemFireMortSnagsStanding>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestTreeRemover::WriteXMLErrorFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>2000</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultselfthin</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>3</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_adultSelfThinSlope>"
       << "<mo_astsVal species=\"Species_1\">0</mo_astsVal>"
       << "<mo_astsVal species=\"Species_2\">0</mo_astsVal>"
       << "</mo_adultSelfThinSlope>"
       << "<mo_adultSelfThinIntercept>"
       << "<mo_astiVal species=\"Species_1\">0</mo_astiVal>"
       << "<mo_astiVal species=\"Species_2\">0</mo_astiVal>"
       << "</mo_adultSelfThinIntercept>"
       << "<mo_adultSelfThinMaxDbh>"
       << "<mo_astmdVal species=\"Species_1\">10</mo_astmdVal>"
       << "<mo_astmdVal species=\"Species_2\">10</mo_astmdVal>"
       << "</mo_adultSelfThinMaxDbh>"
       << "<mo_treeRemNatMortSnagsStanding>"
       << "<mo_trnmssVal species=\"Species_3\">1</mo_trnmssVal>"
       << "</mo_treeRemNatMortSnagsStanding>"
       << "<mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_trdmssVal species=\"Species_3\">1</mo_trdmssVal>"
       << "</mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_treeRemInsectMortSnagsStanding>"
       << "<mo_trimssVal species=\"Species_3\">1</mo_trimssVal>"
       << "</mo_treeRemInsectMortSnagsStanding>"
       << "<mo_treeRemStormMortSnagsStanding>"
       << "<mo_trsmssVal species=\"Species_3\">1</mo_trsmssVal>"
       << "</mo_treeRemStormMortSnagsStanding>"
       << "<mo_treeRemFireMortSnagsStanding>"
       << "<mo_trfmssVal species=\"Species_3\">1</mo_trfmssVal>"
       << "</mo_treeRemFireMortSnagsStanding>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteXMLErrorFile2()
/////////////////////////////////////////////////////////////////////////////
/*char * clTestTreeRemover::WriteXMLErrorFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>2</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>2000</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>adultselfthin</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Snag\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>3</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Snag\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_adultSelfThinSlope>"
       << "<mo_astsVal species=\"Species_3\">0</mo_astsVal>"
       << "</mo_adultSelfThinSlope>"
       << "<mo_adultSelfThinIntercept>"
       << "<mo_astiVal species=\"Species_3\">0</mo_astiVal>"
       << "</mo_adultSelfThinIntercept>"
       << "<mo_adultSelfThinMaxDbh>"
       << "<mo_astmdVal species=\"Species_3\">10</mo_astmdVal>"
       << "</mo_adultSelfThinMaxDbh>"
       << "<mo_treeRemNatMortSnagsStanding>"
       << "<mo_trnmssVal species=\"Species_3\">10</mo_trnmssVal>"
       << "</mo_treeRemNatMortSnagsStanding>"
       << "<mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_trdmssVal species=\"Species_3\">1</mo_trdmssVal>"
       << "</mo_treeRemDiseaseMortSnagsStanding>"
       << "<mo_treeRemInsectMortSnagsStanding>"
       << "<mo_trimssVal species=\"Species_3\">1</mo_trimssVal>"
       << "</mo_treeRemInsectMortSnagsStanding>"
       << "<mo_treeRemStormMortSnagsStanding>"
       << "<mo_trsmssVal species=\"Species_3\">1</mo_trsmssVal>"
       << "</mo_treeRemStormMortSnagsStanding>"
       << "<mo_treeRemFireMortSnagsStanding>"
       << "<mo_trfmssVal species=\"Species_3\">1</mo_trfmssVal>"
       << "</mo_treeRemFireMortSnagsStanding>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}*/

