//---------------------------------------------------------------------------
// TestWeibullClimateGrowth.cpp
//---------------------------------------------------------------------------
#include "TestWeibullClimateGrowth.h"
#include <fstream>
#include <math.h>
#include "TreePopulation.h"
#include "SimManager.h"
#include "BehaviorBase.h"

using namespace std;
////////////////////////////////////////////////////////////////////////////
// TestWeibullClimateGrowth()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateGrowth::TestWeibullClimateGrowth() {
  clSimManager *p_oSimManager = new clSimManager(4, 2, "");

  TestRun1(p_oSimManager);
  TestRun2(p_oSimManager);
  TestErrorProcessing(p_oSimManager);

  delete p_oSimManager;
}

////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateGrowth::TestErrorProcessing(
    clSimManager *p_oSimManager) {

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile1.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile1.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile2.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile2.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile3.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile3.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile4.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile4.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile6());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile7());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile8());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }

  /*try {
    p_oSimManager->ReadFile(WriteXMLErrorFile9());
    CppUnit::Asserter::fail(
        "TestWeibullClimateGrowth error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateGrowth error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }*/
}

////////////////////////////////////////////////////////////////////////////
//  TestRun1()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateGrowth::TestRun1(clSimManager *p_oSimManager) {

  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1, *p_oTargetTree2, *p_oTargetTree3, *p_oTargetTree4,
      *p_oTargetTree5, *p_oTargetTree6, *p_oTargetTree7, *p_oTargetTree8,
      *p_oTargetTree9, *p_oTargetTree;
  float fDiam, fExpectedDiam, fGrowth, fExpectedGrowth;
  int iSpecies;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile(WriteXMLFile1());
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  //Create our trees
  fDiam = 11;
  iSpecies = 1;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(50, 50, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 2;
  p_oTargetTree3 = p_oPop->CreateTree(53, 52, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  p_oTargetTree4 = p_oPop->CreateTree(59, 50, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 30;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(50, 59, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 45;
  iSpecies = 2;
  p_oTargetTree6 = p_oPop->CreateTree(55, 55, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 3;
  p_oTargetTree7 = p_oPop->CreateTree(60, 61, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 4;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(52, 52, iSpecies,
      clTreePopulation::sapling, fDiam);

  fDiam = 4;
  iSpecies = 2;
  p_oTargetTree9 = p_oPop->CreateTree(53, 53, iSpecies,
      clTreePopulation::sapling, fDiam);

  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oTargetTree = p_oPop->CreateTree(54, 54, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), natural);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 11.08373955;
  fExpectedGrowth = 0.418697729;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 10.51201261;
  fExpectedGrowth = 0.060063058;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 20.0912634;
  fExpectedGrowth = 25.45631698;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 25.37568211;
  fExpectedGrowth = 1.878410547;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 30.08664016;
  fExpectedGrowth = 0.433200788;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 48.11810814;
  fExpectedGrowth = 15.59054069;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 15.23503434;
  fExpectedGrowth = 1.17517172;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 4.03513154;
  fExpectedGrowth = 0.219352775;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 4.24614164;
  fExpectedGrowth = 1.536848403;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);
}

////////////////////////////////////////////////////////////////////////////
// TestRun2()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateGrowth::TestRun2(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1, *p_oTargetTree2, *p_oTargetTree3, *p_oTargetTree4,
      *p_oTargetTree5, *p_oTargetTree6, *p_oTargetTree7, *p_oTargetTree8,
      *p_oTargetTree9, *p_oTargetTree;
  float fDiam, fExpectedDiam, fGrowth, fExpectedGrowth;
  int iSpecies;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile(WriteXMLFile2());
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  //Create our trees
  fDiam = 11;
  iSpecies = 1;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(50, 50, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 2;
  p_oTargetTree3 = p_oPop->CreateTree(53, 52, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  p_oTargetTree4 = p_oPop->CreateTree(59, 50, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 30;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(50, 59, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 45;
  iSpecies = 2;
  p_oTargetTree6 = p_oPop->CreateTree(55, 55, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 3;
  p_oTargetTree7 = p_oPop->CreateTree(60, 61, iSpecies,
      clTreePopulation::adult, fDiam);

  fDiam = 4;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(52, 52, iSpecies,
      clTreePopulation::sapling, fDiam);

  fDiam = 4;
  iSpecies = 2;
  p_oTargetTree9 = p_oPop->CreateTree(53, 53, iSpecies,
      clTreePopulation::sapling, fDiam);

  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oTargetTree = p_oPop->CreateTree(54, 54, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), natural);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 11.25159786;
  fExpectedGrowth = 0.419329775;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 10.53614256;
  fExpectedGrowth = 0.060237607;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 30.11101459;
  fExpectedGrowth = 25.18502432;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 26.12030572;
  fExpectedGrowth = 1.867176201;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 30.26014701;
  fExpectedGrowth = 0.433578346;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 53.68619667;
  fExpectedGrowth = 14.47699446;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 15.69994406;
  fExpectedGrowth = 1.166573431;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 4.105681673;
  fExpectedGrowth = 0.219950202;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 4.78060567;
  fExpectedGrowth = 1.624637176;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLFile1() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
      << "<paramFile fileCode=\"06010101\">" << "<plot>"
      << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteTreeStuff(oOut);
  WriteCommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLFile2() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
      << "<paramFile fileCode=\"06010101\">" << "<plot>"
      << "<timesteps>1</timesteps>" << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteTreeStuff(oOut);
  WriteCommonStuff(oOut);

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
// WriteTreeStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateGrowth::WriteTreeStuff(std::fstream &oOut) {
  oOut << "<randomSeed>1</randomSeed>" << "<plot_lenX>200.0</plot_lenX>"
      << "<plot_lenY>200.0</plot_lenY>"
      << "<plot_latitude>55.37</plot_latitude>"
      << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
      << "<plot_temp_C>12.88171785</plot_temp_C>"
      << "</plot>"
      << "<trees>"
      << "<tr_speciesList>" << "<tr_species speciesName=\"Species_1\" />"
      << "<tr_species speciesName=\"Species_2\" />"
      << "<tr_species speciesName=\"Species_3\" />"
      << "<tr_species speciesName=\"Species_4\" />" << "</tr_speciesList>"
      << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>" << "<tr_minAdultDBH>"
      << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
      << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
      << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
      << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
      << "</tr_minAdultDBH>" << "<tr_maxSeedlingHeight>"
      << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
      << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
      << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
      << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
      << "</tr_maxSeedlingHeight>" << "</trees>" << "<allometry>"
      << "<tr_canopyHeight>"
      << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
      << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
      << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
      << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
      << "</tr_canopyHeight>" << "<tr_stdAsympCrownRad>"
      << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
      << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
      << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
      << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
      << "</tr_stdAsympCrownRad>" << "<tr_stdCrownRadExp>"
      << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
      << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
      << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
      << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
      << "</tr_stdCrownRadExp>" << "<tr_conversionDiam10ToDBH>"
      << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
      << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
      << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
      << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
      << "</tr_conversionDiam10ToDBH>" << "<tr_interceptDiam10ToDBH>"
      << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
      << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
      << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
      << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
      << "</tr_interceptDiam10ToDBH>" << "<tr_stdAsympCrownHt>"
      << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
      << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
      << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
      << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
      << "</tr_stdAsympCrownHt>" << "<tr_stdCrownHtExp>"
      << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
      << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
      << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
      << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
      << "</tr_stdCrownHtExp>" << "<tr_slopeOfHeight-Diam10>"
      << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
      << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
      << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
      << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
      << "</tr_slopeOfHeight-Diam10>" << "<tr_slopeOfAsymHeight>"
      << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
      << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
      << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
      << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
      << "</tr_slopeOfAsymHeight>" << "<tr_whatSeedlingHeightDiam>"
      << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
      << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
      << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
      << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
      << "</tr_whatSeedlingHeightDiam>" << "<tr_whatSaplingHeightDiam>"
      << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
      << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
      << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
      << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
      << "</tr_whatSaplingHeightDiam>" << "<tr_whatAdultHeightDiam>"
      << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
      << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
      << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
      << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
      << "</tr_whatAdultHeightDiam>" << "<tr_whatAdultCrownRadDiam>"
      << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
      << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
      << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
      << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
      << "</tr_whatAdultCrownRadDiam>" << "<tr_whatAdultCrownHeightHeight>"
      << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
      << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
      << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
      << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
      << "</tr_whatAdultCrownHeightHeight>" << "<tr_whatSaplingCrownRadDiam>"
      << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
      << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
      << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
      << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
      << "</tr_whatSaplingCrownRadDiam>" << "<tr_whatSaplingCrownHeightHeight>"
      << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
      << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
      << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
      << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
      << "</tr_whatSaplingCrownHeightHeight>" << "</allometry>";
}

/////////////////////////////////////////////////////////////////////////////
// WriteCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateGrowth::WriteCommonStuff(std::fstream &oOut) {
  oOut << "<behaviorList>"
      << "<behavior>"
      << "<behaviorName>WeibullClimateGrowth</behaviorName>"
      << "<version>1</version>"
      << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
      << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
      << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
      << "</behavior>"
      << "<behavior>"
      << "<behaviorName>juvstochasticmort</behaviorName>"
      << "<version>1</version>"
      << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
      << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
      << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
      << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_4\" type=\"Sapling\"/>" << "</behavior>"
      << "</behaviorList>"
      << "<growth>"
      << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_2\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_3\">11</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_4\">12</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>"
      << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_2\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_3\">10</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_4\">5.4</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>"
      << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_2\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_3\">18.07</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_4\">132.1</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>"
      << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_2\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_3\">0.902</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_4\">2.568</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>"
      << "<gr_weibClimSizeEffMinDBH>"
      << "<gr_wcsemdVal species=\"Species_2\">2.54</gr_wcsemdVal>"
      << "<gr_wcsemdVal species=\"Species_3\">7</gr_wcsemdVal>"
      << "<gr_wcsemdVal species=\"Species_4\">10</gr_wcsemdVal>"
      << "</gr_weibClimSizeEffMinDBH>"
      << "<gr_weibClimAdultCompEffC>"
      << "<gr_wcacecVal species=\"Species_2\">8.261</gr_wcacecVal>"
      << "<gr_wcacecVal species=\"Species_3\">0</gr_wcacecVal>"
      << "<gr_wcacecVal species=\"Species_4\">0.321</gr_wcacecVal>"
      << "</gr_weibClimAdultCompEffC>"
      << "<gr_weibClimAdultCompEffD>"
      << "<gr_wcacedVal species=\"Species_2\">1.001</gr_wcacedVal>"
      << "<gr_wcacedVal species=\"Species_3\">2.914</gr_wcacedVal>"
      << "<gr_wcacedVal species=\"Species_4\">0.4</gr_wcacedVal>"
      << "</gr_weibClimAdultCompEffD>"
      << "<gr_weibClimAdultCompEffGamma>"
      << "<gr_wcacegVal species=\"Species_2\">-1.208</gr_wcacegVal>"
      << "<gr_wcacegVal species=\"Species_3\">1.976</gr_wcacegVal>"
      << "<gr_wcacegVal species=\"Species_4\">0.461</gr_wcacegVal>"
      << "</gr_weibClimAdultCompEffGamma>"
      << "<gr_weibClimJuvCompEffC>"
      << "<gr_wcjcecVal species=\"Species_2\">0.2</gr_wcjcecVal>"
      << "<gr_wcjcecVal species=\"Species_3\">0.5</gr_wcjcecVal>"
      << "<gr_wcjcecVal species=\"Species_4\">6.068213</gr_wcjcecVal>"
      << "</gr_weibClimJuvCompEffC>"
      << "<gr_weibClimJuvCompEffD>"
      << "<gr_wcjcedVal species=\"Species_2\">0.9358206</gr_wcjcedVal>"
      << "<gr_wcjcedVal species=\"Species_3\">1.16629</gr_wcjcedVal>"
      << "<gr_wcjcedVal species=\"Species_4\">0.7153209</gr_wcjcedVal>"
      << "</gr_weibClimJuvCompEffD>"
      << "<gr_weibClimJuvCompEffGamma>"
      << "<gr_wcjcegVal species=\"Species_2\">-0.06164447</gr_wcjcegVal>"
      << "<gr_wcjcegVal species=\"Species_3\">-0.4051102</gr_wcjcegVal>"
      << "<gr_wcjcegVal species=\"Species_4\">0.391744</gr_wcjcegVal>"
      << "</gr_weibClimJuvCompEffGamma>"
      << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_2\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_3\">8.91133</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_4\">6.996252</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>"
      << "<gr_weibClimAdultTempEffB>"
      << "<gr_wcatebVal species=\"Species_2\">1.205544</gr_wcatebVal>"
      << "<gr_wcatebVal species=\"Species_3\">1.475192</gr_wcatebVal>"
      << "<gr_wcatebVal species=\"Species_4\">3.000519</gr_wcatebVal>"
      << "</gr_weibClimAdultTempEffB>"
      << "<gr_weibClimAdultTempEffC>"
      << "<gr_wcatecVal species=\"Species_2\">13.2644</gr_wcatecVal>"
      << "<gr_wcatecVal species=\"Species_3\">12.4024</gr_wcatecVal>"
      << "<gr_wcatecVal species=\"Species_4\">9.6727</gr_wcatecVal>"
      << "</gr_weibClimAdultTempEffC>"
      << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_2\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_3\">3.753555</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_4\">0.001</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>"
      << "<gr_weibClimAdultPrecipEffB>"
      << "<gr_wcapebVal species=\"Species_2\">0.4447052</gr_wcapebVal>"
      << "<gr_wcapebVal species=\"Species_3\">0.07809054</gr_wcapebVal>"
      << "<gr_wcapebVal species=\"Species_4\">0.05211167</gr_wcapebVal>"
      << "</gr_weibClimAdultPrecipEffB>"
      << "<gr_weibClimAdultPrecipEffC>"
      << "<gr_wcapecVal species=\"Species_2\">0.000319117</gr_wcapecVal>"
      << "<gr_wcapecVal species=\"Species_3\">1048.734</gr_wcapecVal>"
      << "<gr_wcapecVal species=\"Species_4\">643.8208</gr_wcapecVal>"
      << "</gr_weibClimAdultPrecipEffC>"
      << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_2\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_3\">3306.159</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_4\">0.001</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>"
      << "<gr_weibClimJuvPrecipEffB>"
      << "<gr_wcjpebVal species=\"Species_2\">0.8027915</gr_wcjpebVal>"
      << "<gr_wcjpebVal species=\"Species_3\">6.669916</gr_wcjpebVal>"
      << "<gr_wcjpebVal species=\"Species_4\">0.05211167</gr_wcjpebVal>"
      << "</gr_weibClimJuvPrecipEffB>"
      << "<gr_weibClimJuvPrecipEffC>"
      << "<gr_wcjpecVal species=\"Species_2\">1032.264</gr_wcjpecVal>"
      << "<gr_wcjpecVal species=\"Species_3\">3835.918</gr_wcjpecVal>"
      << "<gr_wcjpecVal species=\"Species_4\">643.8208</gr_wcjpecVal>"
      << "</gr_weibClimJuvPrecipEffC>"
      << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_2\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_3\">139.5745</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_4\">6.996252</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>"
      << "<gr_weibClimJuvTempEffB>"
      << "<gr_wcjtebVal species=\"Species_2\">0.3014869</gr_wcjtebVal>"
      << "<gr_wcjtebVal species=\"Species_3\">0</gr_wcjtebVal>"
      << "<gr_wcjtebVal species=\"Species_4\">3.000519</gr_wcjtebVal>"
      << "</gr_weibClimJuvTempEffB>"
      << "<gr_weibClimJuvTempEffC>"
      << "<gr_wcjtecVal species=\"Species_2\">14.2357</gr_wcjtecVal>"
      << "<gr_wcjtecVal species=\"Species_3\">28.6192</gr_wcjtecVal>"
      << "<gr_wcjtecVal species=\"Species_4\">9.6727</gr_wcjtecVal>"
      << "</gr_weibClimJuvTempEffC>"
      << "<gr_weibClimMinNeighDBH>"
      << "<gr_wcmndVal species=\"Species_1\">5</gr_wcmndVal>"
      << "<gr_wcmndVal species=\"Species_2\">5</gr_wcmndVal>"
      << "<gr_wcmndVal species=\"Species_3\">5</gr_wcmndVal>"
      << "<gr_wcmndVal species=\"Species_4\">5</gr_wcmndVal>"
      << "</gr_weibClimMinNeighDBH>"
      << "</growth>"
      << "<mortality>"
      << "<mo_randomJuvenileMortality>"
      << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
      << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
      << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
      << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
      << "</mo_randomJuvenileMortality>"
      << "</mortality>"
      << "</paramFile>";

}

/////////////////////////////////////////////////////////////////////////////
//  WriteErrorFileCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateGrowth::WriteErrorFileCommonStuff(std::fstream &oOut) {
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
      << "<paramFile fileCode=\"06010101\">"
      << "<plot>"
      << "<timesteps>1</timesteps>"
      << "<yearsPerTimestep>1</yearsPerTimestep>"
      << "<randomSeed>1</randomSeed>"
      << "<plot_lenX>200.0</plot_lenX>"
      << "<plot_lenY>200.0</plot_lenY>"
      << "<plot_latitude>55.37</plot_latitude>"
      << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
      << "<plot_temp_C>12.88171785</plot_temp_C>"
      << "</plot>"
      << "<trees>"
      << "<tr_speciesList>"
      << "<tr_species speciesName=\"Species_1\" />"
      << "<tr_species speciesName=\"Species_2\" />"
      << "</tr_speciesList>"
      << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
      << "<tr_minAdultDBH>"
      << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
      << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
      << "</tr_minAdultDBH>"
      << "<tr_maxSeedlingHeight>"
      << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
      << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
      << "</tr_maxSeedlingHeight>"
      << "</trees>"
      << "<allometry>"
      << "<tr_canopyHeight>"
      << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
      << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
      << "</tr_canopyHeight>"
      << "<tr_stdAsympCrownRad>"
      << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
      << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
      << "</tr_stdAsympCrownRad>"
      << "<tr_stdCrownRadExp>"
      << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
      << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
      << "</tr_stdCrownRadExp>"
      << "<tr_conversionDiam10ToDBH>"
      << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
      << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
      << "</tr_conversionDiam10ToDBH>"
      << "<tr_interceptDiam10ToDBH>"
      << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
      << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
      << "</tr_interceptDiam10ToDBH>"
      << "<tr_stdAsympCrownHt>"
      << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
      << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
      << "</tr_stdAsympCrownHt>"
      << "<tr_stdCrownHtExp>"
      << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
      << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
      << "</tr_stdCrownHtExp>"
      << "<tr_slopeOfHeight-Diam10>"
      << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
      << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
      << "</tr_slopeOfHeight-Diam10>"
      << "<tr_slopeOfAsymHeight>"
      << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
      << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
      << "</tr_slopeOfAsymHeight>"
      << "<tr_whatSeedlingHeightDiam>"
      << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
      << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
      << "</tr_whatSeedlingHeightDiam>"
      << "<tr_whatSaplingHeightDiam>"
      << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
      << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
      << "</tr_whatSaplingHeightDiam>"
      << "<tr_whatAdultHeightDiam>"
      << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
      << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
      << "</tr_whatAdultHeightDiam>"
      << "<tr_whatAdultCrownRadDiam>"
      << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
      << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
      << "</tr_whatAdultCrownRadDiam>"
      << "<tr_whatAdultCrownHeightHeight>"
      << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
      << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
      << "</tr_whatAdultCrownHeightHeight>"
      << "<tr_whatSaplingCrownRadDiam>"
      << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
      << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
      << "</tr_whatSaplingCrownRadDiam>"
      << "<tr_whatSaplingCrownHeightHeight>"
      << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
      << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
      << "</tr_whatSaplingCrownHeightHeight>"
      << "</allometry>"
      << "<behaviorList>"
      << "<behavior>"
      << "<behaviorName>WeibullClimateGrowth</behaviorName>"
      << "<version>1</version>"
      << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
      << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_2\" type=\"Sapling\"/>" << "</behavior>"
      << "<behavior>" << "<behaviorName>juvstochasticmort</behaviorName>"
      << "<version>1</version>"
      << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
      << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
      << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
      << "</behavior>"
      << "</behaviorList>"
      << "<growth>"
      << "<gr_weibClimAdultCompEffC>"
      << "<gr_wcacecVal species=\"Species_1\">8.261</gr_wcacecVal>"
      << "<gr_wcacecVal species=\"Species_2\">0</gr_wcacecVal>"
      << "</gr_weibClimAdultCompEffC>"
      << "<gr_weibClimAdultCompEffD>"
      << "<gr_wcacedVal species=\"Species_1\">1.001</gr_wcacedVal>"
      << "<gr_wcacedVal species=\"Species_2\">2.914</gr_wcacedVal>"
      << "</gr_weibClimAdultCompEffD>"
      << "<gr_weibClimAdultCompEffGamma>"
      << "<gr_wcacegVal species=\"Species_1\">-1.208</gr_wcacegVal>"
      << "<gr_wcacegVal species=\"Species_2\">1.976</gr_wcacegVal>"
      << "</gr_weibClimAdultCompEffGamma>"
      << "<gr_weibClimJuvCompEffC>"
      << "<gr_wcjcecVal species=\"Species_1\">15.16225</gr_wcjcecVal>"
      << "<gr_wcjcecVal species=\"Species_2\">10.67038</gr_wcjcecVal>"
      << "</gr_weibClimJuvCompEffC>"
      << "<gr_weibClimJuvCompEffD>"
      << "<gr_wcjcedVal species=\"Species_1\">0.9358206</gr_wcjcedVal>"
      << "<gr_wcjcedVal species=\"Species_2\">1.16629</gr_wcjcedVal>"
      << "</gr_weibClimJuvCompEffD>"
      << "<gr_weibClimJuvCompEffGamma>"
      << "<gr_wcjcegVal species=\"Species_1\">-0.06164447</gr_wcjcegVal>"
      << "<gr_wcjcegVal species=\"Species_2\">-0.4051102</gr_wcjcegVal>"
      << "</gr_weibClimJuvCompEffGamma>"
      << "<gr_weibClimAdultTempEffB>"
      << "<gr_wcatebVal species=\"Species_1\">1.205544</gr_wcatebVal>"
      << "<gr_wcatebVal species=\"Species_2\">1.475192</gr_wcatebVal>"
      << "</gr_weibClimAdultTempEffB>"
      << "<gr_weibClimAdultTempEffC>"
      << "<gr_wcatecVal species=\"Species_1\">13.2644</gr_wcatecVal>"
      << "<gr_wcatecVal species=\"Species_2\">12.4024</gr_wcatecVal>"
      << "</gr_weibClimAdultTempEffC>"
      << "<gr_weibClimAdultPrecipEffB>"
      << "<gr_wcapebVal species=\"Species_1\">0.4447052</gr_wcapebVal>"
      << "<gr_wcapebVal species=\"Species_2\">0.07809054</gr_wcapebVal>"
      << "</gr_weibClimAdultPrecipEffB>"
      << "<gr_weibClimAdultPrecipEffC>"
      << "<gr_wcapecVal species=\"Species_1\">0.000319117</gr_wcapecVal>"
      << "<gr_wcapecVal species=\"Species_2\">1048.734</gr_wcapecVal>"
      << "</gr_weibClimAdultPrecipEffC>"
      << "<gr_weibClimJuvPrecipEffB>"
      << "<gr_wcjpebVal species=\"Species_1\">0.8027915</gr_wcjpebVal>"
      << "<gr_wcjpebVal species=\"Species_2\">6.669916</gr_wcjpebVal>"
      << "</gr_weibClimJuvPrecipEffB>"
      << "<gr_weibClimJuvPrecipEffC>"
      << "<gr_wcjpecVal species=\"Species_1\">1032.264</gr_wcjpecVal>"
      << "<gr_wcjpecVal species=\"Species_2\">3835.918</gr_wcjpecVal>"
      << "</gr_weibClimJuvPrecipEffC>"
      << "<gr_weibClimJuvTempEffB>"
      << "<gr_wcjtebVal species=\"Species_1\">0.3014869</gr_wcjtebVal>"
      << "<gr_wcjtebVal species=\"Species_2\">0</gr_wcjtebVal>"
      << "</gr_weibClimJuvTempEffB>"
      << "<gr_weibClimJuvTempEffC>"
      << "<gr_wcjtecVal species=\"Species_1\">14.2357</gr_wcjtecVal>"
      << "<gr_wcjtecVal species=\"Species_2\">28.6192</gr_wcjtecVal>"
      << "</gr_weibClimJuvTempEffC>"
      << "<gr_weibClimSizeEffMinDBH>"
      << "<gr_wcsemdVal species=\"Species_1\">0</gr_wcsemdVal>"
      << "<gr_wcsemdVal species=\"Species_2\">0.5</gr_wcsemdVal>"
      << "</gr_weibClimSizeEffMinDBH>"
      << "<gr_weibClimMinNeighDBH>"
      << "<gr_wcmndVal species=\"Species_1\">5</gr_wcmndVal>"
      << "<gr_wcmndVal species=\"Species_2\">5</gr_wcmndVal>"
      << "</gr_weibClimMinNeighDBH>";

}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile1() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">-10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>"
      << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>"
      << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>"
      << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>"
      << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>"
      << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>"
      << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>"
      << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">3306.159</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>"
      << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>"
      << "</growth>"
      << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile2() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>" << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">-0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>" << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>" << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>" << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>" << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>" << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>" << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">3306.159</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>" << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>" << "</growth>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile3() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>" << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>" << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>" << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">0</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>" << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>" << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>" << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>" << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">3306.159</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>" << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>" << "</growth>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile4() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>" << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>" << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">0</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>" << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>" << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>" << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>" << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>" << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">3306.159</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>" << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>" << "</growth>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile5()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile5() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>" << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>" << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>" << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>" << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>" << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>" << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">0</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>" << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">3306.159</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>" << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>" << "</growth>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile6()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile6() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>" << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>" << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>" << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>" << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>" << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>" << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>" << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">0</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>" << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>" << "</growth>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile7()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile7() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>" << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>" << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>" << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>" << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>" << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">0</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>" << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>" << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">3306.159</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>" << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">6.884225</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>" << "</growth>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile8()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateGrowth::WriteXMLErrorFile8() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimMaxNeighRad>"
      << "<gr_wcmnrVal species=\"Species_1\">10</gr_wcmnrVal>"
      << "<gr_wcmnrVal species=\"Species_2\">11</gr_wcmnrVal>"
      << "</gr_weibClimMaxNeighRad>" << "<gr_weibClimMaxGrowth>"
      << "<gr_wcmgVal species=\"Species_1\">0.2574</gr_wcmgVal>"
      << "<gr_wcmgVal species=\"Species_2\">10</gr_wcmgVal>"
      << "</gr_weibClimMaxGrowth>" << "<gr_weibClimSizeEffX0>"
      << "<gr_wcsex0Val species=\"Species_1\">297.615</gr_wcsex0Val>"
      << "<gr_wcsex0Val species=\"Species_2\">18.07</gr_wcsex0Val>"
      << "</gr_weibClimSizeEffX0>" << "<gr_weibClimSizeEffXb>"
      << "<gr_wcsexbVal species=\"Species_1\">4.065</gr_wcsexbVal>"
      << "<gr_wcsexbVal species=\"Species_2\">0.902</gr_wcsexbVal>"
      << "</gr_weibClimSizeEffXb>" << "<gr_weibClimSizeEffY0>"
      << "<gr_wcsey0Val species=\"Species_1\">0</gr_wcsey0Val>"
      << "<gr_wcsey0Val species=\"Species_2\">0.5</gr_wcsey0Val>"
      << "</gr_weibClimSizeEffY0>" << "<gr_weibClimAdultTempEffA>"
      << "<gr_wcateaVal species=\"Species_1\">8.897617</gr_wcateaVal>"
      << "<gr_wcateaVal species=\"Species_2\">8.91133</gr_wcateaVal>"
      << "</gr_weibClimAdultTempEffA>" << "<gr_weibClimAdultPrecipEffA>"
      << "<gr_wcapeaVal species=\"Species_1\">420.2115</gr_wcapeaVal>"
      << "<gr_wcapeaVal species=\"Species_2\">3.753555</gr_wcapeaVal>"
      << "</gr_weibClimAdultPrecipEffA>" << "<gr_weibClimJuvPrecipEffA>"
      << "<gr_wcjpeaVal species=\"Species_1\">1296.228</gr_wcjpeaVal>"
      << "<gr_wcjpeaVal species=\"Species_2\">3306.159</gr_wcjpeaVal>"
      << "</gr_weibClimJuvPrecipEffA>" << "<gr_weibClimJuvTempEffA>"
      << "<gr_wcjteaVal species=\"Species_1\">0</gr_wcjteaVal>"
      << "<gr_wcjteaVal species=\"Species_2\">139.5745</gr_wcjteaVal>"
      << "</gr_weibClimJuvTempEffA>" << "</growth>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
