//---------------------------------------------------------------------------
// TestWeibullClimateGrowth
//---------------------------------------------------------------------------
#if !defined(TestWeibullClimateGrowth_H)
  #define TestWeibullClimateGrowth_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clWeibullClimateGrowth class.
*/
class clTestWeibullClimateGrowth : public CppUnit::TestFixture {

  public:

  /**
  * Tests the clWeibullClimateGrowth class.
  */
  void TestWeibullClimateGrowth();

  /**
  * Performs a test run of growth. WriteXMLFile1() performs setup for a
  * 1-year timestep.  There are 9 target trees whose values will be tested
  * according to the testing spreadsheet prepared.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun1(clSimManager *p_oSimManager);

  /**
  * Performs a test run of growth. WriteXMLFile2() performs setup for a
  * 3-year timestep.  There are 9 target trees whose values will be tested
  * according to the testing spreadsheet prepared.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun2(clSimManager *p_oSimManager);

  /**
  * Tests error processing for input files.
  *
  * WriteXMLErrorFileX (where X = 1-9) is written and checked to make sure that
  * each produces an error.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  protected:

  /**
  * Writes a 1-year timestep file. This contains 4 species.  Weibull climate
  * growth (auto-height) is assigned to saplings and adults of Species 2, 3,
  * and 4.
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes a 3-year timestep file. This contains 4 species.  Weibull climate
  * growth (auto-height) is assigned to saplings and adults of Species 2, 3,
  * and 4.
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes an error condition where max radius of neighbor effects is < 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error condition where max growth for a species is < 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error condition where Xb for a species = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes an error condition where X0 for a species = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile4();

  /**
  * Writes an error condition where an adult precipitation A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile5();

  /**
  * Writes an error condition where a juvenile precipitation A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile6();

  /**
  * Writes an error condition where an adult temperature A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile7();

  /**
  * Writes an error condition where a juvenile temperature A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile8();

    /**
  * Writes an error condition where Y0 for a species is not between 0 and 1.
  * @return Filename written.
  */
  //char* WriteXMLErrorFile9();

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * Picks up right after the number of years per timestep and finishes out the
  * file.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * @param oOut File stream to write to.
  */
  void WriteTreeStuff(std::fstream &oOut);

  /**
  * Writes common portions of the test error parameter files (tree pop, plot,
  * etc).  Starts at the beginning of the file and ends at the closing tree tag.
  * @param oOut File stream to write to.
  */
  void WriteErrorFileCommonStuff(std::fstream &oOut);


};

//---------------------------------------------------------------------------
#endif // TestWeibullClimateGrowth_H
