//---------------------------------------------------------------------------
// TestWeibullClimateQuadratGrowth.cpp
//---------------------------------------------------------------------------
#include "TestWeibullClimateQuadratGrowth.h"
#include <fstream>
#include <math.h>
#include "TreePopulation.h"
#include "SimManager.h"
#include "BehaviorBase.h"

using namespace std;
////////////////////////////////////////////////////////////////////////////
// TestWeibullClimateQuadratGrowth()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateQuadratGrowth::TestWeibullClimateQuadratGrowth() {
  clSimManager *p_oSimManager = new clSimManager(4, 2, "");

  TestRun1(p_oSimManager);
  TestRun2(p_oSimManager);
  TestErrorProcessing(p_oSimManager);

  delete p_oSimManager;
}

////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateQuadratGrowth::TestErrorProcessing(
    clSimManager *p_oSimManager) {

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail(
        "TestWeibullClimateQuadratGrowth error processing didn't catch error for WriteXMLErrorFile1.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateQuadratGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateQuadratGrowth error processing caught wrong error for WriteXMLErrorFile1.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail(
        "TestWeibullClimateQuadratGrowth error processing didn't catch error for WriteXMLErrorFile2.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateQuadratGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateQuadratGrowth error processing caught wrong error for WriteXMLErrorFile2.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail(
        "TestWeibullClimateQuadratGrowth error processing didn't catch error for WriteXMLErrorFile3.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateQuadratGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateQuadratGrowth error processing caught wrong error for WriteXMLErrorFile3.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail(
        "TestWeibullClimateQuadratGrowth error processing didn't catch error for WriteXMLErrorFile4.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateQuadratGrowth::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateQuadratGrowth error processing caught wrong error for WriteXMLErrorFile4.");
    };
  }
}

////////////////////////////////////////////////////////////////////////////
//  TestRun1()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateQuadratGrowth::TestRun1(clSimManager *p_oSimManager) {

  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTargetTree1, *p_oTargetTree2, *p_oTargetTree3, *p_oTargetTree4,
      *p_oTargetTree5, *p_oTargetTree6, *p_oTargetTree7, *p_oTargetTree8,
      *p_oTargetTree9, *p_oTargetTree10, *p_oTargetTree;
  float fDiam, fExpectedDiam, fGrowth, fExpectedGrowth;
  int iSpecies;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  //Create our trees
  fDiam = 0.5;
  iSpecies = 1;
  p_oTargetTree1 = p_oPop->CreateTree(51, 53, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.6;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(51.2, 54, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.7;
  iSpecies = 2;
  p_oTargetTree3 = p_oPop->CreateTree(50.5, 61, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.8;
  iSpecies = 3;
  p_oTargetTree4 = p_oPop->CreateTree(53, 51, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.9;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(20.5, 20.5, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1;
  iSpecies = 2;
  p_oTargetTree6 = p_oPop->CreateTree(61, 50.5, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.1;
  iSpecies = 3;
  p_oTargetTree7 = p_oPop->CreateTree(60, 50.5, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.2;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(51, 53, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.3;
  iSpecies = 2;
  p_oTargetTree9 = p_oPop->CreateTree(51.2, 54, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.4;
  iSpecies = 3;
  p_oTargetTree10 = p_oPop->CreateTree(50.5, 61, iSpecies,
      clTreePopulation::seedling, fDiam);

  //Create all neighbors
  fDiam = 10.5;
  iSpecies = 1;
  p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 2;
  p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 30;
  iSpecies = 1;
  p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 45;
  iSpecies = 2;
  p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 3;
  p_oPop->CreateTree(60, 61, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 4;
  iSpecies = 1;
  p_oPop->CreateTree(52, 52, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 4;
  iSpecies = 2;
  p_oPop->CreateTree(53, 53, iSpecies, clTreePopulation::sapling, fDiam);

  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oTargetTree = p_oPop->CreateTree(54, 54, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 1.333952493;
  fExpectedGrowth = 4.169762464;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 1.433952493;
  fExpectedGrowth = 4.169762464;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 0.788157234;
  fExpectedGrowth = 0.440786172;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 1.540640151;
  fExpectedGrowth = 3.703200756;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 2.952572236;
  fExpectedGrowth = 10.26286118;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 1.179024574;
  fExpectedGrowth = 0.89512287;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 2.089921523;
  fExpectedGrowth = 4.949607615;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 2.033952493;
  fExpectedGrowth = 4.169762464;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 1.342162069;
  fExpectedGrowth = 0.210810347;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 2.251791411;
  fExpectedGrowth = 4.258957053;
  p_oTargetTree = p_oTargetTree10;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  //Kill all the adults
  p_oAllTrees = p_oPop->Find("all");
  p_oTargetTree = p_oAllTrees->NextTree();
  while (p_oTargetTree) {
    if (p_oTargetTree->GetType() == clTreePopulation::adult)
      p_oPop->KillTree(p_oTargetTree, remove_tree);
    p_oTargetTree = p_oAllTrees->NextTree();
  }

  p_oSimManager->RunSim(1);
  //Check the diameters and growth of the target trees
  fExpectedDiam = 3.386524729;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 3.486524729;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 1.858552291;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 3.452213299;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 5.005144473;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 2.249419631;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 4.001494671;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 4.086524729;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 2.412557126;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);

  fExpectedDiam = 4.163364558;
  p_oTargetTree = p_oTargetTree10;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
}

////////////////////////////////////////////////////////////////////////////
// TestRun2()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateQuadratGrowth::TestRun2(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1, *p_oTargetTree2, *p_oTargetTree3, *p_oTargetTree4,
      *p_oTargetTree5, *p_oTargetTree6, *p_oTargetTree7, *p_oTargetTree8,
      *p_oTargetTree9, *p_oTargetTree10, *p_oTargetTree;
  float fDiam, fExpectedDiam, fGrowth, fExpectedGrowth;
  int iSpecies;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  //Create our trees
  fDiam = 0.5;
  iSpecies = 1;
  p_oTargetTree1 = p_oPop->CreateTree(51, 53, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.6;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(51.2, 54, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.7;
  iSpecies = 2;
  p_oTargetTree3 = p_oPop->CreateTree(50.5, 61, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.8;
  iSpecies = 3;
  p_oTargetTree4 = p_oPop->CreateTree(53, 51, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 0.9;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(20.5, 20.5, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1;
  iSpecies = 2;
  p_oTargetTree6 = p_oPop->CreateTree(61, 50.5, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.1;
  iSpecies = 3;
  p_oTargetTree7 = p_oPop->CreateTree(60, 50.5, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.2;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(51, 53, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.3;
  iSpecies = 2;
  p_oTargetTree9 = p_oPop->CreateTree(51.2, 54, iSpecies,
      clTreePopulation::seedling, fDiam);

  fDiam = 1.4;
  iSpecies = 3;
  p_oTargetTree10 = p_oPop->CreateTree(50.5, 61, iSpecies,
      clTreePopulation::seedling, fDiam);

  //Create all neighbors
  fDiam = 10.5;
  iSpecies = 1;
  p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 2;
  p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 30;
  iSpecies = 1;
  p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 45;
  iSpecies = 2;
  p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 3;
  p_oPop->CreateTree(60, 61, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 4;
  iSpecies = 1;
  p_oPop->CreateTree(52, 52, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 4;
  iSpecies = 2;
  p_oPop->CreateTree(53, 53, iSpecies, clTreePopulation::sapling, fDiam);

  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oTargetTree = p_oPop->CreateTree(54, 54, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), natural);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 3.001857478;
  fExpectedGrowth = 4.169762464;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 3.101857478;
  fExpectedGrowth = 4.169762464;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 0.964471703;
  fExpectedGrowth = 0.440786172;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 3.021920453;
  fExpectedGrowth = 3.703200756;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 7.057716709;
  fExpectedGrowth = 10.26286118;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 1.537073722;
  fExpectedGrowth = 0.89512287;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 4.069764569;
  fExpectedGrowth = 4.949607615;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.001);

  fExpectedDiam = 3.701857478;
  fExpectedGrowth = 4.169762464;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 1.426486208;
  fExpectedGrowth = 0.210810347;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

  fExpectedDiam = 3.955374232;
  fExpectedGrowth = 4.258957053;
  p_oTargetTree = p_oTargetTree10;
  p_oTargetTree->GetValue(p_oPop->GetDiam10Code(p_oTargetTree->GetSpecies(),
      p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam)/fDiam < 0.001);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth)/fGrowth < 0.001);

}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateQuadratGrowth::WriteXMLFile(int iYearsPerTimestep) {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>3</timesteps>"
       << "<yearsPerTimestep>" << iYearsPerTimestep << "</yearsPerTimestep>";

  oOut << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<grid gridName=\"Weibull Climate Quadrat Growth\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"growth_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"growth_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"growth_2\">2</ma_floatCode>"
       << "<ma_floatCode label=\"growth_3\">3</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"num_neigh\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>2</ma_lengthYCells>"
       << "</grid>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">1</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">1</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">1</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">1</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>WeibullClimateQuadratGrowth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_weibClimQuadMaxGrowth>"
       << "<gr_wcqmgVal species=\"Species_2\">3</gr_wcqmgVal>"
       << "<gr_wcqmgVal species=\"Species_3\">2</gr_wcqmgVal>"
       << "<gr_wcqmgVal species=\"Species_4\">5.4</gr_wcqmgVal>"
       << "</gr_weibClimQuadMaxGrowth>"
       << "<gr_weibClimQuadMaxNeighRad>10</gr_weibClimQuadMaxNeighRad>"
       << "<gr_weibClimQuadCompEffC>"
       << "<gr_wcqcecVal species=\"Species_2\">0.2</gr_wcqcecVal>"
       << "<gr_wcqcecVal species=\"Species_3\">0.5</gr_wcqcecVal>"
       << "<gr_wcqcecVal species=\"Species_4\">0.3</gr_wcqcecVal>"
       << "</gr_weibClimQuadCompEffC>"
       << "<gr_weibClimQuadCompEffD>"
       << "<gr_wcqcedVal species=\"Species_2\">0.935</gr_wcqcedVal>"
       << "<gr_wcqcedVal species=\"Species_3\">1.16</gr_wcqcedVal>"
       << "<gr_wcqcedVal species=\"Species_4\">0.715</gr_wcqcedVal>"
       << "</gr_weibClimQuadCompEffD>"
       << "<gr_weibClimQuadTempEffA>"
       << "<gr_wcqteaVal species=\"Species_2\">6.88</gr_wcqteaVal>"
       << "<gr_wcqteaVal species=\"Species_3\">139.57</gr_wcqteaVal>"
       << "<gr_wcqteaVal species=\"Species_4\">6.99</gr_wcqteaVal>"
       << "</gr_weibClimQuadTempEffA>"
       << "<gr_weibClimQuadTempEffB>"
       << "<gr_wcqtebVal species=\"Species_2\">0.301</gr_wcqtebVal>"
       << "<gr_wcqtebVal species=\"Species_3\">0</gr_wcqtebVal>"
       << "<gr_wcqtebVal species=\"Species_4\">3</gr_wcqtebVal>"
       << "</gr_weibClimQuadTempEffB>"
       << "<gr_weibClimQuadTempEffC>"
       << "<gr_wcqtecVal species=\"Species_2\">14.23</gr_wcqtecVal>"
       << "<gr_wcqtecVal species=\"Species_3\">28.61</gr_wcqtecVal>"
       << "<gr_wcqtecVal species=\"Species_4\">9.67</gr_wcqtecVal>"
       << "</gr_weibClimQuadTempEffC>"
       << "<gr_weibClimQuadPrecipEffA>"
       << "<gr_wcqpeaVal species=\"Species_2\">1296.2</gr_wcqpeaVal>"
       << "<gr_wcqpeaVal species=\"Species_3\">3306.15</gr_wcqpeaVal>"
       << "<gr_wcqpeaVal species=\"Species_4\">0.001</gr_wcqpeaVal>"
       << "</gr_weibClimQuadPrecipEffA>"
       << "<gr_weibClimQuadPrecipEffB>"
       << "<gr_wcqpebVal species=\"Species_2\">0.802</gr_wcqpebVal>"
       << "<gr_wcqpebVal species=\"Species_3\">6.66</gr_wcqpebVal>"
       << "<gr_wcqpebVal species=\"Species_4\">0.052</gr_wcqpebVal>"
       << "</gr_weibClimQuadPrecipEffB>"
       << "<gr_weibClimQuadPrecipEffC>"
       << "<gr_wcqpecVal species=\"Species_2\">1032.2</gr_wcqpecVal>"
       << "<gr_wcqpecVal species=\"Species_3\">3835.9</gr_wcqpecVal>"
       << "<gr_wcqpecVal species=\"Species_4\">643.82</gr_wcqpecVal>"
       << "</gr_weibClimQuadPrecipEffC>"
       << "<gr_weibClimQuadMinNeighDBH>"
       << "<gr_wcqmndVal species=\"Species_1\">5</gr_wcqmndVal>"
       << "<gr_wcqmndVal species=\"Species_2\">5</gr_wcqmndVal>"
       << "<gr_wcqmndVal species=\"Species_3\">5</gr_wcqmndVal>"
       << "<gr_wcqmndVal species=\"Species_4\">5</gr_wcqmndVal>"
       << "</gr_weibClimQuadMinNeighDBH>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteErrorFileCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateQuadratGrowth::WriteErrorFileCommonStuff(std::fstream &oOut) {
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  oOut << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">1</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">1</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>WeibullClimateQuadratGrowth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seedling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seedling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_weibClimQuadCompEffC>"
       << "<gr_wcqcecVal species=\"Species_1\">0.2</gr_wcqcecVal>"
       << "<gr_wcqcecVal species=\"Species_2\">0.5</gr_wcqcecVal>"
       << "</gr_weibClimQuadCompEffC>"
       << "<gr_weibClimQuadCompEffD>"
       << "<gr_wcqcedVal species=\"Species_1\">0.935</gr_wcqcedVal>"
       << "<gr_wcqcedVal species=\"Species_2\">1.16</gr_wcqcedVal>"
       << "</gr_weibClimQuadCompEffD>"
       << "<gr_weibClimQuadTempEffB>"
       << "<gr_wcqtebVal species=\"Species_1\">0.301</gr_wcqtebVal>"
       << "<gr_wcqtebVal species=\"Species_2\">0</gr_wcqtebVal>"
       << "</gr_weibClimQuadTempEffB>"
       << "<gr_weibClimQuadTempEffC>"
       << "<gr_wcqtecVal species=\"Species_1\">14.23</gr_wcqtecVal>"
       << "<gr_wcqtecVal species=\"Species_2\">28.61</gr_wcqtecVal>"
       << "</gr_weibClimQuadTempEffC>"
       << "<gr_weibClimQuadPrecipEffB>"
       << "<gr_wcqpebVal species=\"Species_1\">0.802</gr_wcqpebVal>"
       << "<gr_wcqpebVal species=\"Species_2\">6.66</gr_wcqpebVal>"
       << "</gr_weibClimQuadPrecipEffB>"
       << "<gr_weibClimQuadPrecipEffC>"
       << "<gr_wcqpecVal species=\"Species_1\">1032.2</gr_wcqpecVal>"
       << "<gr_wcqpecVal species=\"Species_2\">3835.9</gr_wcqpecVal>"
       << "</gr_weibClimQuadPrecipEffC>"
       << "<gr_weibClimQuadMinNeighDBH>"
       << "<gr_wcqmndVal species=\"Species_1\">5</gr_wcqmndVal>"
       << "<gr_wcqmndVal species=\"Species_2\">5</gr_wcqmndVal>"
       << "</gr_weibClimQuadMinNeighDBH>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateQuadratGrowth::WriteXMLErrorFile1() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimQuadMaxGrowth>"
       << "<gr_wcqmgVal species=\"Species_1\">3</gr_wcqmgVal>"
       << "<gr_wcqmgVal species=\"Species_2\">2</gr_wcqmgVal>"
       << "</gr_weibClimQuadMaxGrowth>"
       << "<gr_weibClimQuadMaxNeighRad>-10</gr_weibClimQuadMaxNeighRad>"
       << "<gr_weibClimQuadTempEffA>"
       << "<gr_wcqteaVal species=\"Species_1\">6.88</gr_wcqteaVal>"
       << "<gr_wcqteaVal species=\"Species_2\">139.57</gr_wcqteaVal>"
       << "</gr_weibClimQuadTempEffA>"
       << "<gr_weibClimQuadPrecipEffA>"
       << "<gr_wcqpeaVal species=\"Species_1\">1296.2</gr_wcqpeaVal>"
       << "<gr_wcqpeaVal species=\"Species_2\">3306.15</gr_wcqpeaVal>"
       << "</gr_weibClimQuadPrecipEffA>"
       << "</growth>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateQuadratGrowth::WriteXMLErrorFile2() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimQuadMaxGrowth>"
       << "<gr_wcqmgVal species=\"Species_1\">-3</gr_wcqmgVal>"
       << "<gr_wcqmgVal species=\"Species_2\">2</gr_wcqmgVal>"
       << "</gr_weibClimQuadMaxGrowth>"
       << "<gr_weibClimQuadMaxNeighRad>10</gr_weibClimQuadMaxNeighRad>"
       << "<gr_weibClimQuadTempEffA>"
       << "<gr_wcqteaVal species=\"Species_1\">6.88</gr_wcqteaVal>"
       << "<gr_wcqteaVal species=\"Species_2\">139.57</gr_wcqteaVal>"
       << "</gr_weibClimQuadTempEffA>"
       << "<gr_weibClimQuadPrecipEffA>"
       << "<gr_wcqpeaVal species=\"Species_1\">1296.2</gr_wcqpeaVal>"
       << "<gr_wcqpeaVal species=\"Species_2\">3306.15</gr_wcqpeaVal>"
       << "</gr_weibClimQuadPrecipEffA>"
       << "</growth>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateQuadratGrowth::WriteXMLErrorFile3() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimQuadMaxGrowth>"
       << "<gr_wcqmgVal species=\"Species_1\">3</gr_wcqmgVal>"
       << "<gr_wcqmgVal species=\"Species_2\">2</gr_wcqmgVal>"
       << "</gr_weibClimQuadMaxGrowth>"
       << "<gr_weibClimQuadMaxNeighRad>10</gr_weibClimQuadMaxNeighRad>"
       << "<gr_weibClimQuadTempEffA>"
       << "<gr_wcqteaVal species=\"Species_1\">6.88</gr_wcqteaVal>"
       << "<gr_wcqteaVal species=\"Species_2\">139.57</gr_wcqteaVal>"
       << "</gr_weibClimQuadTempEffA>"
       << "<gr_weibClimQuadPrecipEffA>"
       << "<gr_wcqpeaVal species=\"Species_1\">0</gr_wcqpeaVal>"
       << "<gr_wcqpeaVal species=\"Species_2\">3306.15</gr_wcqpeaVal>"
       << "</gr_weibClimQuadPrecipEffA>"
       << "</growth>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateQuadratGrowth::WriteXMLErrorFile4() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<gr_weibClimQuadMaxGrowth>"
       << "<gr_wcqmgVal species=\"Species_1\">3</gr_wcqmgVal>"
       << "<gr_wcqmgVal species=\"Species_2\">2</gr_wcqmgVal>"
       << "</gr_weibClimQuadMaxGrowth>"
       << "<gr_weibClimQuadMaxNeighRad>10</gr_weibClimQuadMaxNeighRad>"
       << "<gr_weibClimQuadTempEffA>"
       << "<gr_wcqteaVal species=\"Species_1\">0</gr_wcqteaVal>"
       << "<gr_wcqteaVal species=\"Species_2\">139.57</gr_wcqteaVal>"
       << "</gr_weibClimQuadTempEffA>"
       << "<gr_weibClimQuadPrecipEffA>"
       << "<gr_wcqpeaVal species=\"Species_1\">1296.2</gr_wcqpeaVal>"
       << "<gr_wcqpeaVal species=\"Species_2\">3306.15</gr_wcqpeaVal>"
       << "</gr_weibClimQuadPrecipEffA>"
       << "</growth>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}
