//---------------------------------------------------------------------------
// TestWeibullClimateQuadratGrowth
//---------------------------------------------------------------------------
#if !defined(TestWeibullClimateQuadratGrowth_H)
  #define TestWeibullClimateQuadratGrowth_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clWeibullClimateGrowth class.
*/
class clTestWeibullClimateQuadratGrowth : public CppUnit::TestFixture {

  public:

  /**
  * Tests the clWeibullClimateGrowth class.
  */
  void TestWeibullClimateQuadratGrowth();

  /**
  * Performs a test run of growth for a 1-year timestep.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun1(clSimManager *p_oSimManager);

  /**
  * Performs a test run of growth for a 3-year timestep.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun2(clSimManager *p_oSimManager);

  /**
  * Tests error processing for input files.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  protected:

  /**
  * Writes a parameter file with the designated number of years per time step.
  * @param iYearsPerTimestep The desired number of years per time step.
  * @return Filename written.
  */
  char* WriteXMLFile(int iYearsPerTimestep );

  /**
  * Writes an error condition where max radius of neighbor effects is < 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error condition where max growth for a species is < 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error condition where a precipitation A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes an error condition where a temperature A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile4();

  /**
  * Writes common portions of the test error parameter files (tree pop, plot,
  * etc).  Starts at the beginning of the file and ends at the closing tree tag.
  * @param oOut File stream to write to.
  */
  void WriteErrorFileCommonStuff(std::fstream &oOut);


};

//---------------------------------------------------------------------------
#endif // TestWeibullClimateQuadratGrowth_H
