//---------------------------------------------------------------------------
// TestWeibullClimateSurvival.cpp
//---------------------------------------------------------------------------
#include "TestWeibullClimateSurvival.h"
#include <fstream>
#include <math.h>
#include "TreePopulation.h"
#include "SimManager.h"
#include "BehaviorBase.h"

using namespace std;
////////////////////////////////////////////////////////////////////////////
// TestWeibullClimateSurvival()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateSurvival::TestWeibullClimateSurvival() {
  clSimManager *p_oSimManager = new clSimManager(4, 2, "");

  TestRun1(p_oSimManager);
  TestRun2(p_oSimManager);
  TestErrorProcessing(p_oSimManager);

  delete p_oSimManager;
}

////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateSurvival::TestErrorProcessing(
    clSimManager *p_oSimManager) {

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile1.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile1.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile2.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile2.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile3.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile3.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile4.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile4.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile6());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile7());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }

  try {
    p_oSimManager->ReadFile(WriteXMLErrorFile8());
    CppUnit::Asserter::fail(
        "TestWeibullClimateSurvival error processing didn't catch error for WriteXMLErrorFile5.");
  } catch (modelErr err) {
    if (strstr(err.cFunction, "clWeibullClimateSurvival::ValidateData") == NULL) {
      CppUnit::Asserter::fail(
          "TestWeibullClimateSurvival error processing caught wrong error for WriteXMLErrorFile5.");
    };
  }
}

////////////////////////////////////////////////////////////////////////////
//  TestRun1()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateSurvival::TestRun1(clSimManager *p_oSimManager) {

  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fDiam, fTestDiam, fExpected;
  int iSpecies, i, iCount;

  /////////////////////////////////////
  // # 1
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 11;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 861.26;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 2
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 10.5;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 562.82;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 3
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 15;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(iCount == 0);

  /////////////////////////////////////
  // # 4
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 25;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 913.85;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 5
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 30;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 921.62;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 6
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 45;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 956.61;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 7
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 15;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(60, 61, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 702.52;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 8
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 4;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(52, 52, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 187.49;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 9
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 4;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(53, 53, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 200.45;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 10
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 11;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 861.26;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 11
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 2;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50.1, 50.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 149.38;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 12
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 3;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(53.1, 52.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 170.61;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 13
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 6;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(59.1, 50.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 196.95;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 14
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 7;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50.1, 59.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 331.16;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 15
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 8;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50.1, 59.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 438.88;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 16
  p_oSimManager->ReadFile(WriteXMLFile(1));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 9;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(60.1, 61.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 161.42;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);
}

////////////////////////////////////////////////////////////////////////////
// TestRun2()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateSurvival::TestRun2(clSimManager *p_oSimManager) {
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fDiam, fTestDiam, fExpected;
  int iSpecies, i, iCount;

  /////////////////////////////////////
  // # 1
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 11;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 638.87;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 2
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 10.5;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 178.28;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 3
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 15;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(iCount == 0);

  /////////////////////////////////////
  // # 4
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 25;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 763.1;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 5
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 30;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 782.81;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 6
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 45;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 875.4;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 7
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 15;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(60, 61, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 346.73;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 8
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 4;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(52, 52, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 6.59;
  CPPUNIT_ASSERT(iCount < 20);

  /////////////////////////////////////
  // # 9
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 4;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(53, 53, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 8.0;
  CPPUNIT_ASSERT(iCount < 15);

  /////////////////////////////////////
  // # 10
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 11;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::adult, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::adult &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 638.87;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 11
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 2;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50.1, 50.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 3.33;
  CPPUNIT_ASSERT(iCount < 10);

  /////////////////////////////////////
  // # 12
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 3;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(53.1, 52.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 4.96;
  CPPUNIT_ASSERT(iCount < 10);

  /////////////////////////////////////
  // # 13
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 6;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(59.1, 50.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 7.63;
  CPPUNIT_ASSERT(iCount < 15);

  /////////////////////////////////////
  // # 14
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 7;
  iSpecies = 1;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50.1, 59.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 36.31;
  CPPUNIT_ASSERT(iCount > 25 && iCount < 50);

  /////////////////////////////////////
  // # 15
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 8;
  iSpecies = 2;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(50.1, 59.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 84.53;
  CPPUNIT_ASSERT(fabs(iCount - fExpected)/fExpected < 0.1);

  /////////////////////////////////////
  // # 16
  p_oSimManager->ReadFile(WriteXMLFile(3));
  p_oPop = (clTreePopulation *) p_oSimManager->GetPopulationObject(
      "treepopulation");

  CreateTrees(p_oPop);
  //Create 999 more of our target
  fDiam = 9;
  iSpecies = 3;
  for (i = 0; i < 999; i++) {
    p_oPop->CreateTree(60.1, 61.1, iSpecies, clTreePopulation::sapling, fDiam);
  }

  //Now do the run and count the targets
  p_oSimManager->RunSim(1);
  iCount = 0;
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    if (p_oTree->GetType() == clTreePopulation::sapling &&
        p_oTree->GetSpecies() == iSpecies) {
      p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fTestDiam);
      if (fabs(fDiam - fTestDiam) < 0.001) iCount++;
    }
    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 4.20;
  CPPUNIT_ASSERT(iCount < 10);
}

////////////////////////////////////////////////////////////////////////////
// CreateTrees()
////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateSurvival::CreateTrees(clTreePopulation *p_oPop) {

  clTree *p_oTargetTree;
  float fDiam;
  int iSpecies;

  fDiam = 11;
  iSpecies = 1;
  p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  iSpecies = 1;
  p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 2;
  p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 30;
  iSpecies = 1;
  p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 45;
  iSpecies = 2;
  p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 3;
  p_oPop->CreateTree(60, 61, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 4;
  iSpecies = 1;
  p_oPop->CreateTree(52, 52, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 4;
  iSpecies = 2;
  p_oPop->CreateTree(53, 53, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 11;
  iSpecies = 1;
  p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 2;
  iSpecies = 1;
  p_oPop->CreateTree(50.1, 50.1, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 3;
  iSpecies = 2;
  p_oPop->CreateTree(53.1, 52.1, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 6;
  iSpecies = 3;
  p_oPop->CreateTree(59.1, 50.1, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 7;
  iSpecies = 1;
  p_oPop->CreateTree(50.1, 59.1, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 8;
  iSpecies = 2;
  p_oPop->CreateTree(55.1, 55.1, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 9;
  iSpecies = 3;
  p_oPop->CreateTree(60.1, 61.1, iSpecies, clTreePopulation::sapling, fDiam);

  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oTargetTree = p_oPop->CreateTree(54, 54, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead",
      p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLFile(int iYearsPerTimestep) {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>" << iYearsPerTimestep << "</yearsPerTimestep>";

  oOut << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";

  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>WeibullClimateSurvival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_2\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_3\">1</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_4\">0.98</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimJuvMaxSurv>"
       << "<mo_wcjmsVal species=\"Species_2\">1</mo_wcjmsVal>"
       << "<mo_wcjmsVal species=\"Species_3\">0.974</mo_wcjmsVal>"
       << "<mo_wcjmsVal species=\"Species_4\">0.85</mo_wcjmsVal>"
       << "</mo_weibClimJuvMaxSurv>"
       << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_2\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_3\">11</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_4\">12</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultSizeEffX0>"
       << "<mo_wcasex0Val species=\"Species_2\">30.48</mo_wcasex0Val>"
       << "<mo_wcasex0Val species=\"Species_3\">29.6</mo_wcasex0Val>"
       << "<mo_wcasex0Val species=\"Species_4\">26.6</mo_wcasex0Val>"
       << "</mo_weibClimAdultSizeEffX0>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_2\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_3\">12.8</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_4\">8.53</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_2\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_3\">2.85</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_4\">1.19</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffXb>"
       << "<mo_wcjsexbVal species=\"Species_2\">1.53</mo_wcjsexbVal>"
       << "<mo_wcjsexbVal species=\"Species_3\">2.63</mo_wcjsexbVal>"
       << "<mo_wcjsexbVal species=\"Species_4\">0.84</mo_wcjsexbVal>"
       << "</mo_weibClimJuvSizeEffXb>"
       << "<mo_weibClimSizeEffMinDBH>"
       << "<mo_wcsemdVal species=\"Species_2\">2.54</mo_wcsemdVal>"
       << "<mo_wcsemdVal species=\"Species_3\">7</mo_wcsemdVal>"
       << "<mo_wcsemdVal species=\"Species_4\">10</mo_wcsemdVal>"
       << "</mo_weibClimSizeEffMinDBH>"
       << "<mo_weibClimAdultCompEffC>"
       << "<mo_wcacecVal species=\"Species_2\">1.1</mo_wcacecVal>"
       << "<mo_wcacecVal species=\"Species_3\">6.7</mo_wcacecVal>"
       << "<mo_wcacecVal species=\"Species_4\">0.25</mo_wcacecVal>"
       << "</mo_weibClimAdultCompEffC>"
       << "<mo_weibClimAdultCompEffD>"
       << "<mo_wcacedVal species=\"Species_2\">1.35</mo_wcacedVal>"
       << "<mo_wcacedVal species=\"Species_3\">0.874</mo_wcacedVal>"
       << "<mo_wcacedVal species=\"Species_4\">2.05</mo_wcacedVal>"
       << "</mo_weibClimAdultCompEffD>"
       << "<mo_weibClimAdultCompEffGamma>"
       << "<mo_wcacegVal species=\"Species_2\">-1.208</mo_wcacegVal>"
       << "<mo_wcacegVal species=\"Species_3\">1.976</mo_wcacegVal>"
       << "<mo_wcacegVal species=\"Species_4\">-1</mo_wcacegVal>"
       << "</mo_weibClimAdultCompEffGamma>"
       << "<mo_weibClimJuvCompEffC>"
       << "<mo_wcjcecVal species=\"Species_2\">0.2</mo_wcjcecVal>"
       << "<mo_wcjcecVal species=\"Species_3\">0.5</mo_wcjcecVal>"
       << "<mo_wcjcecVal species=\"Species_4\">0.6</mo_wcjcecVal>"
       << "</mo_weibClimJuvCompEffC>"
       << "<mo_weibClimJuvCompEffD>"
       << "<mo_wcjcedVal species=\"Species_2\">0.93</mo_wcjcedVal>"
       << "<mo_wcjcedVal species=\"Species_3\">1.16</mo_wcjcedVal>"
       << "<mo_wcjcedVal species=\"Species_4\">0.072</mo_wcjcedVal>"
       << "</mo_weibClimJuvCompEffD>"
       << "<mo_weibClimJuvCompEffGamma>"
       << "<mo_wcjcegVal species=\"Species_2\">-0.061</mo_wcjcegVal>"
       << "<mo_wcjcegVal species=\"Species_3\">-1.405</mo_wcjcegVal>"
       << "<mo_wcjcegVal species=\"Species_4\">0.39</mo_wcjcegVal>"
       << "</mo_weibClimJuvCompEffGamma>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_2\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_3\">8.91133</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_4\">6.996252</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultTempEffB>"
       << "<mo_wcatebVal species=\"Species_2\">1.205544</mo_wcatebVal>"
       << "<mo_wcatebVal species=\"Species_3\">1.475192</mo_wcatebVal>"
       << "<mo_wcatebVal species=\"Species_4\">3.000519</mo_wcatebVal>"
       << "</mo_weibClimAdultTempEffB>"
       << "<mo_weibClimAdultTempEffC>"
       << "<mo_wcatecVal species=\"Species_2\">13.2644</mo_wcatecVal>"
       << "<mo_wcatecVal species=\"Species_3\">12.4024</mo_wcatecVal>"
       << "<mo_wcatecVal species=\"Species_4\">9.6727</mo_wcatecVal>"
       << "</mo_weibClimAdultTempEffC>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_2\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_3\">4777.299</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_4\">1636.351</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimAdultPrecipEffB>"
       << "<mo_wcapebVal species=\"Species_2\">2.890661</mo_wcapebVal>"
       << "<mo_wcapebVal species=\"Species_3\">1.29611</mo_wcapebVal>"
       << "<mo_wcapebVal species=\"Species_4\">1.692687</mo_wcapebVal>"
       << "</mo_weibClimAdultPrecipEffB>"
       << "<mo_weibClimAdultPrecipEffC>"
       << "<mo_wcapecVal species=\"Species_2\">1449.694</mo_wcapecVal>"
       << "<mo_wcapecVal species=\"Species_3\">1650.96</mo_wcapecVal>"
       << "<mo_wcapecVal species=\"Species_4\">1315.7</mo_wcapecVal>"
       << "</mo_weibClimAdultPrecipEffC>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_2\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_3\">9853.651</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_4\">2089.756</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffB>"
       << "<mo_wcjpebVal species=\"Species_2\">1.320871</mo_wcjpebVal>"
       << "<mo_wcjpebVal species=\"Species_3\">0.9795493</mo_wcjpebVal>"
       << "<mo_wcjpebVal species=\"Species_4\">2.626266</mo_wcjpebVal>"
       << "</mo_weibClimJuvPrecipEffB>"
       << "<mo_weibClimJuvPrecipEffC>"
       << "<mo_wcjpecVal species=\"Species_2\">1099.235</mo_wcjpecVal>"
       << "<mo_wcjpecVal species=\"Species_3\">708.4292</mo_wcjpecVal>"
       << "<mo_wcjpecVal species=\"Species_4\">1580.326</mo_wcjpecVal>"
       << "</mo_weibClimJuvPrecipEffC>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_2\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_3\">139.5745</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_4\">6.996252</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimJuvTempEffB>"
       << "<mo_wcjtebVal species=\"Species_2\">0.3014869</mo_wcjtebVal>"
       << "<mo_wcjtebVal species=\"Species_3\">0</mo_wcjtebVal>"
       << "<mo_wcjtebVal species=\"Species_4\">3.000519</mo_wcjtebVal>"
       << "</mo_weibClimJuvTempEffB>"
       << "<mo_weibClimJuvTempEffC>"
       << "<mo_wcjtecVal species=\"Species_2\">14.2357</mo_wcjtecVal>"
       << "<mo_wcjtecVal species=\"Species_3\">28.6192</mo_wcjtecVal>"
       << "<mo_wcjtecVal species=\"Species_4\">9.6727</mo_wcjtecVal>"
       << "</mo_weibClimJuvTempEffC>"
       << "<mo_weibClimMinNeighDBH>"
       << "<mo_wcmndVal species=\"Species_1\">5</mo_wcmndVal>"
       << "<mo_wcmndVal species=\"Species_2\">5</mo_wcmndVal>"
       << "<mo_wcmndVal species=\"Species_3\">5</mo_wcmndVal>"
       << "<mo_wcmndVal species=\"Species_4\">5</mo_wcmndVal>"
       << "</mo_weibClimMinNeighDBH>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteErrorFileCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullClimateSurvival::WriteErrorFileCommonStuff(std::fstream &oOut) {
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>WeibullClimateSurvival</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_weibClimJuvMaxSurv>"
       << "<mo_wcjmsVal species=\"Species_1\">1</mo_wcjmsVal>"
       << "<mo_wcjmsVal species=\"Species_2\">0.974</mo_wcjmsVal>"
       << "</mo_weibClimJuvMaxSurv>"
       << "<mo_weibClimAdultSizeEffX0>"
       << "<mo_wcasex0Val species=\"Species_1\">30.48</mo_wcasex0Val>"
       << "<mo_wcasex0Val species=\"Species_2\">29.6</mo_wcasex0Val>"
       << "</mo_weibClimAdultSizeEffX0>"
       << "<mo_weibClimJuvSizeEffXb>"
       << "<mo_wcjsexbVal species=\"Species_1\">1.53</mo_wcjsexbVal>"
       << "<mo_wcjsexbVal species=\"Species_2\">2.63</mo_wcjsexbVal>"
       << "</mo_weibClimJuvSizeEffXb>"
       << "<mo_weibClimSizeEffMinDBH>"
       << "<mo_wcsemdVal species=\"Species_1\">2.54</mo_wcsemdVal>"
       << "<mo_wcsemdVal species=\"Species_2\">7</mo_wcsemdVal>"
       << "</mo_weibClimSizeEffMinDBH>"
       << "<mo_weibClimAdultCompEffC>"
       << "<mo_wcacecVal species=\"Species_1\">1.1</mo_wcacecVal>"
       << "<mo_wcacecVal species=\"Species_2\">6.7</mo_wcacecVal>"
       << "</mo_weibClimAdultCompEffC>"
       << "<mo_weibClimAdultCompEffD>"
       << "<mo_wcacedVal species=\"Species_1\">1.35</mo_wcacedVal>"
       << "<mo_wcacedVal species=\"Species_2\">0.874</mo_wcacedVal>"
       << "</mo_weibClimAdultCompEffD>"
       << "<mo_weibClimAdultCompEffGamma>"
       << "<mo_wcacegVal species=\"Species_1\">-1.208</mo_wcacegVal>"
       << "<mo_wcacegVal species=\"Species_2\">1.976</mo_wcacegVal>"
       << "</mo_weibClimAdultCompEffGamma>"
       << "<mo_weibClimJuvCompEffC>"
       << "<mo_wcjcecVal species=\"Species_1\">0.2</mo_wcjcecVal>"
       << "<mo_wcjcecVal species=\"Species_2\">0.5</mo_wcjcecVal>"
       << "</mo_weibClimJuvCompEffC>"
       << "<mo_weibClimJuvCompEffD>"
       << "<mo_wcjcedVal species=\"Species_1\">0.93</mo_wcjcedVal>"
       << "<mo_wcjcedVal species=\"Species_2\">1.16</mo_wcjcedVal>"
       << "</mo_weibClimJuvCompEffD>"
       << "<mo_weibClimJuvCompEffGamma>"
       << "<mo_wcjcegVal species=\"Species_1\">-0.061</mo_wcjcegVal>"
       << "<mo_wcjcegVal species=\"Species_2\">-0.405</mo_wcjcegVal>"
       << "</mo_weibClimJuvCompEffGamma>"
       << "<mo_weibClimAdultTempEffB>"
       << "<mo_wcatebVal species=\"Species_1\">1.205544</mo_wcatebVal>"
       << "<mo_wcatebVal species=\"Species_2\">1.475192</mo_wcatebVal>"
       << "</mo_weibClimAdultTempEffB>"
       << "<mo_weibClimAdultTempEffC>"
       << "<mo_wcatecVal species=\"Species_1\">13.2644</mo_wcatecVal>"
       << "<mo_wcatecVal species=\"Species_2\">12.4024</mo_wcatecVal>"
       << "</mo_weibClimAdultTempEffC>"
       << "<mo_weibClimAdultPrecipEffB>"
       << "<mo_wcapebVal species=\"Species_1\">2.890661</mo_wcapebVal>"
       << "<mo_wcapebVal species=\"Species_2\">1.29611</mo_wcapebVal>"
       << "</mo_weibClimAdultPrecipEffB>"
       << "<mo_weibClimAdultPrecipEffC>"
       << "<mo_wcapecVal species=\"Species_1\">1449.694</mo_wcapecVal>"
       << "<mo_wcapecVal species=\"Species_2\">1650.96</mo_wcapecVal>"
       << "</mo_weibClimAdultPrecipEffC>"
       << "<mo_weibClimJuvPrecipEffB>"
       << "<mo_wcjpebVal species=\"Species_1\">1.320871</mo_wcjpebVal>"
       << "<mo_wcjpebVal species=\"Species_2\">0.9795493</mo_wcjpebVal>"
       << "</mo_weibClimJuvPrecipEffB>"
       << "<mo_weibClimJuvPrecipEffC>"
       << "<mo_wcjpecVal species=\"Species_1\">1099.235</mo_wcjpecVal>"
       << "<mo_wcjpecVal species=\"Species_2\">708.4292</mo_wcjpecVal>"
       << "</mo_weibClimJuvPrecipEffC>"
       << "<mo_weibClimJuvTempEffB>"
       << "<mo_wcjtebVal species=\"Species_1\">0.3014869</mo_wcjtebVal>"
       << "<mo_wcjtebVal species=\"Species_2\">0</mo_wcjtebVal>"
       << "</mo_weibClimJuvTempEffB>"
       << "<mo_weibClimJuvTempEffC>"
       << "<mo_wcjtecVal species=\"Species_1\">14.2357</mo_wcjtecVal>"
       << "<mo_wcjtecVal species=\"Species_2\">28.6192</mo_wcjtecVal>"
       << "</mo_weibClimJuvTempEffC>"
       << "<mo_weibClimMinNeighDBH>"
       << "<mo_wcmndVal species=\"Species_1\">5</mo_wcmndVal>"
       << "<mo_wcmndVal species=\"Species_2\">5</mo_wcmndVal>"
       << "</mo_weibClimMinNeighDBH>";

}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile1() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">-10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">12.8</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">139.5745</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">9853.651</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile2() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">-0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">12.8</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">139.5745</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">9853.651</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile3() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">0</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">12.8</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">139.5745</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">9853.651</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile4() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">0</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">139.5745</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">9853.651</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile5()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile5() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">12.8</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">139.5745</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">0</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">9853.651</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile6()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile6() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">12.8</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">139.5745</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">0</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile7()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile7() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">12.8</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">139.5745</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">0</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">9853.651</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile8()
////////////////////////////////////////////////////////////////////////////
char* clTestWeibullClimateSurvival::WriteXMLErrorFile8() {
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  oOut << "<mo_weibClimMaxNeighRad>"
       << "<mo_wcmnrVal species=\"Species_1\">10</mo_wcmnrVal>"
       << "<mo_wcmnrVal species=\"Species_2\">11</mo_wcmnrVal>"
       << "</mo_weibClimMaxNeighRad>"
       << "<mo_weibClimAdultMaxSurv>"
       << "<mo_wcamsVal species=\"Species_1\">0.95</mo_wcamsVal>"
       << "<mo_wcamsVal species=\"Species_2\">1</mo_wcamsVal>"
       << "</mo_weibClimAdultMaxSurv>"
       << "<mo_weibClimAdultSizeEffXb>"
       << "<mo_wcasexbVal species=\"Species_1\">2.46</mo_wcasexbVal>"
       << "<mo_wcasexbVal species=\"Species_2\">2.85</mo_wcasexbVal>"
       << "</mo_weibClimAdultSizeEffXb>"
       << "<mo_weibClimJuvSizeEffX0>"
       << "<mo_wcjsex0Val species=\"Species_1\">7.75</mo_wcjsex0Val>"
       << "<mo_wcjsex0Val species=\"Species_2\">12.8</mo_wcjsex0Val>"
       << "</mo_weibClimJuvSizeEffX0>"
       << "<mo_weibClimJuvTempEffA>"
       << "<mo_wcjteaVal species=\"Species_1\">6.884225</mo_wcjteaVal>"
       << "<mo_wcjteaVal species=\"Species_2\">0</mo_wcjteaVal>"
       << "</mo_weibClimJuvTempEffA>"
       << "<mo_weibClimAdultTempEffA>"
       << "<mo_wcateaVal species=\"Species_1\">8.897617</mo_wcateaVal>"
       << "<mo_wcateaVal species=\"Species_2\">8.91133</mo_wcateaVal>"
       << "</mo_weibClimAdultTempEffA>"
       << "<mo_weibClimAdultPrecipEffA>"
       << "<mo_wcapeaVal species=\"Species_1\">2593.648</mo_wcapeaVal>"
       << "<mo_wcapeaVal species=\"Species_2\">4777.299</mo_wcapeaVal>"
       << "</mo_weibClimAdultPrecipEffA>"
       << "<mo_weibClimJuvPrecipEffA>"
       << "<mo_wcjpeaVal species=\"Species_1\">2362.133</mo_wcjpeaVal>"
       << "<mo_wcjpeaVal species=\"Species_2\">9853.651</mo_wcjpeaVal>"
       << "</mo_weibClimJuvPrecipEffA>"
       << "</mortality>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}
