//---------------------------------------------------------------------------
// TestWeibullClimateSurvival
//---------------------------------------------------------------------------
#if !defined(TestWeibullClimateSurvival_H)
  #define TestWeibullClimateSurvival_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;
class clTreePopulation;

/**
* Tests the clWeibullClimateSurvival class.
*/
class clTestWeibullClimateSurvival : public CppUnit::TestFixture {

  public:

  /**
  * Tests the clWeibullClimateSurvival class.
  */
  void TestWeibullClimateSurvival();

  /**
  * Performs a test run of survival. WriteXMLFile1() performs setup for a
  * 1-year timestep.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun1(clSimManager *p_oSimManager);

  /**
  * Performs a test run of survival. WriteXMLFile2() performs setup for a
  * 3-year timestep.
  * @param p_oSimManager Sim Manager object to do the runs.
  */
  void TestRun2(clSimManager *p_oSimManager);

  /**
  * Tests error processing for input files.
  *
  * WriteXMLErrorFileX (where X = 1-8) is written and checked to make sure that
  * each produces an error.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  protected:

  void CreateTrees(clTreePopulation *p_oPop);

  /**
  * Writes a parameter file with the designated number of years per time step.
  * @param iYearsPerTimestep The desired number of years per time step.
  * @return Filename written.
  */
  char* WriteXMLFile(int iYearsPerTimestep );

  /**
  * Writes an error condition where max radius of neighbor effects is < 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error condition where max survival for a species is < 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error condition where Xb for a species = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes an error condition where X0 for a species = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile4();

  /**
  * Writes an error condition where an adult precipitation A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile5();

  /**
  * Writes an error condition where a juvenile precipitation A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile6();

  /**
  * Writes an error condition where an adult temperature A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile7();

  /**
  * Writes an error condition where a juvenile temperature A = 0.
  * @return Filename written.
  */
  char* WriteXMLErrorFile8();


  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * Picks up right after the number of years per timestep and finishes out the
  * file.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * @param oOut File stream to write to.
  */
  void WriteTreeStuff(std::fstream &oOut);

  /**
  * Writes common portions of the test error parameter files (tree pop, plot,
  * etc).  Starts at the beginning of the file and ends at the closing tree tag.
  * @param oOut File stream to write to.
  */
  void WriteErrorFileCommonStuff(std::fstream &oOut);


};

//---------------------------------------------------------------------------
#endif // TestWeibullClimateSurvival_H
