//---------------------------------------------------------------------------
// TestWeibullSnagMort.cpp
//---------------------------------------------------------------------------
#include "TestWeibullSnagMort.h"
#include "TreePopulation.h"
#include "SimManager.h"
#include <fstream>
#include <math.h>

/////////////////////////////////////////////////////////////////////////////
//  TestMortality()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullSnagMort::TestWeibullSnagMort() {
  clSimManager *p_oSimManager = new clSimManager(3, 2, "");

  TestNormalProcessing(p_oSimManager);
  TestExceptionProcessing(p_oSimManager);
  TestBackwardsCompatibility(p_oSimManager);

  delete p_oSimManager;
}

/////////////////////////////////////////////////////////////////////////////
//  TestExceptionProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullSnagMort::TestExceptionProcessing(clSimManager *p_oSimManager) {

  //Load our error files and make sure we get the error we expect
  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestWeibullSnagMort error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clWeibullSnagMort::ReadParameterFile") == NULL)
    {
      CppUnit::Asserter::fail("TestWeibullSnagMort error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestWeibullSnagMort error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clWeibullSnagMort::ValidateTypes") == NULL)
    {
      CppUnit::Asserter::fail("TestWeibullSnagMort error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }


}

/////////////////////////////////////////////////////////////////////////////
//  TestNormalProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullSnagMort::TestNormalProcessing(clSimManager *p_oSimManager) {
  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float *p_fSizeClass1, *p_fSizeClass2;
  float fDbh, fExpected;
  int **p_iTreeCount;
  int i, j, iNumSpecies = 4, iNumSizeClasses = 3;

  p_fSizeClass1 = new float[iNumSpecies];
  p_fSizeClass2 = new float[iNumSpecies];
  p_fSizeClass1[0] = 12;
  p_fSizeClass2[0] = 30;
  p_fSizeClass1[1] = 8;
  p_fSizeClass2[1] = 21;
  p_fSizeClass1[2] = 31;
  p_fSizeClass2[2] = 39;
  p_fSizeClass1[3] = 12;
  p_fSizeClass2[3] = 30;

  //******************************************
  // Run 1
  //******************************************

  //Create the sim manager and load our file
  p_oSimManager->ReadFile( WriteXMLFile1() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Set up our tree count array
  p_iTreeCount = new int*[iNumSpecies];
  for (i = 0; i < iNumSpecies; i++) {
    p_iTreeCount[i] = new int[iNumSizeClasses];
  }

  //Create 1000 of each species and each size class
  //Species 1, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::snag, 11);
  }

  //Species 1, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(10, 10, 0, clTreePopulation::snag, 25);
  }

  //Species 1, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(20, 20, 0, clTreePopulation::snag, 37);
  }

  //Species 2, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(30, 30, 1, clTreePopulation::snag, 7);
  }

  //Species 2, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(40, 40, 1, clTreePopulation::snag, 17);
  }

  //Species 2, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(50, 50, 1, clTreePopulation::snag, 22);
  }

  //Species 3, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(60, 60, 2, clTreePopulation::snag, 28);
  }

  //Species 3, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(70, 70, 2, clTreePopulation::snag, 35);
  }

  //Species 3, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(80, 80, 2, clTreePopulation::snag, 44);
  }

  //Species 4, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 3, clTreePopulation::snag, 11);
  }

  //Species 4, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(10, 10, 3, clTreePopulation::snag, 25);
  }

  //Species 4, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(20, 20, 3, clTreePopulation::snag, 37);
  }


  //*****************Timestep 1************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[0][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] == 1000);


  //*****************Timestep 2************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 998.7041503;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 999.9479092;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 995.0006661;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.9843751;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 991.9327166;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 999.9405622;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);


  //*****************Timestep 3************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 989.325481;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 999.7606758;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 975.6207397;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.8750078;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 968.1192569;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 999.6638157;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);


  //*****************Timestep 4************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 963.7272362;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 999.4161349;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 939.210099;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.578214;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 929.6937948;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 999.0738585;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);


  //*****************Timestep 5************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 915.0090781;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 998.9008277;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 885.550984;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.0004998;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 878.4467393;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 998.0997426;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 6************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 839.1327838;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 998.204785;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 816.2267366;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 998.0487811;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 816.6864826;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected =   996.6827432;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 7************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 736.5433214;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 997.3200744;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 734.2907643;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 996.6306889;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 747.0673031;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 994.7722373;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 8************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 613.0796381;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 996.2401498;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 643.8583783;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 994.6549608;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 672.4012624;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 992.3237645;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 9************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 479.448485;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 994.9594989;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 549.6030401;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 992.0319148;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 595.4725422;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.06);
  fExpected = 989.297973;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 10************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 348.9798423;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 993.47343;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 456.2119428;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 988.6740026;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 518.8709905;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 985.6600039;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 31************************
  p_oSimManager->RunSim(21);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 0);
  fExpected = 911.591407;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] == 0);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 655.8160113;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[2][1] <= 2);
  fExpected = 746.016637;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //******************************************
  // Run 2
  //******************************************

  //Create the sim manager and load our file
  p_oSimManager->ReadFile( WriteXMLFile2() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create 1000 of each species and each size class
  //Species 1, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::snag, 11);
  }

  //Species 1, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(10, 10, 0, clTreePopulation::snag, 25);
  }

  //Species 1, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(20, 20, 0, clTreePopulation::snag, 37);
  }

  //Species 2, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(30, 30, 1, clTreePopulation::snag, 7);
  }

  //Species 2, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(40, 40, 1, clTreePopulation::snag, 17);
  }

  //Species 2, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(50, 50, 1, clTreePopulation::snag, 22);
  }

  //Species 3, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(60, 60, 2, clTreePopulation::snag, 28);
  }

  //Species 3, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(70, 70, 2, clTreePopulation::snag, 35);
  }

  //Species 3, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(80, 80, 2, clTreePopulation::snag, 44);
  }

  //Species 4, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 3, clTreePopulation::snag, 11);
  }

  //Species 4, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(10, 10, 3, clTreePopulation::snag, 25);
  }

  //Species 4, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(20, 20, 3, clTreePopulation::snag, 37);
  }

  //*****************Timestep 1************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[0][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] == 1000);

  //*****************Timestep 2************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 963.7272362;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 999.4161349;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 939.210099;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.578214;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 929.6937948;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 999.0738585;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 3************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 736.5433214;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 997.3200744;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 734.2907643;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 996.6306889;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 747.0673031;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 994.7722373;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 4************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 348.9798423;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.07);
  fExpected = 993.47343;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 456.2119428;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.07);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 988.6740026;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 518.8709905;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 985.6600039;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 5************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 79.59440592;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.1);
  fExpected = 987.7454719;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 218.5027334;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.15);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 973.3612415;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 311.4862758;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.07);
  fExpected = 970.7849947;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 6************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] <= 10);
  fExpected = 980.0562787;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 78.78516157;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.15);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 948.6319594;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 161.6211925;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.1);
  fExpected = 949.521718;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 7************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] < 5);
  fExpected = 970.3615655;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 20.96716446;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.2);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 912.9035908;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 72.48323393;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.27);
  fExpected = 921.5423789;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 8************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 0 || p_iTreeCount[0][0] == 1);
  fExpected = 958.6461017;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] <= 10);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 865.2791347;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 28.09678843;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.22);
  fExpected = 886.811969;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 9************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 0);
  fExpected = 944.920126;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] < 5);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 805.7353019;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[2][1] <= 15);
  fExpected = 845.5844702;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 10************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 0);
  fExpected = 929.2170022;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] == 0 || p_iTreeCount[0][2] == 1);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 735.248402;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 2.726054373;
  CPPUNIT_ASSERT(p_iTreeCount[2][1] <= 10);
  fExpected = 798.3911201;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //*****************Timestep 31************************
  p_oSimManager->RunSim(21);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= p_fSizeClass1[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= p_fSizeClass2[p_oTree->GetSpecies()])
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 0);
  fExpected = 354.2395461;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] == 0);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][0] == 0 || p_iTreeCount[2][0] == 1);
  CPPUNIT_ASSERT(p_iTreeCount[2][1] == 0);
  CPPUNIT_ASSERT(p_iTreeCount[2][2] < 20);
  CPPUNIT_ASSERT(p_iTreeCount[3][0] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][1] < 2);
  CPPUNIT_ASSERT(p_iTreeCount[3][2] < 2);

  //Cleanup
  for (i = 0; i < iNumSpecies; i++) delete[] p_iTreeCount[i];
    delete[] p_iTreeCount;
  delete[] p_fSizeClass1;
  delete[] p_fSizeClass2;
}

/////////////////////////////////////////////////////////////////////////////
//  TestBackwardsCompatibility()
/////////////////////////////////////////////////////////////////////////////
void clTestWeibullSnagMort::TestBackwardsCompatibility(clSimManager *p_oSimManager) {
  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTreeSearch *p_oAllTrees;
  clTree *p_oTree;
  float fDbh, fSizeClass1 = 12, fSizeClass2 = 30, fExpected;
  int **p_iTreeCount;
  int i, j, iNumSpecies = 3, iNumSizeClasses = 3;

  //******************************************
  // Run 1
  //******************************************

  //Create the sim manager and load our file
  p_oSimManager->ReadFile( WriteXMLFile3() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Set up our tree count array
  p_iTreeCount = new int*[iNumSpecies];
  for (i = 0; i < iNumSpecies; i++) {
    p_iTreeCount[i] = new int[iNumSizeClasses];
  }

  //Create 1000 of each species and each size class
  //Species 1, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(1, 1, 0, clTreePopulation::snag, 11);
  }

  //Species 1, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(10, 10, 0, clTreePopulation::snag, 25);
  }

  //Species 1, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(20, 20, 0, clTreePopulation::snag, 37);
  }

  //Species 2, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(30, 30, 1, clTreePopulation::snag, 11);
  }

  //Species 2, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(40, 40, 1, clTreePopulation::snag, 25);
  }

  //Species 2, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(50, 50, 1, clTreePopulation::snag, 37);
  }

  //Species 3, size class 1
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(60, 60, 2, clTreePopulation::snag, 11);
  }

  //Species 3, size class 2
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(70, 70, 2, clTreePopulation::snag, 25);
  }

  //Species 3, size class 3
  for (i = 0; i < 1000; i++) {
    p_oTree = p_oPop->CreateTree(80, 80, 2, clTreePopulation::snag, 37);
  }

  //*****************Timestep 1************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[0][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[2][2] == 1000);

  //*****************Timestep 2************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 998.7041503;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 999.9479092;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 995.0006661;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.9843751;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 991.9327166;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 999.9405622;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 3************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 989.325481;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 999.7606758;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 975.6207397;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.8750078;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 968.1192569;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 999.6638157;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 4************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 963.7272362;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 999.4161349;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 939.210099;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.578214;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 929.6937948;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 999.0738585;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 5************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 915.0090781;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 998.9008277;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 885.550984;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 999.0004998;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 878.4467393;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 998.0997426;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 6************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 839.1327838;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 998.204785;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 816.2267366;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 998.0487811;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 816.6864826;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected =   996.6827432;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 7************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 736.5433214;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 997.3200744;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 734.2907643;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 996.6306889;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 747.0673031;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 994.7722373;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 8************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 613.0796381;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 996.2401498;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 643.8583783;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 994.6549608;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 672.4012624;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 992.3237645;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 9************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 479.448485;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 994.9594989;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 549.6030401;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 992.0319148;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 595.4725422;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 989.297973;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 10************************
  p_oSimManager->RunSim(1);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  fExpected = 348.9798423;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][0] - fExpected)/fExpected < 0.05);
  fExpected = 993.47343;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  fExpected = 456.2119428;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][2] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 988.6740026;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  fExpected = 518.8709905;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][1] - fExpected)/fExpected < 0.05);
  fExpected = 985.6600039;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //*****************Timestep 31************************
  p_oSimManager->RunSim(21);
  //Zero out the array and re-count
  for (i = 0; i < iNumSpecies; i++) {
    for (j = 0; j < iNumSizeClasses; j++) {
      p_iTreeCount[i][j] = 0;
    }
  }
  p_oAllTrees = p_oPop->Find("all");
  p_oTree = p_oAllTrees->NextTree();
  while (p_oTree) {
    CPPUNIT_ASSERT(p_oTree->GetType() == clTreePopulation::snag);
    p_oTree->GetValue(p_oPop->GetDbhCode(p_oTree->GetSpecies(), p_oTree->GetType()), &fDbh);

    if (fDbh <= fSizeClass1)
      p_iTreeCount[p_oTree->GetSpecies()][0]++;
    else if (fDbh <= fSizeClass2)
      p_iTreeCount[p_oTree->GetSpecies()][1]++;
    else
      p_iTreeCount[p_oTree->GetSpecies()][2]++;

    p_oTree = p_oAllTrees->NextTree();
  }
  CPPUNIT_ASSERT(p_iTreeCount[0][0] == 0);
  fExpected = 911.591407;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[0][1] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[0][2] == 0);
  CPPUNIT_ASSERT(p_iTreeCount[1][0] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][1] == 1000);
  CPPUNIT_ASSERT(p_iTreeCount[1][2] == 1000);
  fExpected = 655.8160113;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][0] - fExpected)/fExpected < 0.05);
  CPPUNIT_ASSERT(p_iTreeCount[2][1] == 0 || p_iTreeCount[2][1] == 1);
  fExpected = 746.016637;
  CPPUNIT_ASSERT(fabs(p_iTreeCount[2][2] - fExpected)/fExpected < 0.05);

  //Cleanup
  for (i = 0; i < iNumSpecies; i++) delete[] p_iTreeCount[i];
    delete[] p_iTreeCount;
}


/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestWeibullSnagMort::WriteXMLFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>50</timesteps>"
       << "<randomSeed>1</randomSeed>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>0.0</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.7</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.7</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.7</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.7</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>weibull snag mortality</behaviorName>"
       << "<version>1.1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "<applyTo species=\"Species_4\" type=\"Snag\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>2.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "<applyTo species=\"Species_4\" type=\"Snag\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_snagSizeClass1DBH>"
       << "<mo_sc1dVal species=\"Species_3\">31</mo_sc1dVal>"
       << "<mo_sc1dVal species=\"Species_1\">12</mo_sc1dVal>"
       << "<mo_sc1dVal species=\"Species_4\">12</mo_sc1dVal>"
       << "</mo_snagSizeClass1DBH>"
       << "<mo_snagSizeClass2DBH>"
       << "<mo_sc2dVal species=\"Species_3\">39</mo_sc2dVal>"
       << "<mo_sc2dVal species=\"Species_1\">30</mo_sc2dVal>"
       << "<mo_sc2dVal species=\"Species_4\">30</mo_sc2dVal>"
       << "</mo_snagSizeClass2DBH>"
       << "<mo_snag1WeibullA>"
       << "<mo_s1waVal species=\"Species_3\">0.025</mo_s1waVal>"
       << "<mo_s1waVal species=\"Species_1\">0.113</mo_s1waVal>"
       << "<mo_s1waVal species=\"Species_4\">11.51</mo_s1waVal>"
       << "</mo_snag1WeibullA>"
       << "<mo_snag2WeibullA>"
       << "<mo_s2waVal species=\"Species_3\">0.09</mo_s2waVal>"
       << "<mo_s2waVal species=\"Species_1\">0.0113</mo_s2waVal>"
       << "<mo_s2waVal species=\"Species_4\">11.51</mo_s2waVal>"
       << "</mo_snag2WeibullA>"
       << "<mo_snag3WeibullA>"
       << "<mo_s3waVal species=\"Species_3\">0.0204</mo_s3waVal>"
       << "<mo_s3waVal species=\"Species_1\">0.1</mo_s3waVal>"
       << "<mo_s3waVal species=\"Species_4\">11.51</mo_s3waVal>"
       << "</mo_snag3WeibullA>"
       << "<mo_snag1WeibullB>"
       << "<mo_s1wbVal species=\"Species_3\">3</mo_s1wbVal>"
       << "<mo_s1wbVal species=\"Species_1\">3.049</mo_s1wbVal>"
       << "<mo_s1wbVal species=\"Species_4\">1</mo_s1wbVal>"
       << "</mo_snag1WeibullB>"
       << "<mo_snag2WeibullB>"
       << "<mo_s2wbVal species=\"Species_3\">2</mo_s2wbVal>"
       << "<mo_s2wbVal species=\"Species_1\">2.2</mo_s2wbVal>"
       << "<mo_s2wbVal species=\"Species_4\">1</mo_s2wbVal>"
       << "</mo_snag2WeibullB>"
       << "<mo_snag3WeibullB>"
       << "<mo_s3wbVal species=\"Species_3\">2.5</mo_s3wbVal>"
       << "<mo_s3wbVal species=\"Species_1\">2.3</mo_s3wbVal>"
       << "<mo_s3wbVal species=\"Species_4\">1</mo_s3wbVal>"
       << "</mo_snag3WeibullB>"
       << "</mortality>"
       << "</paramFile>";
  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestWeibullSnagMort::WriteXMLFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>35</timesteps>"
       << "<randomSeed>1</randomSeed>"
       << "<yearsPerTimestep>3</yearsPerTimestep>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>0.0</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.7</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.7</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.7</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.7</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>weibull snag mortality</behaviorName>"
       << "<version>1.1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "<applyTo species=\"Species_4\" type=\"Snag\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>2.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "<applyTo species=\"Species_4\" type=\"Snag\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_snagSizeClass1DBH>"
       << "<mo_sc1dVal species=\"Species_3\">31</mo_sc1dVal>"
       << "<mo_sc1dVal species=\"Species_1\">12</mo_sc1dVal>"
       << "<mo_sc1dVal species=\"Species_4\">12</mo_sc1dVal>"
       << "</mo_snagSizeClass1DBH>"
       << "<mo_snagSizeClass2DBH>"
       << "<mo_sc2dVal species=\"Species_3\">39</mo_sc2dVal>"
       << "<mo_sc2dVal species=\"Species_1\">30</mo_sc2dVal>"
       << "<mo_sc2dVal species=\"Species_4\">30</mo_sc2dVal>"
       << "</mo_snagSizeClass2DBH>"
       << "<mo_snag1WeibullA>"
       << "<mo_s1waVal species=\"Species_3\">0.025</mo_s1waVal>"
       << "<mo_s1waVal species=\"Species_1\">0.113</mo_s1waVal>"
       << "<mo_s1waVal species=\"Species_4\">11.51</mo_s1waVal>"
       << "</mo_snag1WeibullA>"
       << "<mo_snag2WeibullA>"
       << "<mo_s2waVal species=\"Species_3\">0.09</mo_s2waVal>"
       << "<mo_s2waVal species=\"Species_1\">0.0113</mo_s2waVal>"
       << "<mo_s2waVal species=\"Species_4\">11.51</mo_s2waVal>"
       << "</mo_snag2WeibullA>"
       << "<mo_snag3WeibullA>"
       << "<mo_s3waVal species=\"Species_3\">0.0204</mo_s3waVal>"
       << "<mo_s3waVal species=\"Species_1\">0.1</mo_s3waVal>"
       << "<mo_s3waVal species=\"Species_4\">11.51</mo_s3waVal>"
       << "</mo_snag3WeibullA>"
       << "<mo_snag1WeibullB>"
       << "<mo_s1wbVal species=\"Species_3\">3</mo_s1wbVal>"
       << "<mo_s1wbVal species=\"Species_1\">3.049</mo_s1wbVal>"
       << "<mo_s1wbVal species=\"Species_4\">1</mo_s1wbVal>"
       << "</mo_snag1WeibullB>"
       << "<mo_snag2WeibullB>"
       << "<mo_s2wbVal species=\"Species_3\">2</mo_s2wbVal>"
       << "<mo_s2wbVal species=\"Species_1\">2.2</mo_s2wbVal>"
       << "<mo_s2wbVal species=\"Species_4\">1</mo_s2wbVal>"
       << "</mo_snag2WeibullB>"
       << "<mo_snag3WeibullB>"
       << "<mo_s3wbVal species=\"Species_3\">2.5</mo_s3wbVal>"
       << "<mo_s3wbVal species=\"Species_1\">2.3</mo_s3wbVal>"
       << "<mo_s3wbVal species=\"Species_4\">1</mo_s3wbVal>"
       << "</mo_snag3WeibullB>"
       << "</mortality>"
       << "</paramFile>";
  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestWeibullSnagMort::WriteXMLFile3()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>50</timesteps>"
       << "<randomSeed>1</randomSeed>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>0.0</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.7</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.7</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.7</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>weibull snag mortality</behaviorName>"
       << "<version>1.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>2.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_snagSizeClass1>12</mo_snagSizeClass1>"
       << "<mo_snagSizeClass2>30</mo_snagSizeClass2>"
       << "<mo_snag1WeibullA>"
       << "<mo_s1waVal species=\"Species_3\">0.025</mo_s1waVal>"
       << "<mo_s1waVal species=\"Species_1\">0.113</mo_s1waVal>"
       << "</mo_snag1WeibullA>"
       << "<mo_snag2WeibullA>"
       << "<mo_s2waVal species=\"Species_3\">0.09</mo_s2waVal>"
       << "<mo_s2waVal species=\"Species_1\">0.0113</mo_s2waVal>"
       << "</mo_snag2WeibullA>"
       << "<mo_snag3WeibullA>"
       << "<mo_s3waVal species=\"Species_3\">0.0204</mo_s3waVal>"
       << "<mo_s3waVal species=\"Species_1\">0.1</mo_s3waVal>"
       << "</mo_snag3WeibullA>"
       << "<mo_snag1WeibullB>"
       << "<mo_s1wbVal species=\"Species_3\">3</mo_s1wbVal>"
       << "<mo_s1wbVal species=\"Species_1\">3.049</mo_s1wbVal>"
       << "</mo_snag1WeibullB>"
       << "<mo_snag2WeibullB>"
       << "<mo_s2wbVal species=\"Species_3\">2</mo_s2wbVal>"
       << "<mo_s2wbVal species=\"Species_1\">2.2</mo_s2wbVal>"
       << "</mo_snag2WeibullB>"
       << "<mo_snag3WeibullB>"
       << "<mo_s3wbVal species=\"Species_3\">2.5</mo_s3wbVal>"
       << "<mo_s3wbVal species=\"Species_1\">2.3</mo_s3wbVal>"
       << "</mo_snag3WeibullB>"
       << "</mortality>"
       << "</paramFile>";
  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestWeibullSnagMort::WriteXMLErrorFile1()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>11</timesteps>"
       << "<randomSeed>1</randomSeed>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>0.0</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.7</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.7</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.7</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>weibull snag mortality</behaviorName>"
       << "<version>1.1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>2.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_snagSizeClass1DBH>"
       << "<mo_sc1dVal species=\"Species_3\">31</mo_sc1dVal>"
       << "<mo_sc1dVal species=\"Species_1\">40</mo_sc1dVal>"
       << "</mo_snagSizeClass1DBH>"
       << "<mo_snagSizeClass2DBH>"
       << "<mo_sc2dVal species=\"Species_3\">39</mo_sc2dVal>"
       << "<mo_sc2dVal species=\"Species_1\">30</mo_sc2dVal>"
       << "</mo_snagSizeClass2DBH>"
       << "<mo_snag1WeibullA>"
       << "<mo_s1waVal species=\"Species_3\">0.0025</mo_s1waVal>"
       << "<mo_s1waVal species=\"Species_1\">0.0013</mo_s1waVal>"
       << "</mo_snag1WeibullA>"
       << "<mo_snag2WeibullA>"
       << "<mo_s2waVal species=\"Species_3\">0.0009</mo_s2waVal>"
       << "<mo_s2waVal species=\"Species_1\">0.0113</mo_s2waVal>"
       << "</mo_snag2WeibullA>"
       << "<mo_snag3WeibullA>"
       << "<mo_s3waVal species=\"Species_3\">0.0204</mo_s3waVal>"
       << "<mo_s3waVal species=\"Species_1\">0.1</mo_s3waVal>"
       << "</mo_snag3WeibullA>"
       << "<mo_snag1WeibullB>"
       << "<mo_s1wbVal species=\"Species_3\">4</mo_s1wbVal>"
       << "<mo_s1wbVal species=\"Species_1\">2.1</mo_s1wbVal>"
      << "</mo_snag1WeibullB>"
      << "<mo_snag2WeibullB>"
      << "<mo_s2wbVal species=\"Species_3\">1</mo_s2wbVal>"
      << "<mo_s2wbVal species=\"Species_1\">2.2</mo_s2wbVal>"
      << "</mo_snag2WeibullB>"
      << "<mo_snag3WeibullB>"
      << "<mo_s3wbVal species=\"Species_3\">2.5</mo_s3wbVal>"
      << "<mo_s3wbVal species=\"Species_1\">2.3</mo_s3wbVal>"
      << "</mo_snag3WeibullB>"
       << "</mortality>"
       << "</paramFile>";
  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestWeibullSnagMort::WriteXMLErrorFile2()
{
  using namespace std;
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>11</timesteps>"
       << "<randomSeed>1</randomSeed>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>0.0</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">40.0</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">40.0</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.7</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.7</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.7</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.7</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.7</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.7</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.7</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.7</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>weibull snag mortality</behaviorName>"
       << "<version>1.1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Adult\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>removedead</behaviorName>"
       << "<version>2.0</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\" />"
       << "<applyTo species=\"Species_3\" type=\"Snag\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<mortality>"
       << "<mo_snagSizeClass1DBH>"
       << "<mo_sc1dVal species=\"Species_3\">31</mo_sc1dVal>"
       << "<mo_sc1dVal species=\"Species_1\">12</mo_sc1dVal>"
       << "</mo_snagSizeClass1DBH>"
       << "<mo_snagSizeClass2DBH>"
       << "<mo_sc2dVal species=\"Species_3\">39</mo_sc2dVal>"
       << "<mo_sc2dVal species=\"Species_1\">30</mo_sc2dVal>"
       << "</mo_snagSizeClass2DBH>"
       << "<mo_snag1WeibullA>"
       << "<mo_s1waVal species=\"Species_3\">0.0025</mo_s1waVal>"
       << "<mo_s1waVal species=\"Species_1\">0.0013</mo_s1waVal>"
       << "</mo_snag1WeibullA>"
       << "<mo_snag2WeibullA>"
       << "<mo_s2waVal species=\"Species_3\">0.0009</mo_s2waVal>"
       << "<mo_s2waVal species=\"Species_1\">0.0113</mo_s2waVal>"
       << "</mo_snag2WeibullA>"
       << "<mo_snag3WeibullA>"
       << "<mo_s3waVal species=\"Species_3\">0.0204</mo_s3waVal>"
       << "<mo_s3waVal species=\"Species_1\">0.1</mo_s3waVal>"
       << "</mo_snag3WeibullA>"
       << "<mo_snag1WeibullB>"
       << "<mo_s1wbVal species=\"Species_3\">4</mo_s1wbVal>"
       << "<mo_s1wbVal species=\"Species_1\">2.1</mo_s1wbVal>"
       << "</mo_snag1WeibullB>"
       << "<mo_snag2WeibullB>"
       << "<mo_s2wbVal species=\"Species_3\">1</mo_s2wbVal>"
       << "<mo_s2wbVal species=\"Species_1\">2.2</mo_s2wbVal>"
       << "</mo_snag2WeibullB>"
       << "<mo_snag3WeibullB>"
       << "<mo_s3wbVal species=\"Species_3\">2.5</mo_s3wbVal>"
       << "<mo_s3wbVal species=\"Species_1\">2.3</mo_s3wbVal>"
       << "</mo_snag3WeibullB>"
       << "</mortality>"
       << "</paramFile>";
  oOut.close();

  return cFileString;
}
