//---------------------------------------------------------------------------
// TestWindstorm
//---------------------------------------------------------------------------
#if !defined(TestWindstorm_H)
  #define TestWindstorm_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clWindstorm class.
*/
class clTestWindstorm : public CppUnit::TestFixture {

  public:

  /**
  * Assembles all other testing functions into one test.
  */
  void TestWindstorm();

  protected:
  
  /**
  * Tests error processing.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Tests normal processing Run 1.  WriteXMLFile1() writes the parameter file.
  * Aspects of the run:
  * <ul>
  * <li>1 year per timestep.</li>
  * <li>Snag run.</li>
  * <li>This run tests correct damage calculation and killing.</li>
  * <li>The following trees will be added, with a storm of 0.2 triggered
  * for timestep 1:
  * <ul>
  * <li>Grid (0,0): 1000 trees of Species 1 and 2, DBH 30.</li>
  * <li>Grid (1,0): 1000 trees of Species 1 and 2, DBH 8.</li>
  * <li>All grids get 1000 trees of DBH 4, Species 1, and DBH 5, Species 2.</li>
  * </ul></li>
  * </ul>
  *
  * The run proceeds for 1 timestep.  The "Windstorm Results" grid is checked,
  * and the actual number of trees alive and dead is checked as well.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 2.  WriteXMLFile2() writes the parameter file.
  * Aspects of the run:
  * <ul>
  * <li>1 year per timestep.</li>
  * <li>Snag run.</li>
  * <li>This run tests correct damage calculation and killing.</li>
  * <li>The following trees will be added, with a storm of 0.8 triggered
  * for timestep 1:
  * <ul>
  * <li>Grid (0,0): 1000 trees of Species 1 and 2, DBH 30.</li>
  * <li>Grid (1,0): 1000 trees of Species 1 and 2, DBH 8.</li>
  * <li>All grids get 1000 trees of DBH 4, Species 1, and DBH 5, Species 2.</li>
  * </ul></li>
  * </ul>
  *
  * The run proceeds for 1 timestep.  The "Windstorm Results" grid is checked,
  * and the actual number of trees alive and dead is checked as well.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun2(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 3.  WriteXMLFile3() writes the parameter file.
  * Aspects of the run:
  * <ul>
  * <li>3 years per timestep.</li>
  * <li>Snag run.</li>
  * <li>This run tests multiple storms per timestep, and making sure dead trees
  * are ignored.</li>
  * <li>The following trees will be added, with 3 storms of 0.2 triggered
  * for timestep 1:
  * <ul>
  * <li>Grid (0,0): 1000 trees of Species 1 and 2, DBH 30.</li>
  * <li>Grid (1,0): 1000 trees of Species 1 and 2, DBH 8.</li>
  * </ul></li>
  * </ul>
  *
  * The run proceeds for 1 timestep.  The "Windstorm Results" grid is checked,
  * and the actual number of trees alive and dead is checked as well.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun3(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 4.  WriteXMLFile4() writes the parameter file.
  * Aspects of the run:
  * <ul>
  * <li>1 year per timestep.</li>
  * <li>No snags.</li>
  * <li>This run tests correct handling when there are no snags.</li>
  * <li>The following trees will be added, with a storm of 0.4 triggered
  * for timestep 1:
  * <ul>
  * <li>Grid (0,0): 1000 trees of Species 1 and 2, DBH 30.</li>
  * <li>Grid (1,0): 1000 trees of Species 1 and 2, DBH 8.</li>
  * <li>All grids get 1000 trees of DBH 4, Species 1, and DBH 5, Species 2.</li>
  * </ul></li>
  * </ul>
  *
  * The run proceeds for 1 timestep.  The "Windstorm Results" grid is checked,
  * and the actual number of trees alive and dead is checked as well.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun4(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 5.  WriteXMLFile5() writes the parameter file.
  * Storm severities for all return intervals are 0, and this makes sure that
  * no storms occur.
  *
  * The run proceeds for 1 timestep.  The "Windstorm Results" grid is checked,
  * and the actual number of trees alive and dead is checked as well to make
  * sure nothing died.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun5(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 6.  WriteXMLFile6() writes the parameter file.
  * Aspects of the run:
  * <ul>
  * <li>1 year per timestep.</li>
  * <li>No snags.</li>
  * <li>This run tests when storms don't start at timestep 1.</li>
  * <li>The following trees will be added, with a storm of 0.5 triggered
  * for timestep 2:
  * <ul>
  * <li>Grid (0,0): 1000 trees of Species 1 and 2, DBH 30.</li>
  * <li>Grid (1,0): 1000 trees of Species 1 and 2, DBH 8.</li>
  * </ul></li>
  * </ul>
  *
  * The run proceeds for 2 timesteps.  The "Windstorm Results" grid is checked,
  * and the actual number of trees alive and dead is checked as well.  No storm
  * should occur for timestep 1.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun6(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 7.  WriteXMLFile7() writes the parameter file.
  * This run tests to make sure the "Windstorm Results" grid is refreshed for
  * each timestep.
  * 
  * The 1 year return interval is 0.  This runs for 2 timesteps, and verifies
  * that the results for the two in the "Windstorm Results" grid are different.
  * 
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun7(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 8.  WriteXMLFile8() writes the parameter file.
  * This run tests to make sure storms below the minimum intensity are handled
  * correctly.
  * Aspects of the run:
  * <ul>
  * <li>1 year per timestep.</li>
  * <li>No snags.</li>
  * <li>The following trees will be added, with a storm of 0.07 triggered
  * for timestep 1:
  * <ul>
  * <li>Grid (0,0): 1000 trees of Species 1 and 2, DBH 30.</li>
  * <li>Grid (1,0): 1000 trees of Species 1 and 2, DBH 8.</li>
  * </ul></li>
  * </ul>
  *
  * The run proceeds for 1 timestep.  The "Windstorm Results" grid is checked,
  * and the actual number of trees alive and dead is checked as well.
  * 
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun8(clSimManager *p_oSimManager);
  

  /**
  * Writes the parameter file for TestNormalProcessing1().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile1();

  /**
  * Writes the parameter file for TestNormalProcessing2().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile2();
  
  /**
  * Writes the parameter file for TestNormalProcessing3().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile3();
  
  /**
  * Writes the parameter file for TestNormalProcessing4().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile4();
  
  /**
  * Writes the parameter file for TestNormalProcessing5().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile5();
  
  /**
  * Writes the parameter file for TestNormalProcessing6().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile6();
  
  /**
  * Writes the parameter file for TestNormalProcessing7().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile7();
  
  /**
  * Writes the parameter file for TestNormalProcessing8().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile8();

  /**
  * Writes an error file where the minimum DBH is negative.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error file where the storm damage applier behavior is applied
  * to seedlings.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error file where the timestep to start storms is negative.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile3();
  
  /**
  * Writes an error file where the severity of a storm return interval is not 
  * between 0 and 1.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile4();
  
  /**
  * Writes an error file where mortality behaviors are not applied to all trees.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile5();
  
  /**
  * Writes an error file where the storm periodicity is zero.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile6();

  /**
  * Writes common portions of the test parameter files.  Starts with
  * &lt;randomSeed&gt; and ends with &lt;/allometry&gt;.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);

  /**
  * Writes the behavior list for the test parameter files with snags.
  * @param oOut File stream to write to.
  */
  void WriteSnagBehaviorList(std::fstream &oOut);
  
  /**
  * Writes the behavior list for the test parameter files without snags.
  * @param oOut File stream to write to.
  */
  void WriteNoSnagBehaviorList(std::fstream &oOut);

};
//---------------------------------------------------------------------------
#endif //TestWindstorm_H
