//---------------------------------------------------------------------------
// TestNciGrowth.cpp
//---------------------------------------------------------------------------
#include "TestNciGrowth.h"
#include <fstream>
#include <math.h>
#include "TreePopulation.h"
#include "SimManager.h"
#include "BehaviorBase.h"

////////////////////////////////////////////////////////////////////////////
//  TestNciGrowth()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestNciGrowth() {
  clSimManager *p_oSimManager = new clSimManager(4, 2, "");

  TestAutoHeightVsDiamOnly(p_oSimManager);
  TestRun1(p_oSimManager);
  TestRun2(p_oSimManager);
  TestRun3(p_oSimManager);
  TestRun4(p_oSimManager);
  TestRun5(p_oSimManager);
  TestRun6(p_oSimManager);
  TestErrorProcessing(p_oSimManager);
  TestBoundaryProcessing(p_oSimManager);

  delete p_oSimManager;
}

////////////////////////////////////////////////////////////////////////////
//  TestAutoHeightVsDiamOnly()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestAutoHeightVsDiamOnly(clSimManager *p_oSimManager) {

  clTreePopulation * p_oPop;
  clTree *p_oTree1, *p_oTree2;
  float fDiam, fHeight, fDiam2, fHeight2, fShade, fGrowth;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile1() );
  p_oPop = ( clTreePopulation * ) p_oSimManager->GetPopulationObject( "treepopulation" );

  //Create our two trees and set diameter, height, and shade for each
  //Adult, Species 1
  fDiam = 22;
  fHeight = 10;
  fShade = 0.5;
  p_oTree1 = p_oPop->CreateTree(1, 1, 0, clTreePopulation::adult, fDiam);
  p_oTree1->SetValue(p_oPop->GetHeightCode(p_oTree1->GetSpecies(), p_oTree1->GetType()), fHeight, false, false);
  p_oTree1->SetValue(p_oPop->GetFloatDataCode("Light", p_oTree1->GetSpecies(), p_oTree1->GetType()), fShade, false, false);

  p_oTree2 = p_oPop->CreateTree(10, 10, 1, clTreePopulation::adult, fDiam);
  p_oTree2->SetValue(p_oPop->GetHeightCode(p_oTree2->GetSpecies(), p_oTree2->GetType()), fHeight, false, false);
  p_oTree2->SetValue(p_oPop->GetFloatDataCode("Light", p_oTree2->GetSpecies(), p_oTree2->GetType()), fShade, false, false);

  //Now run growth, but skip light
  int i;
  for (i = 1; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    clBehaviorBase *p_oBase = p_oSimManager->GetBehaviorObject(i);
    p_oBase->Action();
  }

  //Diameters should be the same
  p_oTree1->GetValue(p_oPop->GetDbhCode(p_oTree1->GetSpecies(), p_oTree1->GetType()), &fDiam);
  p_oTree2->GetValue(p_oPop->GetDbhCode(p_oTree2->GetSpecies(), p_oTree2->GetType()), &fDiam2);
  CPPUNIT_ASSERT(fabs(fDiam - fDiam2) < 0.001);

  //Heights should be different
  p_oTree1->GetValue(p_oPop->GetHeightCode(p_oTree1->GetSpecies(), p_oTree1->GetType()), &fHeight);
  p_oTree2->GetValue(p_oPop->GetHeightCode(p_oTree2->GetSpecies(), p_oTree2->GetType()), &fHeight2);
  CPPUNIT_ASSERT(fabs(fHeight - fHeight2) > 1);

  //Lgm should be different from shade for each
  p_oTree1->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTree1->GetSpecies(), p_oTree1->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fGrowth - fShade) > 0.1);

  p_oTree2->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTree2->GetSpecies(), p_oTree2->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fGrowth - fShade) > 0.1);
}

////////////////////////////////////////////////////////////////////////////
//  TestBoundaryProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestBoundaryProcessing(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1,
         *p_oTargetTree2,
         *p_oTargetTree3;
  float fDiam;
  int iSpecies, iDamage;

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile4() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set the damage level for each
  fDiam = 11;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree1->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree1->GetSpecies(),
                                                  p_oTargetTree1->GetType()),
                           iDamage);

  fDiam = 8;
  iSpecies = 1;
  iDamage = 1010;
  p_oTargetTree2 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::sapling, fDiam);
  p_oTargetTree2->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree2->GetSpecies(),
                                                  p_oTargetTree2->GetType()),
                           iDamage);

  fDiam = 15;
  iSpecies = 3;
  iDamage = 2010;
  p_oTargetTree3 = p_oPop->CreateTree(12, 12, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           iDamage);

  //Now do the run
  p_oSimManager->RunSim(1);

}

////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestErrorProcessing(clSimManager *p_oSimManager) {

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile4.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile4.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile5.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile5.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile6());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile6.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile6.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile7());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile7.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile7.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile8());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile8.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile8.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile9());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile9.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile9.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile10());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile10.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile10.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile11());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile11.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile11.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile12());
    CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile12.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
    {
      CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile12.");
    }
    ;
  }

  try
 {
   p_oSimManager->ReadFile(WriteXMLErrorFile13());
   CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile13.");
 }
 catch (modelErr err)
 {
   if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
   {
     CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile13.");
   }
   ;
 }

 try
 {
   p_oSimManager->ReadFile(WriteXMLErrorFile14());
   CppUnit::Asserter::fail("TestNCIGrowth error processing didn't catch error for WriteXMLErrorFile14.");
 }
 catch (modelErr err)
 {
   if (strstr(err.cFunction, "clNciGrowth::ValidateData") == NULL)
   {
     CppUnit::Asserter::fail("TestNCIGrowth error processing caught wrong error for WriteXMLErrorFile14.");
   }
   ;
 }
}

////////////////////////////////////////////////////////////////////////////
//  TestRun1()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestRun1(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1,
         *p_oTargetTree2,
         *p_oTargetTree3,
         *p_oTargetTree4,
         *p_oTargetTree5,
         *p_oTargetTree6,
         *p_oTargetTree7,
         *p_oTargetTree8,
         *p_oTargetTree9,
         *p_oTargetTree;
  float fDiam, fExpectedDiam;
  int iSpecies, iDamage;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile4() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set the damage level for each
  fDiam = 11;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree1->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree1->GetSpecies(),
                                                  p_oTargetTree1->GetType()),
                           iDamage);

  fDiam = 8;
  iSpecies = 1;
  iDamage = 1000;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);
  p_oTargetTree2->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree2->GetSpecies(),
                                                  p_oTargetTree2->GetType()),
                           iDamage);

  fDiam = 15;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           iDamage);

  fDiam = 10.5;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree4->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree4->GetSpecies(),
                                                  p_oTargetTree4->GetType()),
                           iDamage);

  fDiam = 15;
  iSpecies = 1;
  iDamage = 1000;
  p_oTargetTree5 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree5->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree5->GetSpecies(),
                                                  p_oTargetTree5->GetType()),
                           iDamage);

  fDiam = 25;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree6 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree6->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree6->GetSpecies(),
                                                  p_oTargetTree6->GetType()),
                           iDamage);

  fDiam = 30;
  iSpecies = 0;
  iDamage = 2000;
  p_oTargetTree7 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree7->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree7->GetSpecies(),
                                                  p_oTargetTree7->GetType()),
                           iDamage);

  fDiam = 45;
  iSpecies = 1;
  iDamage = 0;
  p_oTargetTree8 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree8->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree8->GetSpecies(),
                                                  p_oTargetTree8->GetType()),
                           iDamage);

  fDiam = 1;
  iSpecies = 3;
  iDamage = 0;
  p_oTargetTree9 = p_oPop->CreateTree(30, 10, iSpecies, clTreePopulation::sapling, fDiam);


  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(54, 54, 2, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 12.02578252;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 8.566136279;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 15.62491548;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 11.2924378;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 15.78042057;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 25.52586497;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 30.37529052;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 46.24530477;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 2.6016;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile5() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set the damage level for each
  fDiam = 11;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree1->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree1->GetSpecies(),
                                                  p_oTargetTree1->GetType()),
                           iDamage);

  fDiam = 8;
  iSpecies = 1;
  iDamage = 1000;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);
  p_oTargetTree2->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree2->GetSpecies(),
                                                  p_oTargetTree2->GetType()),
                           iDamage);

  fDiam = 15;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           iDamage);

  fDiam = 10.5;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree4->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree4->GetSpecies(),
                                                  p_oTargetTree4->GetType()),
                           iDamage);

  fDiam = 15;
  iSpecies = 1;
  iDamage = 1000;
  p_oTargetTree5 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree5->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree5->GetSpecies(),
                                                  p_oTargetTree5->GetType()),
                           iDamage);

  fDiam = 25;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree6 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree6->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree6->GetSpecies(),
                                                  p_oTargetTree6->GetType()),
                           iDamage);

  fDiam = 30;
  iSpecies = 0;
  iDamage = 2000;
  p_oTargetTree7 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree7->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree7->GetSpecies(),
                                                  p_oTargetTree7->GetType()),
                           iDamage);

  fDiam = 45;
  iSpecies = 1;
  iDamage = 0;
  p_oTargetTree8 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree8->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree8->GetSpecies(),
                                                  p_oTargetTree8->GetType()),
                           iDamage);

  fDiam = 1;
  iSpecies = 3;
  iDamage = 0;
  p_oTargetTree9 = p_oPop->CreateTree(30, 10, iSpecies, clTreePopulation::sapling, fDiam);

  //Now create all the neighbors that are too small to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(54, 54, 2, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 14.08875462;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 9.754968806;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 16.8769391;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 12.90645617;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 17.39443379;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 26.57309113;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 31.12786623;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 48.75968063;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 5.8048;
  p_oTargetTree = p_oTargetTree9;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

}

////////////////////////////////////////////////////////////////////////////
//  TestRun2()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestRun2(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1, *p_oTargetTree2, *p_oTree;
  float fDiam, fExpectedDiam, fGrowth, fExpectedGrowth;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile2() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our two target trees
  fDiam = 11;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, 0, clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  p_oTargetTree2 = p_oPop->CreateTree(50, 50, 0, clTreePopulation::adult, fDiam);

  //Now create all the neighbors
  p_oPop->CreateTree(53, 52, 1, clTreePopulation::adult, 15);
  p_oPop->CreateTree(59, 50, 2, clTreePopulation::adult, 25);
  p_oPop->CreateTree(50, 59, 0, clTreePopulation::adult, 30);
  p_oPop->CreateTree(55, 55, 1, clTreePopulation::adult, 45);
  p_oPop->CreateTree(60, 61, 2, clTreePopulation::adult, 15);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oTree = p_oPop->CreateTree(54, 54, 0, clTreePopulation::adult, 20);
  p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 11.94022982;
  fExpectedGrowth = 4.70114909;
  p_oTargetTree1->GetValue(p_oPop->GetDbhCode(p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fDiam);
  p_oTargetTree1->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 11.39981688;
  fExpectedGrowth = 4.49908438;
  p_oTargetTree2->GetValue(p_oPop->GetDbhCode(p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fDiam);
  p_oTargetTree2->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile3() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our two target trees
  fDiam = 11;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, 0, clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  p_oTargetTree2 = p_oPop->CreateTree(50, 50, 0, clTreePopulation::adult, fDiam);

  //Now create all the neighbors
  p_oPop->CreateTree(53, 52, 1, clTreePopulation::adult, 15);
  p_oPop->CreateTree(59, 50, 2, clTreePopulation::adult, 25);
  p_oPop->CreateTree(50, 59, 0, clTreePopulation::adult, 30);
  p_oPop->CreateTree(55, 55, 1, clTreePopulation::adult, 45);
  p_oPop->CreateTree(60, 61, 2, clTreePopulation::adult, 15);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oTree = p_oPop->CreateTree(54, 54, 0, clTreePopulation::adult, 20);
  p_oTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTree->GetSpecies(), p_oTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 13.83037522;
  fExpectedGrowth = 4.71729204;
  p_oTargetTree1->GetValue(p_oPop->GetDbhCode(p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fDiam);
  p_oTargetTree1->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree1->GetSpecies(), p_oTargetTree1->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 13.20914701;
  fExpectedGrowth = 4.515245025;
  p_oTargetTree2->GetValue(p_oPop->GetDbhCode(p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fDiam);
  p_oTargetTree2->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree2->GetSpecies(), p_oTargetTree2->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);
}

////////////////////////////////////////////////////////////////////////////
//  TestRun3()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestRun3(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1,
         *p_oTargetTree2,
         *p_oTargetTree3,
         *p_oTargetTree4,
         *p_oTargetTree5,
         *p_oTargetTree;
  float fDiam, fExpectedDiam, fShade, fGrowth, fExpectedGrowth;
  int iSpecies;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile6() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set their light levels
  fDiam = 15;
  iSpecies = 1;
  fShade = 1;
  p_oTargetTree1 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree1->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree1->GetSpecies(),
                                                  p_oTargetTree1->GetType()),
                           fShade);


  fDiam = 25;
  iSpecies = 3;
  fShade = 0.2;
  p_oTargetTree2 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree2->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree2->GetSpecies(),
                                                  p_oTargetTree2->GetType()),
                           fShade);

  fDiam = 30;
  iSpecies = 0;
  fShade = 0.4;
  p_oTargetTree3 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           fShade);

  fDiam = 45;
  iSpecies = 1;
  fShade = 0.8;
  p_oTargetTree4 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree4->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree4->GetSpecies(),
                                                  p_oTargetTree4->GetType()),
                           fShade);

  fDiam = 10.5;
  iSpecies = 0;
  fShade = 0;
  p_oTargetTree5 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree5->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree5->GetSpecies(),
                                                  p_oTargetTree5->GetType()),
                           fShade);

  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 9);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::adult, 11);
  p_oPop->CreateTree(54, 54, 3, clTreePopulation::adult, 13);
  p_oPop->CreateTree(56, 56, 2, clTreePopulation::adult, 15);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run - but don't let saillight go, or it will mess up the
  //shading values we've assigned
  for (int i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    if (strcmp(p_oSimManager->GetBehaviorObject(i)->GetName(), "ncigrowthshell") == 0) {
      p_oSimManager->GetBehaviorObject(i)->Action();
      break;
    }
  }

  //Check the diameters and growth of the target trees
  fExpectedDiam = 15.91129062;
  fExpectedGrowth = 4.556453117;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 27.30600165;
  fExpectedGrowth = 11.53000827;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 31.01554876;
  fExpectedGrowth = 5.077743794;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 46.44982526;
  fExpectedGrowth = 7.249126321;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 11.53806956;
  fExpectedGrowth = 5.190347813;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile7() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set their light levels
  fDiam = 15;
  iSpecies = 1;
  fShade = 1;
  p_oTargetTree1 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree1->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree1->GetSpecies(),
                                                  p_oTargetTree1->GetType()),
                           fShade);


  fDiam = 25;
  iSpecies = 3;
  fShade = 0.2;
  p_oTargetTree2 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree2->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree2->GetSpecies(),
                                                  p_oTargetTree2->GetType()),
                           fShade);

  fDiam = 30;
  iSpecies = 0;
  fShade = 0.4;
  p_oTargetTree3 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           fShade);

  fDiam = 45;
  iSpecies = 1;
  fShade = 0.8;
  p_oTargetTree4 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree4->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree4->GetSpecies(),
                                                  p_oTargetTree4->GetType()),
                           fShade);

  fDiam = 10.5;
  iSpecies = 0;
  fShade = 0;
  p_oTargetTree5 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree5->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree5->GetSpecies(),
                                                  p_oTargetTree5->GetType()),
                           fShade);

  //Now create all the neighbors that are too small to compete
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 9);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::adult, 11);
  p_oPop->CreateTree(54, 54, 3, clTreePopulation::adult, 13);
  p_oPop->CreateTree(56, 56, 2, clTreePopulation::adult, 15);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run - but don't let saillight go, or it will mess up the
  //shading values we've assigned
  for (int i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    if (strcmp(p_oSimManager->GetBehaviorObject(i)->GetName(), "ncigrowthshell") == 0) {
      p_oSimManager->GetBehaviorObject(i)->Action();
      break;
    }
  }

  //Check the diameters and growth of the target trees
  fExpectedDiam = 17.80779863;
  fExpectedGrowth = 4.679664378;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 31.82738854;
  fExpectedGrowth = 11.37898089;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 33.04706798;
  fExpectedGrowth = 5.078446636;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 49.38354469;
  fExpectedGrowth = 7.305907813;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 13.62688973;
  fExpectedGrowth = 5.211482877;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);
}

////////////////////////////////////////////////////////////////////////////
//  TestRun4()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestRun4(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1,
         *p_oTargetTree2,
         *p_oTargetTree3,
         *p_oTargetTree4,
         *p_oTargetTree5,
         *p_oTargetTree;
  float fDiam, fExpectedDiam, fShade, fGrowth, fExpectedGrowth;
  int iSpecies;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************

  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile8() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set their light levels
  fDiam = 15;
  iSpecies = 1;
  p_oTargetTree1 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);


  fDiam = 25;
  iSpecies = 3;
  fShade = 0.2;
  p_oTargetTree2 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree2->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree2->GetSpecies(),
                                                  p_oTargetTree2->GetType()),
                           fShade);

  fDiam = 30;
  iSpecies = 0;
  fShade = 0.4;
  p_oTargetTree3 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           fShade);

  fDiam = 45;
  iSpecies = 1;
  p_oTargetTree4 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  iSpecies = 0;
  fShade = 0;
  p_oTargetTree5 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree5->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree5->GetSpecies(),
                                                  p_oTargetTree5->GetType()),
                           fShade);

  //Now create all the neighbors that are too small or dead to compete
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 9);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::adult, 11);
  p_oPop->CreateTree(54, 54, 3, clTreePopulation::adult, 13);
  p_oPop->CreateTree(56, 56, 2, clTreePopulation::adult, 15);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::snag, 30);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run - but don't let saillight go, or it will mess up the
  //shading values we've assigned
  for (int i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    if (strcmp(p_oSimManager->GetBehaviorObject(i)->GetName(), "ncigrowthshell") == 0) {
      p_oSimManager->GetBehaviorObject(i)->Action();
      break;
    }
  }

  //Check the diameters and growth of the target trees
  fExpectedDiam = 16.23011367;
  fExpectedGrowth = 6.150568371;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 27.30600165;
  fExpectedGrowth = 11.53000827;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 31.01554876;
  fExpectedGrowth = 5.077743794;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 46.84308914;
  fExpectedGrowth = 9.215445676;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 11.53806956;
  fExpectedGrowth = 5.190347813;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile9() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set their light levels
  fDiam = 15;
  iSpecies = 1;
  p_oTargetTree1 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);


  fDiam = 25;
  iSpecies = 3;
  fShade = 0.2;
  p_oTargetTree2 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree2->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree2->GetSpecies(),
                                                  p_oTargetTree2->GetType()),
                           fShade);

  fDiam = 30;
  iSpecies = 0;
  fShade = 0.4;
  p_oTargetTree3 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           fShade);

  fDiam = 45;
  iSpecies = 1;
  p_oTargetTree4 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  iSpecies = 0;
  fShade = 0;
  p_oTargetTree5 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree5->SetValue(p_oPop->GetFloatDataCode("Light",
                                                  p_oTargetTree5->GetSpecies(),
                                                  p_oTargetTree5->GetType()),
                           fShade);

  //Now create all the neighbors that are too small to compete
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 9);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::adult, 11);
  p_oPop->CreateTree(54, 54, 3, clTreePopulation::adult, 13);
  p_oPop->CreateTree(56, 56, 2, clTreePopulation::adult, 15);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run - but don't let saillight go, or it will mess up the
  //shading values we've assigned
  for (int i = 0; i < p_oSimManager->GetNumberOfBehaviors(); i++) {
    if (strcmp(p_oSimManager->GetBehaviorObject(i)->GetName(), "ncigrowthshell") == 0) {
      p_oSimManager->GetBehaviorObject(i)->Action();
      break;
    }
  }

  //Check the diameters and growth of the target trees
  fExpectedDiam = 18.8233003;
  fExpectedGrowth = 6.372167173;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 31.82738854;
  fExpectedGrowth = 11.37898089;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 33.04706798;
  fExpectedGrowth = 5.078446636;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 50.5837852;
  fExpectedGrowth = 9.306308666;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

  fExpectedDiam = 13.62688973;
  fExpectedGrowth = 5.211482877;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  p_oTargetTree->GetValue(p_oPop->GetFloatDataCode("Growth", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fGrowth);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);
  CPPUNIT_ASSERT(fabs(fGrowth - fExpectedGrowth) < 0.01);

}

////////////////////////////////////////////////////////////////////////////
// TestRun5()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestRun5(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1,
         *p_oTargetTree2,
         *p_oTargetTree3,
         *p_oTargetTree4,
         *p_oTargetTree5,
         *p_oTargetTree6,
         *p_oTargetTree7,
         *p_oTargetTree8,
         *p_oTargetTree;
  float fDiam, fExpectedDiam;
  int iSpecies, iDamage;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile10() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set the damage level for each
  fDiam = 11;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree1->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree1->GetSpecies(),
                                                  p_oTargetTree1->GetType()),
                           iDamage);

  fDiam = 8;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 15;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           iDamage);

  fDiam = 10.5;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree4->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree4->GetSpecies(),
                                                  p_oTargetTree4->GetType()),
                           iDamage);

  fDiam = 15;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree6 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree6->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree6->GetSpecies(),
                                                  p_oTargetTree6->GetType()),
                           iDamage);

  fDiam = 30;
  iSpecies = 0;
  iDamage = 2000;
  p_oTargetTree7 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree7->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree7->GetSpecies(),
                                                  p_oTargetTree7->GetType()),
                           iDamage);

  fDiam = 45;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  //Competing neighbor snag
  fDiam = 11;
  iSpecies = 0;
  iDamage = 2000;
  p_oTargetTree = p_oPop->CreateTree(57, 57, iSpecies, clTreePopulation::snag, fDiam);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree->GetSpecies(),
                                                  p_oTargetTree->GetType()),
                           iDamage);


  //Now create all the neighbors that are too small to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(54, 54, 2, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 12.02578252;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 8.62904031;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 15.62491548;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 11.2924611;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 15.8671366;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 25.52597706;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 30.37533594;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 46.2453247;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile11() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set the damage level for each
  fDiam = 11;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree1->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree1->GetSpecies(),
                                                  p_oTargetTree1->GetType()),
                           iDamage);

  fDiam = 8;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 15;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree3->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree3->GetSpecies(),
                                                  p_oTargetTree3->GetType()),
                           iDamage);

  fDiam = 10.5;
  iSpecies = 0;
  iDamage = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree4->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree4->GetSpecies(),
                                                  p_oTargetTree4->GetType()),
                           iDamage);

  fDiam = 15;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  iDamage = 2000;
  p_oTargetTree6 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree6->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree6->GetSpecies(),
                                                  p_oTargetTree6->GetType()),
                           iDamage);

  fDiam = 30;
  iSpecies = 0;
  iDamage = 2000;
  p_oTargetTree7 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);
  p_oTargetTree7->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree7->GetSpecies(),
                                                  p_oTargetTree7->GetType()),
                           iDamage);

  fDiam = 45;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  //Competing neighbor snag
  fDiam = 11;
  iSpecies = 0;
  iDamage = 2000;
  p_oTargetTree = p_oPop->CreateTree(57, 57, iSpecies, clTreePopulation::snag, fDiam);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("stm_dmg",
                                                  p_oTargetTree->GetSpecies(),
                                                  p_oTargetTree->GetType()),
                           iDamage);

  //Now create all the neighbors that are too small to compete
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(54, 54, 2, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 14.08875462;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 9.956648552;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 16.8769391;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 12.90647995;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 17.6666058;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 26.57320243;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 31.12798751;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 48.75973525;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

}

////////////////////////////////////////////////////////////////////////////
// TestRun6()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::TestRun6(clSimManager *p_oSimManager) {

  clPopulationBase * p_oTemp;
  clTreePopulation * p_oPop;
  clTree *p_oTargetTree1,
         *p_oTargetTree2,
         *p_oTargetTree3,
         *p_oTargetTree4,
         *p_oTargetTree5,
         *p_oTargetTree6,
         *p_oTargetTree7,
         *p_oTargetTree8,
         *p_oTargetTree;
  float fDiam, fExpectedDiam;
  int iSpecies;

  //***********************************
  // Run 1 - 1 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile12() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees
  fDiam = 11;
  iSpecies = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 8;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 15;
  iSpecies = 3;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  iSpecies = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  p_oTargetTree6 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 30;
  iSpecies = 0;
  p_oTargetTree7 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 45;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  //Neighbors
  fDiam = 11;
  iSpecies = 0;
  p_oTargetTree = p_oPop->CreateTree(57, 57, iSpecies, clTreePopulation::snag, fDiam);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(54, 54, 2, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 12.02578252;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 8.62904031;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 15.99192934;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 11.52357274;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 16.03131074;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 25.9509129;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 31.05221861;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 46.39973664;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  //***********************************
  // Run 2 - 3 year timestep
  //***********************************
  //Load our test file and get our tree population pointers
  p_oSimManager->ReadFile( WriteXMLFile13() );
  p_oTemp = p_oSimManager->GetPopulationObject( "treepopulation" );
  p_oPop = ( clTreePopulation * ) p_oTemp;

  //Create our trees and set the damage level for each
  fDiam = 11;
  iSpecies = 0;
  p_oTargetTree1 = p_oPop->CreateTree(10, 10, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 8;
  iSpecies = 1;
  p_oTargetTree2 = p_oPop->CreateTree(20, 20, iSpecies, clTreePopulation::sapling, fDiam);

  fDiam = 15;
  iSpecies = 3;
  p_oTargetTree3 = p_oPop->CreateTree(30, 30, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 10.5;
  iSpecies = 0;
  p_oTargetTree4 = p_oPop->CreateTree(50, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 15;
  iSpecies = 1;
  p_oTargetTree5 = p_oPop->CreateTree(53, 52, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 25;
  iSpecies = 3;
  p_oTargetTree6 = p_oPop->CreateTree(59, 50, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 30;
  iSpecies = 0;
  p_oTargetTree7 = p_oPop->CreateTree(50, 59, iSpecies, clTreePopulation::adult, fDiam);

  fDiam = 45;
  iSpecies = 1;
  p_oTargetTree8 = p_oPop->CreateTree(55, 55, iSpecies, clTreePopulation::adult, fDiam);

  //Neighbors
  fDiam = 11;
  iSpecies = 0;
  p_oTargetTree = p_oPop->CreateTree(57, 57, iSpecies, clTreePopulation::snag, fDiam);
  p_oPop->CreateTree(56, 56, 0, clTreePopulation::seedling, 0.2);
  p_oPop->CreateTree(52, 52, 0, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(53, 53, 1, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(54, 54, 2, clTreePopulation::sapling, 4);
  p_oPop->CreateTree(57, 57, 3, clTreePopulation::sapling, 4);
  p_oTargetTree = p_oPop->CreateTree(58, 58, 1, clTreePopulation::adult, 20);
  p_oTargetTree->SetValue(p_oPop->GetIntDataCode("dead", p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), storm);

  //Now do the run
  p_oSimManager->RunSim(1);

  //Check the diameters and growth of the target trees
  fExpectedDiam = 14.0887546;
  p_oTargetTree = p_oTargetTree1;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 9.95664855;
  p_oTargetTree = p_oTargetTree2;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 17.97947018;
  p_oTargetTree = p_oTargetTree3;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 13.58307004;
  p_oTargetTree = p_oTargetTree4;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 18.1699152;
  p_oTargetTree = p_oTargetTree5;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 27.82913748;
  p_oTargetTree = p_oTargetTree6;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 33.15710399;
  p_oTargetTree = p_oTargetTree7;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

  fExpectedDiam = 49.22161854;
  p_oTargetTree = p_oTargetTree8;
  p_oTargetTree->GetValue(p_oPop->GetDbhCode(p_oTargetTree->GetSpecies(), p_oTargetTree->GetType()), &fDiam);
  CPPUNIT_ASSERT(fabs(fDiam - fExpectedDiam) < 0.01);

}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile1() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Constant GLI</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "<applyTo species=\"Species_2\" type=\"Adult\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth diam only</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>height incrementer</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_2\" type=\"Adult\" />"
       << "</behavior>"
       << "</behaviorList>"
       << "<lightOther>"
       << "<li_constGLI>100</li_constGLI>"
       << "</lightOther>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.17031683</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.17031683</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">1.531</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">1.531</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.36</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.36</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">122.23</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">122.23</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">1</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">1</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">1</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">1</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">1</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.71</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.71</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.12</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.12</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile2() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";
  WriteCommonStuff(oOut);
  WriteRun2CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile3() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";
  WriteCommonStuff(oOut);
  WriteRun2CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

/////////////////////////////////////////////////////////////////////////////
//  WriteCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteCommonStuff( std::fstream &oOut )
{
  using namespace std;
  oOut << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "<tr_species speciesName=\"Species_3\" />"
       << "<tr_species speciesName=\"Species_4\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_4\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_4\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_4\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_3\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_4\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_3\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_4\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_4\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_3\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_4\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_3\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_4\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_3\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_4\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_4\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_4\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_4\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_4\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_4\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_3\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_4\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_3\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_4\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_3\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_4\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_3\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_4\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile4() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun1CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile5()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile5() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun1CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile6()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile6() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun3CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile7()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile7() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun3CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile8()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile8() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun4CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile9()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile9() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun4CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile10()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile10() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun5CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile11()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile11() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun5CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
// WriteXMLFile12()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile12() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun6CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
// WriteXMLFile13()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLFile13() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>3</yearsPerTimestep>";

  WriteCommonStuff(oOut);
  WriteRun6CommonStuff(oOut);

  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteRun1CommonStuff()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteRun1CommonStuff( std::fstream &oOut ) {

  using namespace std;
  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>constradialgrowth</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_3\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_3\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "<st_mdVal species=\"Species_3\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_4\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "<st_sdimVal species=\"Species_3\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_4\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "<st_sdifVal species=\"Species_3\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_4\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "<st_sicVal species=\"Species_3\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_4\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "<st_sdcVal species=\"Species_3\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_4\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_3\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_4\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_3\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_4\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_3\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_4\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_adultConstRadialInc>"
       << "<gr_acriVal species=\"Species_4\">10</gr_acriVal>"
       << "</gr_adultConstRadialInc>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_4\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.17031683</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_4\">1.33</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.699942</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_4\">0.09</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">1.05258749</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">1.531</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_4\">0.994</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">-0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">-0.36</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_4\">-0.4</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.24638994</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">122.23</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_4\">16.43</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">2.36</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_4\">1.41</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">0.698</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">0.457</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_4\">0.469</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">-0.00163</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">-0.00126</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_4\">-0.00163</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_4\">0</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_4\">1</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.89</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_4\">0.78</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.34</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_4\">0.63</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.83</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_4\">0.76</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_3\">0.76</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.27</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_4\">0.7</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_3\">0.7</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66401082</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.71</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.08</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.00442797</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.12</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.03</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciSpecies_3NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_3NeighborLambda>"
       << "<gr_nciSpecies_4NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_4NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_3\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_4\">5</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteRun2CommonStuff()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteRun2CommonStuff( std::fstream &oOut ) {
  using namespace std;

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>saillight</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\" />"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<sailLight>"
       << "<li_heightOfFishEyePhoto>1</li_heightOfFishEyePhoto>"
       << "<li_beamFractGlobalRad>0.5</li_beamFractGlobalRad>"
       << "<li_clearSkyTransCoeff>0.65</li_clearSkyTransCoeff>"
       << "<li_julianDayGrowthStarts>120</li_julianDayGrowthStarts>"
       << "<li_julianDayGrowthEnds>270</li_julianDayGrowthEnds>"
       << "<li_minSunAngle>0.785</li_minSunAngle>"
       << "<li_lightExtinctionCoefficient>"
       << "<li_lecVal species=\"Species_1\">0.08</li_lecVal>"
       << "<li_lecVal species=\"Species_2\">0.091</li_lecVal>"
       << "<li_lecVal species=\"Species_3\">0.059</li_lecVal>"
       << "<li_lecVal species=\"Species_4\">0.059</li_lecVal>"
       << "</li_lightExtinctionCoefficient>"
       << "<li_maxShadingRadius>15.0</li_maxShadingRadius>"
       << "<li_skyMaskAngle>30.0</li_skyMaskAngle>"
       << "<li_crownFracOfHeight>0</li_crownFracOfHeight>"
       << "</sailLight>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.170317</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.699942</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">1.052587488</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.24639</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5.0</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0.2</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">0.5</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.6640108</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.00442797</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciSpecies_3NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "</gr_nciSpecies_3NeighborLambda>"
       << "<gr_nciSpecies_4NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "</gr_nciSpecies_4NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_3\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_4\">5</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteRun3CommonStuff()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteRun3CommonStuff( std::fstream &oOut ) {
  using namespace std;

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Constant GLI</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<lightOther>"
       << "<li_constGLI>100</li_constGLI>"
       << "</lightOther>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_4\">15</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.17031683</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_4\">1.33</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.699942</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_4\">0.09</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">3.052587488</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">3.531</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_4\">3.994</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">-0.13</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_4\">-0.23</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.24638994</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">122.23</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_4\">16.43</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">2.36</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_4\">1.41</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">0.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">0.57</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_4\">0.069</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">0.012</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">0.056</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_4\">1</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0.2</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0.3</gr_nscVal>"
       << "<gr_nscVal species=\"Species_4\">0.5</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_4\">1</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_4\">1</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_4\">1</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_4\">1</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_4\">1</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66401082</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.71</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.08</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.00442797</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.12</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.03</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciSpecies_3NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_3NeighborLambda>"
       << "<gr_nciSpecies_4NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_4NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">10</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">12</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_3\">16</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_4\">14</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>1</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteRun4CommonStuff()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteRun4CommonStuff( std::fstream &oOut ) {

  using namespace std;
  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>Constant GLI</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<lightOther>"
       << "<li_constGLI>100</li_constGLI>"
       << "</lightOther>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_4\">15</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.17031683</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_4\">1.33</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.699942</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_4\">0.09</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">3.052587488</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">3.531</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_4\">3.994</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">-0.13</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_4\">-0.23</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.24638994</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">122.23</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_4\">16.43</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">2.36</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_4\">1.41</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">0.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">0.57</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_4\">0.069</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">0.012</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">0.056</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_4\">1</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0.2</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_4\">0.5</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_4\">1</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_4\">1</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_4\">1</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_4\">1</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_4\">1</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66401082</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.71</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.08</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.00442797</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.12</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.03</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciSpecies_3NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_3NeighborLambda>"
       << "<gr_nciSpecies_4NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_4NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">10</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">12</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_3\">16</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_4\">14</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>1</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteRun5CommonStuff()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteRun5CommonStuff( std::fstream &oOut ) {

  using namespace std;
  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "<st_mdVal species=\"Species_3\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_4\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "<st_sdimVal species=\"Species_3\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_4\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "<st_sdifVal species=\"Species_3\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_4\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "<st_sicVal species=\"Species_3\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_4\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "<st_sdcVal species=\"Species_3\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_4\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_3\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_4\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_3\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_4\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_3\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_4\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_4\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.17031683</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_4\">1.33</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.699942</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_4\">0.09</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">1.05258749</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">1.531</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_4\">0.994</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">-0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">-0.36</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_4\">-0.4</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.24638994</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">122.23</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_4\">16.43</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">2.36</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_4\">1.41</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">0.698</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">0.457</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_4\">0.469</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">-0.00163</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">-0.00126</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_4\">-0.00163</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_4\">0</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_4\">1</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.89</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_4\">0.78</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.34</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_4\">0.63</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.83</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_4\">0.76</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.27</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_4\">0.7</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66401082</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.71</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.08</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.00442797</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.12</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.03</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciSpecies_3NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_3NeighborLambda>"
       << "<gr_nciSpecies_4NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_4NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_3\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_4\">5</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>1</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteRun5CommonStuff()
////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteRun6CommonStuff( std::fstream &oOut ) {

  using namespace std;
  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>juvstochasticmort</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Snag\"/>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_1\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Sapling\"/>"
       << "<applyTo species=\"Species_4\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_4\" type=\"Sapling\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_4\">0</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">0</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.17031683</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_4\">1.33</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.699942</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_4\">0.09</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">1.05258749</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">1.531</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_4\">0.994</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">-0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">-0.36</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_4\">-0.4</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.24638994</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">122.23</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_4\">16.43</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">2.36</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_4\">1.41</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">0</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">0.457</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_4\">0.469</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">-0.00163</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">-0.00126</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_4\">-0.00163</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0</gr_nscVal>"
       << "<gr_nscVal species=\"Species_4\">0</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">1</gr_nseVal>"
       << "<gr_nseVal species=\"Species_4\">1</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.89</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_4\">0.78</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.34</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_4\">0.63</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.83</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_4\">0.76</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.27</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_4\">0.7</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66401082</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.71</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.08</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.00442797</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.12</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.03</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciSpecies_3NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_3NeighborLambda>"
       << "<gr_nciSpecies_4NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.41812471</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.24</gr_nlVal>"
       << "<gr_nlVal species=\"Species_4\">0.05</gr_nlVal>"
       << "</gr_nciSpecies_4NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_3\">5</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_4\">5</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>1</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "<mortality>"
       << "<mo_randomJuvenileMortality>"
       << "<mo_rjmVal species=\"Species_3\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_1\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_2\">0</mo_rjmVal>"
       << "<mo_rjmVal species=\"Species_4\">0</mo_rjmVal>"
       << "</mo_randomJuvenileMortality>"
       << "</mortality>"
       << "</paramFile>";
}

/////////////////////////////////////////////////////////////////////////////
//  WriteErrorFileCommonStuff()
/////////////////////////////////////////////////////////////////////////////
void clTestNciGrowth::WriteErrorFileCommonStuff( std::fstream &oOut )
{
  using namespace std;
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>";
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile1() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">-10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile2() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">-15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile3() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">0</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile4() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">0</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile5()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile5() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">-0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile6()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile6() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">1.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile7()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile7() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">-0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile8()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile8() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">1.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile10()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile10() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">1.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile11()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile11() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">-0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile12()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile12() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">1.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile13()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile13() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_4\">1</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_4\">1</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_4\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_3\">1</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_4\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_3\">1</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0.2</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0.2</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">0.5</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">0.5</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile14()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile14() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  WriteErrorFileCommonStuff(oOut);

  //Write file
  oOut << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">1</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_4\">1</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">1</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_4\">1</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_4\">1</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_3\">1</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_4\">1</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_3\">1</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciShadingCoefficient>"
       << "<gr_nscVal species=\"Species_1\">0.2</gr_nscVal>"
       << "<gr_nscVal species=\"Species_2\">0.2</gr_nscVal>"
       << "</gr_nciShadingCoefficient>"
       << "<gr_nciShadingExponent>"
       << "<gr_nseVal species=\"Species_1\">0.5</gr_nseVal>"
       << "<gr_nseVal species=\"Species_2\">0.5</gr_nseVal>"
       << "</gr_nciShadingExponent>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">-10</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}

////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile9()
////////////////////////////////////////////////////////////////////////////
char* clTestNciGrowth::WriteXMLErrorFile9() {
  using namespace std;
  char *cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  //Write file
  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>200.0</plot_lenX>"
       << "<plot_lenY>200.0</plot_lenY>"
       << "<plot_precip_mm_yr>1150.645781</plot_precip_mm_yr>"
       << "<plot_temp_C>12.88171785</plot_temp_C>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\" />"
       << "<tr_species speciesName=\"Species_2\" />"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_stdAsympCrownRad>"
       << "<tr_sacrVal species=\"Species_1\">0.0549</tr_sacrVal>"
       << "<tr_sacrVal species=\"Species_2\">0.0549</tr_sacrVal>"
       << "</tr_stdAsympCrownRad>"
       << "<tr_stdCrownRadExp>"
       << "<tr_screVal species=\"Species_1\">1.0</tr_screVal>"
       << "<tr_screVal species=\"Species_2\">1.0</tr_screVal>"
       << "</tr_stdCrownRadExp>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_interceptDiam10ToDBH>"
       << "<tr_idtdVal species=\"Species_1\">0</tr_idtdVal>"
       << "<tr_idtdVal species=\"Species_2\">0</tr_idtdVal>"
       << "</tr_interceptDiam10ToDBH>"
       << "<tr_stdAsympCrownHt>"
       << "<tr_sachVal species=\"Species_1\">0.389</tr_sachVal>"
       << "<tr_sachVal species=\"Species_2\">0.389</tr_sachVal>"
       << "</tr_stdAsympCrownHt>"
       << "<tr_stdCrownHtExp>"
       << "<tr_scheVal species=\"Species_1\">1.0</tr_scheVal>"
       << "<tr_scheVal species=\"Species_2\">1.0</tr_scheVal>"
       << "</tr_stdCrownHtExp>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "<tr_whatAdultCrownRadDiam>"
       << "<tr_wacrdVal species=\"Species_1\">0</tr_wacrdVal>"
       << "<tr_wacrdVal species=\"Species_2\">0</tr_wacrdVal>"
       << "</tr_whatAdultCrownRadDiam>"
       << "<tr_whatAdultCrownHeightHeight>"
       << "<tr_wachhVal species=\"Species_1\">0</tr_wachhVal>"
       << "<tr_wachhVal species=\"Species_2\">0</tr_wachhVal>"
       << "</tr_whatAdultCrownHeightHeight>"
       << "<tr_whatSaplingCrownRadDiam>"
       << "<tr_wscrdVal species=\"Species_1\">0</tr_wscrdVal>"
       << "<tr_wscrdVal species=\"Species_2\">0</tr_wscrdVal>"
       << "</tr_whatSaplingCrownRadDiam>"
       << "<tr_whatSaplingCrownHeightHeight>"
       << "<tr_wschhVal species=\"Species_1\">0</tr_wschhVal>"
       << "<tr_wschhVal species=\"Species_2\">0</tr_wschhVal>"
       << "</tr_whatSaplingCrownHeightHeight>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>storm</behaviorName>"
       << "<version>1</version>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>storm damage applier</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "<behavior>"
       << "<behaviorName>ncigrowth</behaviorName>"
       << "<version>2</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>"
       << "<applyTo species=\"Species_2\" type=\"Adult\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<storm>"
       << "<st_s1ReturnInterval>1000</st_s1ReturnInterval>"
       << "<st_s2ReturnInterval>1000</st_s2ReturnInterval>"
       << "<st_s3ReturnInterval>1000</st_s3ReturnInterval>"
       << "<st_s4ReturnInterval>1000</st_s4ReturnInterval>"
       << "<st_s5ReturnInterval>1000</st_s5ReturnInterval>"
       << "<st_s6ReturnInterval>1000</st_s6ReturnInterval>"
       << "<st_s7ReturnInterval>1000</st_s7ReturnInterval>"
       << "<st_s8ReturnInterval>1000</st_s8ReturnInterval>"
       << "<st_s9ReturnInterval>1000</st_s9ReturnInterval>"
       << "<st_s10ReturnInterval>1000</st_s10ReturnInterval>"
       << "<st_susceptibility>1</st_susceptibility>"
       << "<st_stochasticity>0</st_stochasticity>"
       << "<st_stmSSTPeriod>1</st_stmSSTPeriod>"
       << "<st_stmSineD>0</st_stmSineD>"
       << "<st_stmSineF>1</st_stmSineF>"
       << "<st_stmSineG>1</st_stmSineG>"
       << "<st_stmTrendSlopeM>0</st_stmTrendSlopeM>"
       << "<st_stmTrendInterceptI>1</st_stmTrendInterceptI>"
       << "<st_minDBH>"
       << "<st_mdVal species=\"Species_1\">5</st_mdVal>"
       << "<st_mdVal species=\"Species_2\">6</st_mdVal>"
       << "</st_minDBH>"
       << "<st_stmDmgInterceptMed>"
       << "<st_sdimVal species=\"Species_1\">2.1789601</st_sdimVal>"
       << "<st_sdimVal species=\"Species_2\">2.475987</st_sdimVal>"
       << "</st_stmDmgInterceptMed>"
       << "<st_stmDmgInterceptFull>"
       << "<st_sdifVal species=\"Species_1\">3.6334169</st_sdifVal>"
       << "<st_sdifVal species=\"Species_2\">3.6331242</st_sdifVal>"
       << "</st_stmDmgInterceptFull>"
       << "<st_stmIntensityCoeff>"
       << "<st_sicVal species=\"Species_1\">-0.3545352</st_sicVal>"
       << "<st_sicVal species=\"Species_2\">-1.2289105</st_sicVal>"
       << "</st_stmIntensityCoeff>"
       << "<st_stmDBHCoeff>"
       << "<st_sdcVal species=\"Species_1\">0.8280319</st_sdcVal>"
       << "<st_sdcVal species=\"Species_2\">0.3282479</st_sdcVal>"
       << "</st_stmDBHCoeff>"
       << "<st_stmPropDieMedDmg>"
       << "<st_spdmdVal species=\"Species_1\">0</st_spdmdVal>"
       << "<st_spdmdVal species=\"Species_2\">0</st_spdmdVal>"
       << "</st_stmPropDieMedDmg>"
       << "<st_stmPropDieFullDmg>"
       << "<st_spdfdVal species=\"Species_1\">0</st_spdfdVal>"
       << "<st_spdfdVal species=\"Species_2\">0</st_spdfdVal>"
       << "</st_stmPropDieFullDmg>"
       << "<st_stmPropTipUpFullDmg>"
       << "<st_sptufdVal species=\"Species_1\">0</st_sptufdVal>"
       << "<st_sptufdVal species=\"Species_2\">0</st_sptufdVal>"
       << "</st_stmPropTipUpFullDmg>"
       << "<st_numYearsStormSnags>0</st_numYearsStormSnags>"
       << "<st_numYearsToHeal>4</st_numYearsToHeal>"
       << "</storm>"
       << "<growth>"
       << "<gr_nciMaxCrowdingRadius>"
       << "<gr_nmcrVal species=\"Species_1\">10</gr_nmcrVal>"
       << "<gr_nmcrVal species=\"Species_2\">10</gr_nmcrVal>"
       << "</gr_nciMaxCrowdingRadius>"
       << "<gr_nciAlpha>"
       << "<gr_naVal species=\"Species_1\">2.81</gr_naVal>"
       << "<gr_naVal species=\"Species_2\">2.81</gr_naVal>"
       << "</gr_nciAlpha>"
       << "<gr_nciBeta>"
       << "<gr_nbVal species=\"Species_1\">0.5</gr_nbVal>"
       << "<gr_nbVal species=\"Species_2\">0.5</gr_nbVal>"
       << "</gr_nciBeta>"
       << "<gr_nciMaxPotentialGrowth>"
       << "<gr_nmpgVal species=\"Species_1\">15.31</gr_nmpgVal>"
       << "<gr_nmpgVal species=\"Species_2\">15.31</gr_nmpgVal>"
       << "</gr_nciMaxPotentialGrowth>"
       << "<gr_nciSizeSensNCI>"
       << "<gr_nssnVal species=\"Species_1\">0.43</gr_nssnVal>"
       << "<gr_nssnVal species=\"Species_2\">0.43</gr_nssnVal>"
       << "</gr_nciSizeSensNCI>"
       << "<gr_nciSizeEffectMode>"
       << "<gr_nsemVal species=\"Species_1\">34.2</gr_nsemVal>"
       << "<gr_nsemVal species=\"Species_2\">34.2</gr_nsemVal>"
       << "</gr_nciSizeEffectMode>"
       << "<gr_nciSizeEffectVariance>"
       << "<gr_nsevVal species=\"Species_1\">5</gr_nsevVal>"
       << "<gr_nsevVal species=\"Species_2\">5</gr_nsevVal>"
       << "</gr_nciSizeEffectVariance>"
       << "<gr_nciCrowdingSlope>"
       << "<gr_ncslVal species=\"Species_1\">1.98</gr_ncslVal>"
       << "<gr_ncslVal species=\"Species_2\">1.98</gr_ncslVal>"
       << "</gr_nciCrowdingSlope>"
       << "<gr_nciCrowdingSteepness>"
       << "<gr_ncstVal species=\"Species_1\">1.63</gr_ncstVal>"
       << "<gr_ncstVal species=\"Species_2\">1.63</gr_ncstVal>"
       << "</gr_nciCrowdingSteepness>"
       << "<gr_nciStormEffMedDmg>"
       << "<gr_nsemdVal species=\"Species_1\">-0.9</gr_nsemdVal>"
       << "<gr_nsemdVal species=\"Species_2\">0.9</gr_nsemdVal>"
       << "</gr_nciStormEffMedDmg>"
       << "<gr_nciStormEffFullDmg>"
       << "<gr_nsefdVal species=\"Species_1\">0.42</gr_nsefdVal>"
       << "<gr_nsefdVal species=\"Species_2\">0.42</gr_nsefdVal>"
       << "</gr_nciStormEffFullDmg>"
       << "<gr_nciNeighStormEffMedDmg>"
       << "<gr_nnsemdVal species=\"Species_1\">0.33</gr_nnsemdVal>"
       << "<gr_nnsemdVal species=\"Species_2\">0.33</gr_nnsemdVal>"
       << "</gr_nciNeighStormEffMedDmg>"
       << "<gr_nciNeighStormEffFullDmg>"
       << "<gr_nnsefdVal species=\"Species_1\">0.54</gr_nnsefdVal>"
       << "<gr_nnsefdVal species=\"Species_2\">0.54</gr_nnsefdVal>"
       << "</gr_nciNeighStormEffFullDmg>"
       << "<gr_nciSpecies_1NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_1NeighborLambda>"
       << "<gr_nciSpecies_2NeighborLambda>"
       << "<gr_nlVal species=\"Species_1\">0.66</gr_nlVal>"
       << "<gr_nlVal species=\"Species_2\">0.66</gr_nlVal>"
       << "</gr_nciSpecies_2NeighborLambda>"
       << "<gr_nciMinNeighborDBH>"
       << "<gr_nmndVal species=\"Species_1\">0</gr_nmndVal>"
       << "<gr_nmndVal species=\"Species_2\">0</gr_nmndVal>"
       << "</gr_nciMinNeighborDBH>"
       << "<gr_nciDbhDivisor>100</gr_nciDbhDivisor>"
       << "<gr_nciIncludeSnagsInNCI>0</gr_nciIncludeSnagsInNCI>"
       << "</growth>"
       << "</paramFile>";


  oOut.close();

  return cFileString;
}
